@@ -15,12 +15,12 @@
 ***************************************************************************
 """
 
-__author__ = 'Médéric Ribreux'
-__date__ = 'March 2016'
-__copyright__ = '(C) 2016, Médéric Ribreux'
+__author__ = "Médéric Ribreux"
+__date__ = "March 2016"
+__copyright__ = "(C) 2016, Médéric Ribreux"
 
 from .i import verifyRasterNum
 
 
 def checkParameterValuesBeforeExecuting(alg, parameters, context):
-    return verifyRasterNum(alg, parameters, context, 'input', 4)
+    return verifyRasterNum(alg, parameters, context, "input", 4)
