@@ -15,27 +15,26 @@
 ***************************************************************************
 """
 
-__author__ = 'Médéric Ribreux'
-__date__ = 'September 2017'
-__copyright__ = '(C) 2017, Médéric Ribreux'
+__author__ = "Médéric Ribreux"
+__date__ = "September 2017"
+__copyright__ = "(C) 2017, Médéric Ribreux"
 
 from qgis.core import QgsProcessingParameterString
-from grassprovider.Grass7Utils import Grass7Utils
+from grassprovider.grass_utils import GrassUtils
 
 
 def processCommand(alg, parameters, context, feedback):
     # We had a new "output" parameter
-    out = 'output{}'.format(alg.uniqueSuffix)
-    p = QgsProcessingParameterString('~output', None, out, False, False)
+    out = f"output{alg.uniqueSuffix}"
+    p = QgsProcessingParameterString("~output", None, out, False, False)
     alg.addParameter(p)
 
     # We need to remove all outputs
     alg.processCommand(parameters, context, feedback, True)
 
     # Then we add a new command for treating results
-    calcExpression = 'correctedoutput{}=@{}'.format(
-        alg.uniqueSuffix, out)
-    command = 'r.mapcalc expression="{}"'.format(calcExpression)
+    calcExpression = f"correctedoutput{alg.uniqueSuffix}=@{out}"
+    command = f'r.mapcalc expression="{calcExpression}"'
     alg.commands.append(command)
 
 
@@ -44,9 +43,7 @@ def processOutputs(alg, parameters, context, feedback):
     metaOpt = alg.parameterAsString(parameters, alg.GRASS_RASTER_FORMAT_META, context)
 
     # Export the results from correctedoutput
-    grassName = 'correctedoutput{}'.format(alg.uniqueSuffix)
-    fileName = alg.parameterAsOutputLayer(
-        parameters, 'routput', context)
-    outFormat = Grass7Utils.getRasterFormatFromFilename(fileName)
-    alg.exportRasterLayer(grassName, fileName, True,
-                          outFormat, createOpt, metaOpt)
+    grassName = f"correctedoutput{alg.uniqueSuffix}"
+    fileName = alg.parameterAsOutputLayer(parameters, "routput", context)
+    outFormat = GrassUtils.getRasterFormatFromFilename(fileName)
+    alg.exportRasterLayer(grassName, fileName, True, outFormat, createOpt, metaOpt)
