@@ -27,6 +27,8 @@ from collections import defaultdict
 
 from qgis.core import (
     QgsField,
+    QgsFields,
+    QgsProcessingUtils,
     QgsFeatureSink,
     QgsGeometry,
     QgsSpatialIndex,
@@ -133,8 +135,9 @@ class TopoColor(QgisAlgorithm):
         balance_by = self.parameterAsEnum(parameters, self.BALANCE, context)
         min_distance = self.parameterAsDouble(parameters, self.MIN_DISTANCE, context)
 
-        fields = source.fields()
-        fields.append(QgsField("color_id", QMetaType.Type.Int))
+        newFields = QgsFields()
+        newFields.append(QgsField("color_id", QMetaType.Type.Int))
+        fields = QgsProcessingUtils.combineFields(source.fields(), newFields)
 
         (sink, dest_id) = self.parameterAsSink(
             parameters,
