@@ -15,15 +15,17 @@
 ***************************************************************************
 """
 
-__author__ = 'Victor Olaya'
-__date__ = 'January 2013'
-__copyright__ = '(C) 2013, Victor Olaya'
+__author__ = "Victor Olaya"
+__date__ = "January 2013"
+__copyright__ = "(C) 2013, Victor Olaya"
 
 import warnings
-from qgis.core import (QgsProcessingParameterFeatureSource,
-                       QgsProcessingParameterField,
-                       QgsProcessingParameterFileDestination,
-                       QgsProcessingException)
+from qgis.core import (
+    QgsProcessingParameterFeatureSource,
+    QgsProcessingParameterField,
+    QgsProcessingParameterFileDestination,
+    QgsProcessingException,
+)
 from processing.algs.qgis.QgisAlgorithm import QgisAlgorithm
 
 from processing.tools import vector
@@ -32,44 +34,61 @@ from qgis.PyQt.QtCore import QCoreApplication
 
 
 class VectorLayerScatterplot3D(QgisAlgorithm):
-    INPUT = 'INPUT'
-    OUTPUT = 'OUTPUT'
-    XFIELD = 'XFIELD'
-    YFIELD = 'YFIELD'
-    ZFIELD = 'ZFIELD'
+    INPUT = "INPUT"
+    OUTPUT = "OUTPUT"
+    XFIELD = "XFIELD"
+    YFIELD = "YFIELD"
+    ZFIELD = "ZFIELD"
 
     def group(self):
-        return self.tr('Plots')
+        return self.tr("Plots")
 
     def groupId(self):
-        return 'plots'
+        return "plots"
 
     def __init__(self):
         super().__init__()
 
     def initAlgorithm(self, config=None):
-        self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT,
-                                                              self.tr('Input layer')))
-        self.addParameter(QgsProcessingParameterField(self.XFIELD,
-                                                      self.tr('X attribute'),
-                                                      parentLayerParameterName=self.INPUT,
-                                                      type=QgsProcessingParameterField.Numeric))
-        self.addParameter(QgsProcessingParameterField(self.YFIELD,
-                                                      self.tr('Y attribute'),
-                                                      parentLayerParameterName=self.INPUT,
-                                                      type=QgsProcessingParameterField.Numeric))
-        self.addParameter(QgsProcessingParameterField(self.ZFIELD,
-                                                      self.tr('Z attribute'),
-                                                      parentLayerParameterName=self.INPUT,
-                                                      type=QgsProcessingParameterField.Numeric))
+        self.addParameter(
+            QgsProcessingParameterFeatureSource(self.INPUT, self.tr("Input layer"))
+        )
+        self.addParameter(
+            QgsProcessingParameterField(
+                self.XFIELD,
+                self.tr("X attribute"),
+                parentLayerParameterName=self.INPUT,
+                type=QgsProcessingParameterField.DataType.Numeric,
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterField(
+                self.YFIELD,
+                self.tr("Y attribute"),
+                parentLayerParameterName=self.INPUT,
+                type=QgsProcessingParameterField.DataType.Numeric,
+            )
+        )
+        self.addParameter(
+            QgsProcessingParameterField(
+                self.ZFIELD,
+                self.tr("Z attribute"),
+                parentLayerParameterName=self.INPUT,
+                type=QgsProcessingParameterField.DataType.Numeric,
+            )
+        )
 
-        self.addParameter(QgsProcessingParameterFileDestination(self.OUTPUT, self.tr('Histogram'), self.tr('HTML files (*.html)')))
+        self.addParameter(
+            QgsProcessingParameterFileDestination(
+                self.OUTPUT, self.tr("Histogram"), self.tr("HTML files (*.html)")
+            )
+        )
 
     def name(self):
-        return 'scatter3dplot'
+        return "scatter3dplot"
 
     def displayName(self):
-        return self.tr('Vector layer scatterplot 3D')
+        return self.tr("Vector layer scatterplot 3D")
 
     def processAlgorithm(self, parameters, context, feedback):
         try:
@@ -80,11 +99,18 @@ class VectorLayerScatterplot3D(QgisAlgorithm):
                 import plotly as plt
                 import plotly.graph_objs as go
         except ImportError:
-            raise QgsProcessingException(QCoreApplication.translate('VectorLayerScatterplot3D', 'This algorithm requires the Python “plotly” library. Please install this library and try again.'))
+            raise QgsProcessingException(
+                QCoreApplication.translate(
+                    "VectorLayerScatterplot3D",
+                    "This algorithm requires the Python “plotly” library. Please install this library and try again.",
+                )
+            )
 
         source = self.parameterAsSource(parameters, self.INPUT, context)
         if source is None:
-            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+            raise QgsProcessingException(
+                self.invalidSourceError(parameters, self.INPUT)
+            )
 
         xfieldname = self.parameterAsString(parameters, self.XFIELD, context)
         yfieldname = self.parameterAsString(parameters, self.YFIELD, context)
@@ -94,11 +120,14 @@ class VectorLayerScatterplot3D(QgisAlgorithm):
 
         values = vector.values(source, xfieldname, yfieldname, zfieldname)
 
-        data = [go.Scatter3d(
+        data = [
+            go.Scatter3d(
                 x=values[xfieldname],
                 y=values[yfieldname],
                 z=values[zfieldname],
-                mode='markers')]
+                mode="markers",
+            )
+        ]
 
         plt.offline.plot(data, filename=output, auto_open=False)
 
