@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     user.py
@@ -17,16 +15,16 @@
 ***************************************************************************
 """
 
-__author__ = 'Nathan Woodrow'
-__date__ = 'January 2015'
-__copyright__ = '(C) 2015, Nathan Woodrow'
+__author__ = "Nathan Woodrow"
+__date__ = "January 2015"
+__copyright__ = "(C) 2015, Nathan Woodrow"
 
 import os
 import sys
 import glob
 import traceback
 
-from qgis.PyQt.QtCore import QCoreApplication
+from qgis.PyQt.QtCore import QCoreApplication, qDebug
 from qgis.core import Qgis, QgsApplication, QgsMessageLog
 
 
@@ -43,12 +41,51 @@ def load_user_expressions(path):
         # As user expression functions should be registered with qgsfunction
         # just importing the file is enough to get it to load the functions into QGIS
         try:
-            __import__("expressions.{0}".format(name), locals(), globals())
+            __import__(f"expressions.{name}", locals(), globals())
         except:
             error = traceback.format_exc()
             msgtitle = QCoreApplication.translate("UserExpressions", "User expressions")
-            msg = QCoreApplication.translate("UserExpressions", "The user expression {0} is not valid").format(name)
-            QgsMessageLog.logMessage(msg + "\n" + error, msgtitle, Qgis.Warning)
+            msg = QCoreApplication.translate(
+                "UserExpressions", "The user expression {0} is not valid"
+            ).format(name)
+            QgsMessageLog.logMessage(
+                msg + "\n" + error, msgtitle, Qgis.MessageLevel.Warning
+            )
+
+
+def reload_user_expressions(path):
+    """
+    Reload all user expressions from the given path
+    """
+    # First unload expression modules, looping all
+    # py files and remove them from sys.modules
+    modules = glob.glob(path + "/*.py")
+    names = [os.path.basename(f)[:-3] for f in modules]
+    for name in names:
+        if name == "__init__":
+            continue
+
+        mod = f"expressions.{name}"
+        if mod not in sys.modules:
+            continue
+
+        # try removing path
+        if hasattr(sys.modules[mod], "__path__"):
+            for path in sys.modules[mod].__path__:
+                try:
+                    sys.path.remove(path)
+                except ValueError:
+                    # Discard if path is not there
+                    pass
+
+        # try to remove the module from python
+        try:
+            del sys.modules[mod]
+        except:
+            qDebug("Error when removing module:\n%s" % traceback.format_exc())
+
+    # Finally, load again the users expressions from the given path
+    load_user_expressions(path)
 
 
 userpythonhome = os.path.join(QgsApplication.qgisSettingsDirPath(), "python")
@@ -87,6 +124,7 @@ try:
     expressions.load = load_user_expressions
     expressions.load(expressionspath)
     expressions.template = template
+    expressions.reload = reload_user_expressions
 except ImportError:
     # We get a import error and crash for some reason even if we make the expressions package
     # TODO Fix the crash on first load with no expressions folder
