@@ -16,22 +16,18 @@
 #ifndef QGSWINDOW3DENGINE_H
 #define QGSWINDOW3DENGINE_H
 
+#include <QSize>
+
 #include "qgsabstract3dengine.h"
-#include "qgsshadowrenderingframegraph.h"
-#include "qgspostprocessingentity.h"
-#include "qgspreviewquad.h"
 
-namespace Qt3DRender
-{
-  class QRenderCapture;
-}
 
 namespace Qt3DExtras
 {
-  class Qt3DWindow;
   class QForwardRenderer;
 }
 
+
+class Qgs3DMapCanvas;
 class QWindow;
 
 
@@ -50,15 +46,17 @@ class _3D_EXPORT QgsWindow3DEngine : public QgsAbstract3DEngine
 {
     Q_OBJECT
   public:
-
     /**
-     * Constructor for QgsWindow3DEngine with the specified \a parent object.
+     * Constructor for QgsWindow3DEngine with the specified \a parent Qgs3DMapCanvas.
      */
-    QgsWindow3DEngine( QObject *parent = nullptr );
+    QgsWindow3DEngine( Qgs3DMapCanvas *parent );
 
     //! Returns the internal 3D window where all the rendered output is displayed
     QWindow *window();
 
+    //! Returns the root entity
+    Qt3DCore::QEntity *root() const;
+
     //! Sets whether shadow rendering is enabled
     void setShadowRenderingEnabled( bool enabled );
     //! Returns whether shadow rendering is enabled
@@ -74,15 +72,15 @@ class _3D_EXPORT QgsWindow3DEngine : public QgsAbstract3DEngine
     QSurface *surface() const override;
 
     void setSize( QSize s ) override;
+
   private:
     //! 3D window with all the 3D magic inside
-    Qt3DExtras::Qt3DWindow *mWindow3D = nullptr;
+    Qgs3DMapCanvas *mMapCanvas3D = nullptr;
     //! Frame graph node for render capture
     bool mShadowRenderingEnabled = false;
     Qt3DCore::QEntity *mRoot = nullptr;
     Qt3DCore::QEntity *mSceneRoot = nullptr;
 
-    QgsPreviewQuad *mPreviewQuad = nullptr;
     QSize mSize = QSize( 1024, 768 );
 };
 
