@@ -51,9 +51,9 @@ QStringList QgsExtractLabelsAlgorithm::tags() const
   return QObject::tr( "map themes,font,position" ).split( ',' );
 }
 
-QgsProcessingAlgorithm::Flags QgsExtractLabelsAlgorithm::flags() const
+Qgis::ProcessingAlgorithmFlags QgsExtractLabelsAlgorithm::flags() const
 {
-  return QgsProcessingAlgorithm::flags() | FlagRequiresProject;
+  return QgsProcessingAlgorithm::flags() | Qgis::ProcessingAlgorithmFlag::RequiresProject;
 }
 
 QString QgsExtractLabelsAlgorithm::group() const
@@ -69,37 +69,43 @@ QString QgsExtractLabelsAlgorithm::groupId() const
 void QgsExtractLabelsAlgorithm::initAlgorithm( const QVariantMap & )
 {
   addParameter( new QgsProcessingParameterExtent(
-                  QStringLiteral( "EXTENT" ),
-                  QObject::tr( "Map extent" ) ) );
+    QStringLiteral( "EXTENT" ),
+    QObject::tr( "Map extent" )
+  ) );
 
   addParameter( new QgsProcessingParameterScale(
-                  QStringLiteral( "SCALE" ),
-                  QObject::tr( "Map scale" ) ) );
+    QStringLiteral( "SCALE" ),
+    QObject::tr( "Map scale" )
+  ) );
 
   std::unique_ptr<QgsProcessingParameterMapTheme> mapThemeParameter = std::make_unique<QgsProcessingParameterMapTheme>(
-        QStringLiteral( "MAP_THEME" ),
-        QObject::tr( "Map theme" ),
-        QVariant(), true );
+    QStringLiteral( "MAP_THEME" ),
+    QObject::tr( "Map theme" ),
+    QVariant(), true
+  );
   mapThemeParameter->setHelp( QObject::tr( "This parameter is optional. When left unset, the algorithm will fallback to extracting labels from all currently visible layers in the project." ) );
   addParameter( mapThemeParameter.release() );
 
   addParameter( new QgsProcessingParameterBoolean(
-                  QStringLiteral( "INCLUDE_UNPLACED" ),
-                  QObject::tr( "Include unplaced labels" ),
-                  QVariant( true ), true ) );
+    QStringLiteral( "INCLUDE_UNPLACED" ),
+    QObject::tr( "Include unplaced labels" ),
+    QVariant( true ), true
+  ) );
 
   std::unique_ptr<QgsProcessingParameterNumber> dpiParameter = std::make_unique<QgsProcessingParameterNumber>(
-        QStringLiteral( "DPI" ),
-        QObject::tr( "Map resolution (in DPI)" ),
-        QgsProcessingParameterNumber::Double,
-        QVariant( 96.0 ), true );
-  dpiParameter->setFlags( dpiParameter->flags() | QgsProcessingParameterDefinition::FlagAdvanced );
+    QStringLiteral( "DPI" ),
+    QObject::tr( "Map resolution (in DPI)" ),
+    Qgis::ProcessingNumberParameterType::Double,
+    QVariant( 96.0 ), true
+  );
+  dpiParameter->setFlags( dpiParameter->flags() | Qgis::ProcessingParameterFlag::Advanced );
   addParameter( dpiParameter.release() );
 
   addParameter( new QgsProcessingParameterFeatureSink(
-                  QStringLiteral( "OUTPUT" ),
-                  QObject::tr( "Extracted labels" ),
-                  QgsProcessing::TypeVectorPoint ) );
+    QStringLiteral( "OUTPUT" ),
+    QObject::tr( "Extracted labels" ),
+    Qgis::ProcessingSourceType::VectorPoint
+  ) );
 }
 
 QString QgsExtractLabelsAlgorithm::shortDescription() const
@@ -107,6 +113,11 @@ QString QgsExtractLabelsAlgorithm::shortDescription() const
   return QObject::tr( "Converts map labels to a point layer with relevant details saved as attributes." );
 }
 
+Qgis::ProcessingAlgorithmDocumentationFlags QgsExtractLabelsAlgorithm::documentationFlags() const
+{
+  return Qgis::ProcessingAlgorithmDocumentationFlag::RegeneratesPrimaryKey;
+}
+
 QString QgsExtractLabelsAlgorithm::shortHelpString() const
 {
   return QObject::tr( "This algorithm extracts label information from a rendered map at a given extent and scale.\n\n"
@@ -174,25 +185,22 @@ class ExtractLabelSink : public QgsLabelSink
         return;
 
       QgsPalLayerSettings labelSettings( settings );
-      const QMap< QgsPalLayerSettings::Property, QVariant > &dataDefinedValues = labelFeature->dataDefinedValues();
+      const QMap<QgsPalLayerSettings::Property, QVariant> &dataDefinedValues = labelFeature->dataDefinedValues();
 
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::MultiLineWrapChar ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::MultiLineWrapChar ) )
       {
-        labelSettings.wrapChar = dataDefinedValues.value( QgsPalLayerSettings::MultiLineWrapChar ).toString();
+        labelSettings.wrapChar = dataDefinedValues.value( QgsPalLayerSettings::Property::MultiLineWrapChar ).toString();
       }
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::AutoWrapLength ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::AutoWrapLength ) )
       {
-        labelSettings.autoWrapLength = dataDefinedValues.value( QgsPalLayerSettings::AutoWrapLength ).toInt();
+        labelSettings.autoWrapLength = dataDefinedValues.value( QgsPalLayerSettings::Property::AutoWrapLength ).toInt();
       }
-      const QString labelText = QgsPalLabeling::splitToLines( labelFeature->text( -1 ),
-                                labelSettings.wrapChar,
-                                labelSettings.autoWrapLength,
-                                labelSettings.useMaxLineLengthForAutoWrap ).join( '\n' );
+      const QString labelText = QgsPalLabeling::splitToLines( labelFeature->text( -1 ), labelSettings.wrapChar, labelSettings.autoWrapLength, labelSettings.useMaxLineLengthForAutoWrap ).join( '\n' );
 
       QString labelAlignment;
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::MultiLineAlignment ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::MultiLineAlignment ) )
       {
-        labelSettings.multilineAlign = static_cast< Qgis::LabelMultiLineAlignment >( dataDefinedValues.value( QgsPalLayerSettings::MultiLineAlignment ).toInt() );
+        labelSettings.multilineAlign = static_cast<Qgis::LabelMultiLineAlignment>( dataDefinedValues.value( QgsPalLayerSettings::Property::MultiLineAlignment ).toInt() );
       }
       switch ( labelSettings.multilineAlign )
       {
@@ -213,23 +221,23 @@ class ExtractLabelSink : public QgsLabelSink
           break;
 
         case Qgis::LabelMultiLineAlignment::FollowPlacement:
-          switch ( label->getQuadrant() )
+          switch ( label->quadrant() )
           {
-            case pal::LabelPosition::QuadrantAboveLeft:
-            case pal::LabelPosition::QuadrantLeft:
-            case pal::LabelPosition::QuadrantBelowLeft:
+            case Qgis::LabelQuadrantPosition::AboveLeft:
+            case Qgis::LabelQuadrantPosition::Left:
+            case Qgis::LabelQuadrantPosition::BelowLeft:
               labelAlignment = QStringLiteral( "right" );
               break;
 
-            case pal::LabelPosition::QuadrantAbove:
-            case pal::LabelPosition::QuadrantOver:
-            case pal::LabelPosition::QuadrantBelow:
+            case Qgis::LabelQuadrantPosition::Above:
+            case Qgis::LabelQuadrantPosition::Over:
+            case Qgis::LabelQuadrantPosition::Below:
               labelAlignment = QStringLiteral( "center" );
               break;
 
-            case pal::LabelPosition::QuadrantAboveRight:
-            case pal::LabelPosition::QuadrantRight:
-            case pal::LabelPosition::QuadrantBelowRight:
+            case Qgis::LabelQuadrantPosition::AboveRight:
+            case Qgis::LabelQuadrantPosition::Right:
+            case Qgis::LabelQuadrantPosition::BelowRight:
               labelAlignment = QStringLiteral( "left" );
               break;
           }
@@ -237,8 +245,8 @@ class ExtractLabelSink : public QgsLabelSink
       }
 
       const double labelRotation = !qgsDoubleNear( label->getAlpha(), 0.0 )
-                                   ? -( label->getAlpha() * 180 / M_PI ) + 360
-                                   : 0.0;
+                                     ? -( label->getAlpha() * 180 / M_PI ) + 360
+                                     : 0.0;
 
       const QFont font = labelFeature->definedFont();
       const QString fontFamily = font.family();
@@ -251,21 +259,21 @@ class ExtractLabelSink : public QgsLabelSink
       const double fontWordSpacing = font.wordSpacing();
 
       QgsTextFormat format = labelSettings.format();
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::Size ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::Size ) )
       {
-        format.setSize( dataDefinedValues.value( QgsPalLayerSettings::Size ).toDouble() );
+        format.setSize( dataDefinedValues.value( QgsPalLayerSettings::Property::Size ).toDouble() );
       }
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::Color ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::Color ) )
       {
-        format.setColor( dataDefinedValues.value( QgsPalLayerSettings::Color ).value<QColor>() );
+        format.setColor( dataDefinedValues.value( QgsPalLayerSettings::Property::Color ).value<QColor>() );
       }
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::FontOpacity ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::FontOpacity ) )
       {
-        format.setOpacity( dataDefinedValues.value( QgsPalLayerSettings::FontOpacity ).toDouble() / 100.0 );
+        format.setOpacity( dataDefinedValues.value( QgsPalLayerSettings::Property::FontOpacity ).toDouble() / 100.0 );
       }
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::MultiLineHeight ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::MultiLineHeight ) )
       {
-        format.setLineHeight( dataDefinedValues.value( QgsPalLayerSettings::MultiLineHeight ).toDouble() );
+        format.setLineHeight( dataDefinedValues.value( QgsPalLayerSettings::Property::MultiLineHeight ).toDouble() );
       }
 
       const QString formatColor = format.color().name();
@@ -273,9 +281,9 @@ class ExtractLabelSink : public QgsLabelSink
       const double formatLineHeight = format.lineHeight();
 
       QgsTextBufferSettings buffer = format.buffer();
-      if ( dataDefinedValues.contains( QgsPalLayerSettings::BufferDraw ) )
+      if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::BufferDraw ) )
       {
-        buffer.setEnabled( dataDefinedValues.value( QgsPalLayerSettings::BufferDraw ).toBool() );
+        buffer.setEnabled( dataDefinedValues.value( QgsPalLayerSettings::Property::BufferDraw ).toBool() );
       }
       const bool bufferDraw = buffer.enabled();
       double bufferSize = 0.0;
@@ -283,22 +291,22 @@ class ExtractLabelSink : public QgsLabelSink
       double bufferOpacity = 0.0;
       if ( bufferDraw )
       {
-        if ( dataDefinedValues.contains( QgsPalLayerSettings::BufferSize ) )
+        if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::BufferSize ) )
         {
-          buffer.setSize( dataDefinedValues.value( QgsPalLayerSettings::BufferSize ).toDouble() );
+          buffer.setSize( dataDefinedValues.value( QgsPalLayerSettings::Property::BufferSize ).toDouble() );
         }
-        if ( dataDefinedValues.contains( QgsPalLayerSettings::BufferColor ) )
+        if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::BufferColor ) )
         {
-          buffer.setColor( dataDefinedValues.value( QgsPalLayerSettings::BufferColor ).value<QColor>() );
+          buffer.setColor( dataDefinedValues.value( QgsPalLayerSettings::Property::BufferColor ).value<QColor>() );
         }
-        if ( dataDefinedValues.contains( QgsPalLayerSettings::BufferOpacity ) )
+        if ( dataDefinedValues.contains( QgsPalLayerSettings::Property::BufferOpacity ) )
         {
-          buffer.setOpacity( dataDefinedValues.value( QgsPalLayerSettings::BufferOpacity ).toDouble() / 100.0 );
+          buffer.setOpacity( dataDefinedValues.value( QgsPalLayerSettings::Property::BufferOpacity ).toDouble() / 100.0 );
         }
 
-        bufferSize =  buffer.sizeUnit() == QgsUnitTypes::RenderPercentage
-                      ? context.convertToPainterUnits( format.size(), format.sizeUnit(), format.sizeMapUnitScale() ) * buffer.size() / 100
-                      : context.convertToPainterUnits( buffer.size(), buffer.sizeUnit(), buffer.sizeMapUnitScale() );
+        bufferSize = buffer.sizeUnit() == Qgis::RenderUnit::Percentage
+                       ? context.convertToPainterUnits( format.size(), format.sizeUnit(), format.sizeMapUnitScale() ) * buffer.size() / 100
+                       : context.convertToPainterUnits( buffer.size(), buffer.sizeUnit(), buffer.sizeMapUnitScale() );
         bufferSize = bufferSize * 72 / context.painter()->device()->logicalDpiX();
         bufferColor = buffer.color().name();
         bufferOpacity = buffer.opacity() * 100;
@@ -324,7 +332,6 @@ class ExtractLabelSink : public QgsLabelSink
     QList<QgsFeature> features;
 
   private:
-
     QMap<QString, QString> mMapLayerNames;
     QList<QString> mCurvedWarningPushed;
 
@@ -351,32 +358,32 @@ QVariantMap QgsExtractLabelsAlgorithm::processAlgorithm( const QVariantMap &para
   const QSize imageSize = calculator.calculateImageSize( extent, scale ).toSize();
 
   QgsFields fields;
-  fields.append( QgsField( QStringLiteral( "Layer" ), QVariant::String, QString(), 0, 0 ) );
-  fields.append( QgsField( QStringLiteral( "FeatureID" ), QVariant::LongLong, QString(), 20 ) );
-  fields.append( QgsField( QStringLiteral( "LabelText" ), QVariant::String, QString(), 0, 0 ) );
-  fields.append( QgsField( QStringLiteral( "LabelWidth" ), QVariant::Double, QString(), 20, 8 ) );
-  fields.append( QgsField( QStringLiteral( "LabelHeight" ), QVariant::Double, QString(), 20, 8 ) );
-  fields.append( QgsField( QStringLiteral( "LabelRotation" ), QVariant::Double, QString(), 20, 2 ) );
-  fields.append( QgsField( QStringLiteral( "LabelUnplaced" ), QVariant::Bool, QString(), 1, 0 ) );
-  fields.append( QgsField( QStringLiteral( "Family" ), QVariant::String, QString(), 0, 0 ) );
-  fields.append( QgsField( QStringLiteral( "Size" ), QVariant::Double, QString(), 20, 4 ) );
-  fields.append( QgsField( QStringLiteral( "Italic" ), QVariant::Bool, QString(), 1, 0 ) );
-  fields.append( QgsField( QStringLiteral( "Bold" ), QVariant::Bool, QString(), 1, 0 ) );
-  fields.append( QgsField( QStringLiteral( "Underline" ), QVariant::Bool, QString(), 1, 0 ) );
-  fields.append( QgsField( QStringLiteral( "FontStyle" ), QVariant::String, QString(), 0, 0 ) );
-  fields.append( QgsField( QStringLiteral( "FontLetterSpacing" ), QVariant::Double, QString(), 20, 4 ) );
-  fields.append( QgsField( QStringLiteral( "FontWordSpacing" ), QVariant::Double, QString(), 20, 4 ) );
-  fields.append( QgsField( QStringLiteral( "MultiLineAlignment" ), QVariant::String, QString(), 0, 0 ) );
-  fields.append( QgsField( QStringLiteral( "MultiLineHeight" ), QVariant::Double, QString(), 20, 2 ) );
-  fields.append( QgsField( QStringLiteral( "Color" ), QVariant::String, QString(), 7, 0 ) );
-  fields.append( QgsField( QStringLiteral( "FontOpacity" ), QVariant::Double, QString(), 20, 1 ) );
-  fields.append( QgsField( QStringLiteral( "BufferDraw" ), QVariant::Bool, QString(), 1, 0 ) );
-  fields.append( QgsField( QStringLiteral( "BufferSize" ), QVariant::Double, QString(), 20, 4 ) );
-  fields.append( QgsField( QStringLiteral( "BufferColor" ), QVariant::String, QString(), 7, 0 ) );
-  fields.append( QgsField( QStringLiteral( "BufferOpacity" ), QVariant::Double, QString(), 20, 1 ) );
+  fields.append( QgsField( QStringLiteral( "Layer" ), QMetaType::Type::QString, QString(), 0, 0 ) );
+  fields.append( QgsField( QStringLiteral( "FeatureID" ), QMetaType::Type::LongLong, QString(), 20 ) );
+  fields.append( QgsField( QStringLiteral( "LabelText" ), QMetaType::Type::QString, QString(), 0, 0 ) );
+  fields.append( QgsField( QStringLiteral( "LabelWidth" ), QMetaType::Type::Double, QString(), 20, 8 ) );
+  fields.append( QgsField( QStringLiteral( "LabelHeight" ), QMetaType::Type::Double, QString(), 20, 8 ) );
+  fields.append( QgsField( QStringLiteral( "LabelRotation" ), QMetaType::Type::Double, QString(), 20, 2 ) );
+  fields.append( QgsField( QStringLiteral( "LabelUnplaced" ), QMetaType::Type::Bool, QString(), 1, 0 ) );
+  fields.append( QgsField( QStringLiteral( "Family" ), QMetaType::Type::QString, QString(), 0, 0 ) );
+  fields.append( QgsField( QStringLiteral( "Size" ), QMetaType::Type::Double, QString(), 20, 4 ) );
+  fields.append( QgsField( QStringLiteral( "Italic" ), QMetaType::Type::Bool, QString(), 1, 0 ) );
+  fields.append( QgsField( QStringLiteral( "Bold" ), QMetaType::Type::Bool, QString(), 1, 0 ) );
+  fields.append( QgsField( QStringLiteral( "Underline" ), QMetaType::Type::Bool, QString(), 1, 0 ) );
+  fields.append( QgsField( QStringLiteral( "FontStyle" ), QMetaType::Type::QString, QString(), 0, 0 ) );
+  fields.append( QgsField( QStringLiteral( "FontLetterSpacing" ), QMetaType::Type::Double, QString(), 20, 4 ) );
+  fields.append( QgsField( QStringLiteral( "FontWordSpacing" ), QMetaType::Type::Double, QString(), 20, 4 ) );
+  fields.append( QgsField( QStringLiteral( "MultiLineAlignment" ), QMetaType::Type::QString, QString(), 0, 0 ) );
+  fields.append( QgsField( QStringLiteral( "MultiLineHeight" ), QMetaType::Type::Double, QString(), 20, 2 ) );
+  fields.append( QgsField( QStringLiteral( "Color" ), QMetaType::Type::QString, QString(), 7, 0 ) );
+  fields.append( QgsField( QStringLiteral( "FontOpacity" ), QMetaType::Type::Double, QString(), 20, 1 ) );
+  fields.append( QgsField( QStringLiteral( "BufferDraw" ), QMetaType::Type::Bool, QString(), 1, 0 ) );
+  fields.append( QgsField( QStringLiteral( "BufferSize" ), QMetaType::Type::Double, QString(), 20, 4 ) );
+  fields.append( QgsField( QStringLiteral( "BufferColor" ), QMetaType::Type::QString, QString(), 7, 0 ) );
+  fields.append( QgsField( QStringLiteral( "BufferOpacity" ), QMetaType::Type::Double, QString(), 20, 1 ) );
 
   QString dest;
-  std::unique_ptr< QgsFeatureSink > sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, fields, QgsWkbTypes::Point, mCrs, QgsFeatureSink::RegeneratePrimaryKey ) );
+  std::unique_ptr<QgsFeatureSink> sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, fields, Qgis::WkbType::Point, mCrs, QgsFeatureSink::RegeneratePrimaryKey ) );
   if ( !sink )
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT" ) ) );
 
@@ -401,7 +408,7 @@ QVariantMap QgsExtractLabelsAlgorithm::processAlgorithm( const QVariantMap &para
 
   QgsNullPaintDevice nullPaintDevice;
   nullPaintDevice.setOutputSize( imageSize );
-  nullPaintDevice.setOutputDpi( static_cast< int >( std::round( dpi ) ) );
+  nullPaintDevice.setOutputDpi( static_cast<int>( std::round( dpi ) ) );
   QPainter painter( &nullPaintDevice );
 
   QgsMapRendererCustomPainterJob renderJob( mapSettings, &painter );
@@ -417,67 +424,56 @@ QVariantMap QgsExtractLabelsAlgorithm::processAlgorithm( const QVariantMap &para
   QObject::connect( feedback, &QgsFeedback::canceled, &renderJob, &QgsMapRendererCustomPainterJob::cancel );
   QObject::connect( &renderJob, &QgsMapRendererJob::renderingLayersFinished, feedback, [feedback]() { feedback->pushInfo( QObject::tr( "Calculating label placement" ) ); } );
   int labelsCollectedFromLayers = 0;
-  QObject::connect( &renderJob, &QgsMapRendererJob::layerRenderingStarted, feedback, [this, &multiStepFeedback, &labelsCollectedFromLayers]( const QString & layerId )
-  {
+  QObject::connect( &renderJob, &QgsMapRendererJob::layerRenderingStarted, feedback, [this, &multiStepFeedback, &labelsCollectedFromLayers]( const QString &layerId ) {
     multiStepFeedback.pushInfo( QObject::tr( "Collecting labelled features from %1" ).arg( mMapLayerNames.value( layerId ) ) );
-    multiStepFeedback.setProgress( 100.0 * static_cast< double >( labelsCollectedFromLayers ) / mMapLayers.size() );
+    multiStepFeedback.setProgress( 100.0 * static_cast<double>( labelsCollectedFromLayers ) / mMapLayers.size() );
     labelsCollectedFromLayers++;
   } );
 
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::labelRegistrationAboutToBegin, &multiStepFeedback, [&multiStepFeedback]()
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::labelRegistrationAboutToBegin, &multiStepFeedback, [&multiStepFeedback]() {
     multiStepFeedback.setCurrentStep( 1 );
     multiStepFeedback.pushInfo( QObject::tr( "Registering labels" ) );
   } );
 
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::providerRegistrationAboutToBegin, &multiStepFeedback, [this, &multiStepFeedback]( QgsAbstractLabelProvider * provider )
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::providerRegistrationAboutToBegin, &multiStepFeedback, [this, &multiStepFeedback]( QgsAbstractLabelProvider *provider ) {
     multiStepFeedback.setCurrentStep( 2 );
     if ( !provider->layerId().isEmpty() )
     {
       multiStepFeedback.pushInfo( QObject::tr( "Adding labels from %1" ).arg( mMapLayerNames.value( provider->layerId() ) ) );
     }
   } );
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::candidateCreationAboutToBegin, &multiStepFeedback, [this, &multiStepFeedback]( QgsAbstractLabelProvider * provider )
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::candidateCreationAboutToBegin, &multiStepFeedback, [this, &multiStepFeedback]( QgsAbstractLabelProvider *provider ) {
     multiStepFeedback.setCurrentStep( 3 );
     if ( !provider->layerId().isEmpty() )
     {
       multiStepFeedback.pushInfo( QObject::tr( "Generating label placement candidates for %1" ).arg( mMapLayerNames.value( provider->layerId() ) ) );
     }
   } );
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::obstacleCostingAboutToBegin, &multiStepFeedback, [&multiStepFeedback]()
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::obstacleCostingAboutToBegin, &multiStepFeedback, [&multiStepFeedback]() {
     multiStepFeedback.setCurrentStep( 4 );
     multiStepFeedback.setProgressText( QObject::tr( "Calculating obstacle costs" ) );
   } );
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::calculatingConflictsAboutToBegin, &multiStepFeedback, [&multiStepFeedback]()
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::calculatingConflictsAboutToBegin, &multiStepFeedback, [&multiStepFeedback]() {
     multiStepFeedback.setCurrentStep( 5 );
     multiStepFeedback.setProgressText( QObject::tr( "Calculating label conflicts" ) );
   } );
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::finalizingCandidatesAboutToBegin, &multiStepFeedback, [&multiStepFeedback]()
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::finalizingCandidatesAboutToBegin, &multiStepFeedback, [&multiStepFeedback]() {
     multiStepFeedback.setCurrentStep( 6 );
     multiStepFeedback.setProgressText( QObject::tr( "Finalizing candidates" ) );
   } );
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::reductionAboutToBegin, &multiStepFeedback, [&multiStepFeedback]()
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::reductionAboutToBegin, &multiStepFeedback, [&multiStepFeedback]() {
     multiStepFeedback.setCurrentStep( 7 );
     multiStepFeedback.setProgressText( QObject::tr( "Reducing problem" ) );
   } );
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::solvingPlacementAboutToBegin, &multiStepFeedback, [&multiStepFeedback]()
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::solvingPlacementAboutToBegin, &multiStepFeedback, [&multiStepFeedback]() {
     multiStepFeedback.setCurrentStep( 8 );
     multiStepFeedback.setProgressText( QObject::tr( "Determining optimal label placements" ) );
   } );
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::solvingPlacementFinished, &multiStepFeedback, [&multiStepFeedback]()
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::solvingPlacementFinished, &multiStepFeedback, [&multiStepFeedback]() {
     multiStepFeedback.setProgressText( QObject::tr( "Labeling complete" ) );
   } );
 
-  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::progressChanged, &multiStepFeedback, [&multiStepFeedback]( double progress )
-  {
+  QObject::connect( renderJob.labelingEngineFeedback(), &QgsLabelingEngineFeedback::progressChanged, &multiStepFeedback, [&multiStepFeedback]( double progress ) {
     multiStepFeedback.setProgress( progress );
   } );
 
@@ -504,7 +500,7 @@ QVariantMap QgsExtractLabelsAlgorithm::processAlgorithm( const QVariantMap &para
   }
   sink.reset();
 
-  if ( QgsVectorLayer *vl = qobject_cast< QgsVectorLayer * >( QgsProcessingUtils::mapLayerFromString( dest, context ) ) )
+  if ( QgsVectorLayer *vl = qobject_cast<QgsVectorLayer *>( QgsProcessingUtils::mapLayerFromString( dest, context ) ) )
   {
     vl->setRenderer( new QgsNullSymbolRenderer() );
     if ( vl->renderer() )
@@ -517,38 +513,38 @@ QVariantMap QgsExtractLabelsAlgorithm::processAlgorithm( const QVariantMap &para
       settings.fieldName = QStringLiteral( "LabelText" );
       settings.obstacleSettings().setIsObstacle( false );
       settings.placement = Qgis::LabelPlacement::OverPoint;
-      settings.quadOffset = Qgis::LabelQuadrantPosition::AboveRight;
+      settings.pointSettings().setQuadrant( Qgis::LabelQuadrantPosition::AboveRight );
       settings.placementSettings().setAllowDegradedPlacement( true );
       settings.placementSettings().setOverlapHandling( Qgis::LabelOverlapHandling::AllowOverlapIfRequired );
 
       QgsTextFormat textFormat;
       textFormat.setSize( 9 );
-      textFormat.setSizeUnit( QgsUnitTypes::RenderPoints );
+      textFormat.setSizeUnit( Qgis::RenderUnit::Points );
       textFormat.setColor( QColor( 0, 0, 0 ) );
 
       QgsTextBufferSettings buffer = textFormat.buffer();
-      buffer.setSizeUnit( QgsUnitTypes::RenderPoints );
+      buffer.setSizeUnit( Qgis::RenderUnit::Points );
 
       textFormat.setBuffer( buffer );
       settings.setFormat( textFormat );
 
-      settingsProperties.setProperty( QgsPalLayerSettings::Color, QgsProperty::fromExpression( QStringLiteral( "if(\"LabelUnplaced\",'255,0,0',\"Color\")" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::FontOpacity, QgsProperty::fromField( QStringLiteral( "FontOpacity" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::Family, QgsProperty::fromField( QStringLiteral( "Family" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::Italic, QgsProperty::fromField( QStringLiteral( "Italic" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::Bold, QgsProperty::fromField( QStringLiteral( "Bold" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::Underline, QgsProperty::fromField( QStringLiteral( "Underline" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::Size, QgsProperty::fromField( QStringLiteral( "Size" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::FontLetterSpacing, QgsProperty::fromField( QStringLiteral( "FontLetterSpacing" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::FontWordSpacing, QgsProperty::fromField( QStringLiteral( "FontWordSpacing" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::MultiLineAlignment, QgsProperty::fromField( QStringLiteral( "MultiLineAlignment" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::MultiLineHeight, QgsProperty::fromField( QStringLiteral( "MultiLineHeight" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::LabelRotation, QgsProperty::fromField( QStringLiteral( "LabelRotation" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::BufferDraw, QgsProperty::fromField( QStringLiteral( "BufferDraw" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::BufferSize, QgsProperty::fromField( QStringLiteral( "BufferSize" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::BufferColor, QgsProperty::fromField( QStringLiteral( "BufferColor" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::BufferOpacity, QgsProperty::fromField( QStringLiteral( "BufferOpacity" ) ) );
-      settingsProperties.setProperty( QgsPalLayerSettings::Show, QgsProperty::fromExpression( QStringLiteral( "\"LabelUnplaced\"=false" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::Color, QgsProperty::fromExpression( QStringLiteral( "if(\"LabelUnplaced\",'255,0,0',\"Color\")" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::FontOpacity, QgsProperty::fromField( QStringLiteral( "FontOpacity" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::Family, QgsProperty::fromField( QStringLiteral( "Family" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::Italic, QgsProperty::fromField( QStringLiteral( "Italic" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::Bold, QgsProperty::fromField( QStringLiteral( "Bold" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::Underline, QgsProperty::fromField( QStringLiteral( "Underline" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::Size, QgsProperty::fromField( QStringLiteral( "Size" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::FontLetterSpacing, QgsProperty::fromField( QStringLiteral( "FontLetterSpacing" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::FontWordSpacing, QgsProperty::fromField( QStringLiteral( "FontWordSpacing" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::MultiLineAlignment, QgsProperty::fromField( QStringLiteral( "MultiLineAlignment" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::MultiLineHeight, QgsProperty::fromField( QStringLiteral( "MultiLineHeight" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::LabelRotation, QgsProperty::fromField( QStringLiteral( "LabelRotation" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::BufferDraw, QgsProperty::fromField( QStringLiteral( "BufferDraw" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::BufferSize, QgsProperty::fromField( QStringLiteral( "BufferSize" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::BufferColor, QgsProperty::fromField( QStringLiteral( "BufferColor" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::BufferOpacity, QgsProperty::fromField( QStringLiteral( "BufferOpacity" ) ) );
+      settingsProperties.setProperty( QgsPalLayerSettings::Property::Show, QgsProperty::fromExpression( QStringLiteral( "\"LabelUnplaced\"=false" ) ) );
       settings.setDataDefinedProperties( settingsProperties );
 
       QgsAbstractVectorLayerLabeling *labeling = new QgsVectorLayerSimpleLabeling( settings );
@@ -556,7 +552,7 @@ QVariantMap QgsExtractLabelsAlgorithm::processAlgorithm( const QVariantMap &para
       vl->setLabelsEnabled( true );
 
       QString errorMessage;
-      vl->saveStyleToDatabase( QString(), QString(), true, QString(), errorMessage );
+      vl->saveStyleToDatabaseV2( QString(), QString(), true, QString(), errorMessage );
     }
   }
 
@@ -576,10 +572,10 @@ bool QgsExtractLabelsAlgorithm::prepareAlgorithm( const QVariantMap &parameters,
     for ( const QgsMapLayer *l : constLayers )
     {
       // only copy vector layers as other layer types aren't actors in the labeling process
-      if ( l->type() == QgsMapLayerType::VectorLayer )
+      if ( l->type() == Qgis::LayerType::Vector )
         mMapLayers.push_back( l->clone() );
     }
-    mMapThemeStyleOverrides = context.project()->mapThemeCollection( )->mapThemeStyleOverrides( mapTheme );
+    mMapThemeStyleOverrides = context.project()->mapThemeCollection()->mapThemeStyleOverrides( mapTheme );
   }
 
   if ( mMapLayers.isEmpty() )
@@ -597,7 +593,7 @@ bool QgsExtractLabelsAlgorithm::prepareAlgorithm( const QVariantMap &parameters,
 
     for ( const QgsMapLayer *l : std::as_const( layers ) )
     {
-      if ( l->type() == QgsMapLayerType::VectorLayer )
+      if ( l->type() == Qgis::LayerType::Vector )
         mMapLayers.push_back( l->clone() );
     }
   }
@@ -613,8 +609,8 @@ bool QgsExtractLabelsAlgorithm::prepareAlgorithm( const QVariantMap &parameters,
 
   bool includeUnplaced = parameterAsBoolean( parameters, QStringLiteral( "INCLUDE_UNPLACED" ), context );
   mLabelSettings = context.project()->labelingEngineSettings();
-  mLabelSettings.setFlag( QgsLabelingEngineSettings::DrawUnplacedLabels, includeUnplaced );
-  mLabelSettings.setFlag( QgsLabelingEngineSettings::CollectUnplacedLabels, includeUnplaced );
+  mLabelSettings.setFlag( Qgis::LabelingFlag::DrawUnplacedLabels, includeUnplaced );
+  mLabelSettings.setFlag( Qgis::LabelingFlag::CollectUnplacedLabels, includeUnplaced );
 
   return true;
 }
