@@ -30,12 +30,10 @@
  */
 class QgsLayoutMapExtentToLayerAlgorithm : public QgsProcessingAlgorithm
 {
-
   public:
-
     QgsLayoutMapExtentToLayerAlgorithm() = default;
     void initAlgorithm( const QVariantMap &configuration = QVariantMap() ) override;
-    Flags flags() const override;
+    Qgis::ProcessingAlgorithmFlags flags() const override;
     QString name() const override;
     QString displayName() const override;
     QStringList tags() const override;
@@ -46,10 +44,8 @@ class QgsLayoutMapExtentToLayerAlgorithm : public QgsProcessingAlgorithm
     QgsLayoutMapExtentToLayerAlgorithm *createInstance() const override SIP_FACTORY;
 
   protected:
-    bool prepareAlgorithm( const QVariantMap &parameters,
-                           QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-    QVariantMap processAlgorithm( const QVariantMap &parameters,
-                                  QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
+    bool prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
+    QVariantMap processAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
 
   private:
     QgsFeatureList mFeatures;
@@ -58,11 +54,8 @@ class QgsLayoutMapExtentToLayerAlgorithm : public QgsProcessingAlgorithm
     double mScale = 0;
     double mRotation = 0;
     QgsCoordinateReferenceSystem mCrs;
-
 };
 
 ///@endcond PRIVATE
 
 #endif // QGSALGORITHMEXTRACTLAYOUTMAPEXTENT_H
-
-
