@@ -62,36 +62,26 @@ QString QgsPointsToPathsAlgorithm::groupId() const
 
 void QgsPointsToPathsAlgorithm::initAlgorithm( const QVariantMap & )
 {
-  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INPUT" ),
-                QObject::tr( "Input layer" ), QList< int >() << QgsProcessing::TypeVectorPoint ) );
-  addParameter( new QgsProcessingParameterBoolean( QStringLiteral( "CLOSE_PATH" ),
-                QObject::tr( "Create closed paths" ), false, true ) );
-  addParameter( new QgsProcessingParameterExpression( QStringLiteral( "ORDER_EXPRESSION" ),
-                QObject::tr( "Order expression" ), QVariant(), QStringLiteral( "INPUT" ), true ) );
-  addParameter( new QgsProcessingParameterBoolean( QStringLiteral( "NATURAL_SORT" ),
-                QObject::tr( "Sort text containing numbers naturally" ), false, true ) );
-  addParameter( new QgsProcessingParameterExpression( QStringLiteral( "GROUP_EXPRESSION" ),
-                QObject::tr( "Path group expression" ), QVariant(), QStringLiteral( "INPUT" ), true ) );
-  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT" ),
-                QObject::tr( "Paths" ), QgsProcessing::TypeVectorLine ) );
+  addParameter( new QgsProcessingParameterFeatureSource( QStringLiteral( "INPUT" ), QObject::tr( "Input layer" ), QList<int>() << static_cast<int>( Qgis::ProcessingSourceType::VectorPoint ) ) );
+  addParameter( new QgsProcessingParameterBoolean( QStringLiteral( "CLOSE_PATH" ), QObject::tr( "Create closed paths" ), false, true ) );
+  addParameter( new QgsProcessingParameterExpression( QStringLiteral( "ORDER_EXPRESSION" ), QObject::tr( "Order expression" ), QVariant(), QStringLiteral( "INPUT" ), true ) );
+  addParameter( new QgsProcessingParameterBoolean( QStringLiteral( "NATURAL_SORT" ), QObject::tr( "Sort text containing numbers naturally" ), false, true ) );
+  addParameter( new QgsProcessingParameterExpression( QStringLiteral( "GROUP_EXPRESSION" ), QObject::tr( "Path group expression" ), QVariant(), QStringLiteral( "INPUT" ), true ) );
+  addParameter( new QgsProcessingParameterFeatureSink( QStringLiteral( "OUTPUT" ), QObject::tr( "Paths" ), Qgis::ProcessingSourceType::VectorLine ) );
   // TODO QGIS 4: remove parameter. move logic to separate algorithm if needed.
-  addParameter( new QgsProcessingParameterFolderDestination( QStringLiteral( "OUTPUT_TEXT_DIR" ),
-                QObject::tr( "Directory for text output" ), QVariant(), true, false ) );
+  addParameter( new QgsProcessingParameterFolderDestination( QStringLiteral( "OUTPUT_TEXT_DIR" ), QObject::tr( "Directory for text output" ), QVariant(), true, false ) );
   addOutput( new QgsProcessingOutputNumber( QStringLiteral( "NUM_PATHS" ), QObject::tr( "Number of paths" ) ) );
 
   // backwards compatibility parameters
   // TODO QGIS 4: remove compatibility parameters and their logic
-  QgsProcessingParameterField *orderField = new QgsProcessingParameterField( QStringLiteral( "ORDER_FIELD" ),
-      QObject::tr( "Order field" ), QVariant(), QString(), QgsProcessingParameterField::Any, false, true );
-  orderField->setFlags( orderField->flags() | QgsProcessingParameterDefinition::FlagHidden );
+  QgsProcessingParameterField *orderField = new QgsProcessingParameterField( QStringLiteral( "ORDER_FIELD" ), QObject::tr( "Order field" ), QVariant(), QString(), Qgis::ProcessingFieldParameterDataType::Any, false, true );
+  orderField->setFlags( orderField->flags() | Qgis::ProcessingParameterFlag::Hidden );
   addParameter( orderField );
-  QgsProcessingParameterField *groupField = new QgsProcessingParameterField( QStringLiteral( "GROUP_FIELD" ),
-      QObject::tr( "Group field" ), QVariant(), QStringLiteral( "INPUT" ), QgsProcessingParameterField::Any, false, true );
-  groupField->setFlags( orderField->flags() | QgsProcessingParameterDefinition::FlagHidden );
+  QgsProcessingParameterField *groupField = new QgsProcessingParameterField( QStringLiteral( "GROUP_FIELD" ), QObject::tr( "Group field" ), QVariant(), QStringLiteral( "INPUT" ), Qgis::ProcessingFieldParameterDataType::Any, false, true );
+  groupField->setFlags( orderField->flags() | Qgis::ProcessingParameterFlag::Hidden );
   addParameter( groupField );
-  QgsProcessingParameterString *dateFormat = new QgsProcessingParameterString( QStringLiteral( "DATE_FORMAT" ),
-      QObject::tr( "Date format (if order field is DateTime)" ), QVariant(), false, true );
-  dateFormat->setFlags( orderField->flags() | QgsProcessingParameterDefinition::FlagHidden );
+  QgsProcessingParameterString *dateFormat = new QgsProcessingParameterString( QStringLiteral( "DATE_FORMAT" ), QObject::tr( "Date format (if order field is DateTime)" ), QVariant(), false, true );
+  dateFormat->setFlags( orderField->flags() | Qgis::ProcessingParameterFlag::Hidden );
   addParameter( dateFormat );
 }
 
@@ -102,7 +92,7 @@ QgsPointsToPathsAlgorithm *QgsPointsToPathsAlgorithm::createInstance() const
 
 QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback )
 {
-  std::unique_ptr< QgsProcessingFeatureSource > source( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
+  std::unique_ptr<QgsProcessingFeatureSource> source( parameterAsSource( parameters, QStringLiteral( "INPUT" ), context ) );
   if ( !source )
     throw QgsProcessingException( invalidSourceError( parameters, QStringLiteral( "INPUT" ) ) );
 
@@ -110,42 +100,42 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
 
   QString orderExpressionString = parameterAsString( parameters, QStringLiteral( "ORDER_EXPRESSION" ), context );
   const QString orderFieldString = parameterAsString( parameters, QStringLiteral( "ORDER_FIELD" ), context );
-  if ( ! orderFieldString.isEmpty() )
+  if ( !orderFieldString.isEmpty() )
   {
     // this is a backwards compatibility parameter
     orderExpressionString = QgsExpression::quotedColumnRef( orderFieldString );
 
     QString dateFormat = parameterAsString( parameters, QStringLiteral( "DATE_FORMAT" ), context );
-    if ( ! dateFormat.isEmpty() )
+    if ( !dateFormat.isEmpty() )
     {
-      QVector< QPair< QString, QString > > codeMap;
-      codeMap << QPair< QString, QString >( "%%", "%" )
-              << QPair< QString, QString >( "%a", "ddd" )
-              << QPair< QString, QString >( "%A", "dddd" )
-              << QPair< QString, QString >( "%w", "" ) //day of the week 0-6
-              << QPair< QString, QString >( "%d", "dd" )
-              << QPair< QString, QString >( "%b", "MMM" )
-              << QPair< QString, QString >( "%B", "MMMM" )
-              << QPair< QString, QString >( "%m", "MM" )
-              << QPair< QString, QString >( "%y", "yy" )
-              << QPair< QString, QString >( "%Y", "yyyy" )
-              << QPair< QString, QString >( "%H", "hh" )
-              << QPair< QString, QString >( "%I", "hh" ) // 12 hour
-              << QPair< QString, QString >( "%p", "AP" )
-              << QPair< QString, QString >( "%M", "mm" )
-              << QPair< QString, QString >( "%S", "ss" )
-              << QPair< QString, QString >( "%f", "zzz" ) // milliseconds instead of microseconds
-              << QPair< QString, QString >( "%z", "" ) // utc offset
-              << QPair< QString, QString >( "%Z", "" ) // timezone name
-              << QPair< QString, QString >( "%j", "" ) // day of the year
-              << QPair< QString, QString >( "%U", "" ) // week number of the year sunday based
-              << QPair< QString, QString >( "%W", "" ) // week number of the year monday based
-              << QPair< QString, QString >( "%c", "" ) // full datetime
-              << QPair< QString, QString >( "%x", "" ) // full date
-              << QPair< QString, QString >( "%X", "" ) // full time
-              << QPair< QString, QString >( "%G", "yyyy" )
-              << QPair< QString, QString >( "%u", "" ) // day of the week 1-7
-              << QPair< QString, QString >( "%V", "" ); // week number
+      QVector<QPair<QString, QString>> codeMap;
+      codeMap << QPair<QString, QString>( "%%", "%" )
+              << QPair<QString, QString>( "%a", "ddd" )
+              << QPair<QString, QString>( "%A", "dddd" )
+              << QPair<QString, QString>( "%w", "" ) //day of the week 0-6
+              << QPair<QString, QString>( "%d", "dd" )
+              << QPair<QString, QString>( "%b", "MMM" )
+              << QPair<QString, QString>( "%B", "MMMM" )
+              << QPair<QString, QString>( "%m", "MM" )
+              << QPair<QString, QString>( "%y", "yy" )
+              << QPair<QString, QString>( "%Y", "yyyy" )
+              << QPair<QString, QString>( "%H", "hh" )
+              << QPair<QString, QString>( "%I", "hh" ) // 12 hour
+              << QPair<QString, QString>( "%p", "AP" )
+              << QPair<QString, QString>( "%M", "mm" )
+              << QPair<QString, QString>( "%S", "ss" )
+              << QPair<QString, QString>( "%f", "zzz" ) // milliseconds instead of microseconds
+              << QPair<QString, QString>( "%z", "" )    // utc offset
+              << QPair<QString, QString>( "%Z", "" )    // timezone name
+              << QPair<QString, QString>( "%j", "" )    // day of the year
+              << QPair<QString, QString>( "%U", "" )    // week number of the year sunday based
+              << QPair<QString, QString>( "%W", "" )    // week number of the year monday based
+              << QPair<QString, QString>( "%c", "" )    // full datetime
+              << QPair<QString, QString>( "%x", "" )    // full date
+              << QPair<QString, QString>( "%X", "" )    // full time
+              << QPair<QString, QString>( "%G", "yyyy" )
+              << QPair<QString, QString>( "%u", "" )  // day of the week 1-7
+              << QPair<QString, QString>( "%V", "" ); // week number
       for ( const auto &pair : codeMap )
       {
         dateFormat.replace( pair.first, pair.second );
@@ -166,7 +156,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
   QStringList requiredFields = QStringList( orderExpression.referencedColumns().values() );
   orderExpression.prepare( &expressionContext );
 
-  QVariant::Type orderFieldType = QVariant::String;
+  QMetaType::Type orderFieldType = QMetaType::Type::QString;
   if ( orderExpression.isField() )
   {
     const int orderFieldIndex = source->fields().indexFromName( orderExpression.referencedColumns().values().first() );
@@ -177,7 +167,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
   QString groupExpressionString = parameterAsString( parameters, QStringLiteral( "GROUP_EXPRESSION" ), context );
   // handle backwards compatibility parameter GROUP_FIELD
   const QString groupFieldString = parameterAsString( parameters, QStringLiteral( "GROUP_FIELD" ), context );
-  if ( ! groupFieldString.isEmpty() )
+  if ( !groupFieldString.isEmpty() )
     groupExpressionString = QgsExpression::quotedColumnRef( groupFieldString );
 
   QgsExpression groupExpression = groupExpressionString.isEmpty() ? QgsExpression( QString( "true" ) ) : QgsExpression( groupExpressionString );
@@ -185,7 +175,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
     throw QgsProcessingException( groupExpression.parserErrorString() );
 
   QgsFields outputFields = QgsFields();
-  if ( ! groupExpressionString.isEmpty() )
+  if ( !groupExpressionString.isEmpty() )
   {
     requiredFields.append( groupExpression.referencedColumns().values() );
     const QgsField field = groupExpression.isField() ? source->fields().field( requiredFields.last() ) : QStringLiteral( "group" );
@@ -205,24 +195,25 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
     wkbType = QgsWkbTypes::addZ( wkbType );
 
   QString dest;
-  std::unique_ptr< QgsFeatureSink > sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, outputFields, wkbType, source->sourceCrs() ) );
+  std::unique_ptr<QgsFeatureSink> sink( parameterAsSink( parameters, QStringLiteral( "OUTPUT" ), context, dest, outputFields, wkbType, source->sourceCrs() ) );
   if ( !sink )
     throw QgsProcessingException( invalidSinkError( parameters, QStringLiteral( "OUTPUT" ) ) );
 
   const QString textDir = parameterAsString( parameters, QStringLiteral( "OUTPUT_TEXT_DIR" ), context );
-  if ( ! textDir.isEmpty() &&
-       ! QDir( textDir ).exists() )
-    throw QgsProcessingException( QObject::tr( "The text output directory does not exist" ) );
+  if ( !textDir.isEmpty() && !QDir().mkpath( textDir ) )
+  {
+    throw QgsProcessingException( QObject::tr( "Failed to create the text output directory" ) );
+  }
 
   QgsDistanceArea da = QgsDistanceArea();
   da.setSourceCrs( source->sourceCrs(), context.transformContext() );
   da.setEllipsoid( context.ellipsoid() );
 
   // Store the points in a hash with the group identifier as the key
-  QHash< QVariant, QVector< QPair< QVariant, QgsPoint > > > allPoints;
+  QHash<QVariant, QVector<QPair<QVariant, QgsPoint>>> allPoints;
 
   const QgsFeatureRequest request = QgsFeatureRequest().setSubsetOfAttributes( requiredFields, source->fields() );
-  QgsFeatureIterator fit = source->getFeatures( request, QgsProcessingFeatureSource::FlagSkipGeometryValidityChecks );
+  QgsFeatureIterator fit = source->getFeatures( request, Qgis::ProcessingFeatureSourceFlag::SkipGeometryValidityChecks );
   QgsFeature f;
   const double totalPoints = source->featureCount() > 0 ? 100.0 / source->featureCount() : 0;
   long currentPoint = 0;
@@ -241,25 +232,25 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
       const QVariant orderValue = orderExpression.evaluate( &expressionContext );
       const QVariant groupValue = groupExpressionString.isEmpty() ? QVariant() : groupExpression.evaluate( &expressionContext );
 
-      if ( ! allPoints.contains( groupValue ) )
-        allPoints[ groupValue ] = QVector< QPair< QVariant, QgsPoint > >();
+      if ( !allPoints.contains( groupValue ) )
+        allPoints[groupValue] = QVector<QPair<QVariant, QgsPoint>>();
       const QgsAbstractGeometry *geom = f.geometry().constGet();
       if ( QgsWkbTypes::isMultiType( geom->wkbType() ) )
       {
-        const QgsMultiPoint mp( *qgsgeometry_cast< const QgsMultiPoint * >( geom ) );
+        const QgsMultiPoint mp( *qgsgeometry_cast<const QgsMultiPoint *>( geom ) );
         for ( auto pit = mp.const_parts_begin(); pit != mp.const_parts_end(); ++pit )
         {
-          if ( const QgsPoint *point = qgsgeometry_cast< const QgsPoint * >( *pit ) )
+          if ( const QgsPoint *point = qgsgeometry_cast<const QgsPoint *>( *pit ) )
           {
-            allPoints[ groupValue ] << qMakePair( orderValue, *point );
+            allPoints[groupValue] << qMakePair( orderValue, *point );
           }
         }
       }
       else
       {
-        if ( const QgsPoint *point = qgsgeometry_cast< const QgsPoint * >( geom ) )
+        if ( const QgsPoint *point = qgsgeometry_cast<const QgsPoint *>( geom ) )
         {
-          allPoints[ groupValue ] << qMakePair( orderValue, *point );
+          allPoints[groupValue] << qMakePair( orderValue, *point );
         }
       }
     }
@@ -268,7 +259,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
 
   int pathCount = 0;
   currentPoint = 0;
-  QHashIterator< QVariant, QVector< QPair< QVariant, QgsPoint > > > hit( allPoints );
+  QHashIterator<QVariant, QVector<QPair<QVariant, QgsPoint>>> hit( allPoints );
   feedback->setProgressText( QObject::tr( "Creating paths…" ) );
   while ( hit.hasNext() )
   {
@@ -277,25 +268,17 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
     {
       break;
     }
-    QVector< QPair< QVariant, QgsPoint > > pairs = hit.value();
+    QVector<QPair<QVariant, QgsPoint>> pairs = hit.value();
 
     if ( naturalSort )
     {
-      std::stable_sort( pairs.begin(),
-                        pairs.end(),
-                        [&collator]( const QPair< const QVariant, QgsPoint > &pair1,
-                                     const QPair< const QVariant, QgsPoint > &pair2 )
-      {
+      std::stable_sort( pairs.begin(), pairs.end(), [&collator]( const QPair<const QVariant, QgsPoint> &pair1, const QPair<const QVariant, QgsPoint> &pair2 ) {
         return collator.compare( pair1.first.toString(), pair2.first.toString() ) < 0;
       } );
     }
     else
     {
-      std::stable_sort( pairs.begin(),
-                        pairs.end(),
-                        []( const QPair< const QVariant, QgsPoint > &pair1,
-                            const QPair< const QVariant, QgsPoint > &pair2 )
-      {
+      std::stable_sort( pairs.begin(), pairs.end(), []( const QPair<const QVariant, QgsPoint> &pair1, const QPair<const QVariant, QgsPoint> &pair2 ) {
         return qgsVariantLessThan( pair1.first, pair2.first );
       } );
     }
@@ -322,7 +305,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
 
     QgsFeature outputFeature;
     QgsAttributes attrs;
-    if ( ! groupExpressionString.isEmpty() )
+    if ( !groupExpressionString.isEmpty() )
       attrs.append( hit.key() );
     attrs.append( pairs.first().first );
     attrs.append( pairs.last().first );
@@ -331,7 +314,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
     if ( !sink->addFeature( outputFeature, QgsFeatureSink::FastInsert ) )
       throw QgsProcessingException( writeFeatureError( sink.get(), parameters, QStringLiteral( "OUTPUT" ) ) );
 
-    if ( ! textDir.isEmpty() )
+    if ( !textDir.isEmpty() )
     {
       const QString filename = QDir( textDir ).filePath( hit.key().toString() + QString( ".txt" ) );
       QFile textFile( filename );
@@ -339,7 +322,7 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
         throw QgsProcessingException( QObject::tr( "Cannot open file for writing " ) + filename );
 
       QTextStream out( &textFile );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
       out.setCodec( "UTF-8" );
 #endif
       out << QString( "angle=Azimuth\n"
@@ -347,12 +330,22 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
                       "dist_units=Default\n"
                       "startAt=%1;%2;90\n"
                       "survey=Polygonal\n"
-                      "[data]\n" ).arg( pathPoints.at( 0 ).x() ).arg( pathPoints.at( 0 ).y() );
+                      "[data]\n" )
+               .arg( pathPoints.at( 0 ).x() )
+               .arg( pathPoints.at( 0 ).y() );
 
       for ( int i = 1; i < pathPoints.size(); ++i )
       {
         const double angle = pathPoints.at( i - 1 ).azimuth( pathPoints.at( i ) );
-        const double distance = da.measureLine( pathPoints.at( i - 1 ), pathPoints.at( i ) );
+        double distance = 0;
+        try
+        {
+          distance = da.measureLine( pathPoints.at( i - 1 ), pathPoints.at( i ) );
+        }
+        catch ( QgsCsException & )
+        {
+          throw QgsProcessingException( QObject::tr( "An error occurred while calculating length" ) );
+        }
         out << QString( "%1;%2;90\n" ).arg( angle ).arg( distance );
       }
     }
@@ -364,6 +357,10 @@ QVariantMap QgsPointsToPathsAlgorithm::processAlgorithm( const QVariantMap &para
   QVariantMap outputs;
   outputs.insert( QStringLiteral( "OUTPUT" ), dest );
   outputs.insert( QStringLiteral( "NUM_PATHS" ), pathCount );
+  if ( !textDir.isEmpty() )
+  {
+    outputs.insert( QStringLiteral( "OUTPUT_TEXT_DIR" ), textDir );
+  }
   return outputs;
 }
 
