@@ -31,9 +31,7 @@
  */
 class QgsRectanglesOvalsDiamondsAlgorithm : public QgsProcessingFeatureBasedAlgorithm
 {
-
   public:
-
     QgsRectanglesOvalsDiamondsAlgorithm() = default;
     QString name() const override;
     QString displayName() const override;
@@ -48,13 +46,12 @@ class QgsRectanglesOvalsDiamondsAlgorithm : public QgsProcessingFeatureBasedAlgo
     QgsRectanglesOvalsDiamondsAlgorithm *createInstance() const override SIP_FACTORY;
 
   protected:
-
     QString outputName() const override;
-    QgsProcessing::SourceType outputLayerType() const override;
+    Qgis::ProcessingSourceType outputLayerType() const override;
     Qgis::WkbType outputWkbType( Qgis::WkbType inputWkbType ) const override;
 
     bool prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-    QgsFeatureList processFeature( const QgsFeature &feature,  QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
+    QgsFeatureList processFeature( const QgsFeature &feature, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
 
   private:
     int mShape = 0;
@@ -76,5 +73,3 @@ class QgsRectanglesOvalsDiamondsAlgorithm : public QgsProcessingFeatureBasedAlgo
 ///@endcond PRIVATE
 
 #endif // QGSALGORITHMRECTANGLESOVALSDIAMONDS_H
-
-
