@@ -30,9 +30,7 @@
  */
 class QgsTranslateAlgorithm : public QgsProcessingFeatureBasedAlgorithm
 {
-
   public:
-
     QgsTranslateAlgorithm() = default;
     QString name() const override;
     QString displayName() const override;
@@ -47,11 +45,10 @@ class QgsTranslateAlgorithm : public QgsProcessingFeatureBasedAlgorithm
   protected:
     QString outputName() const override;
     bool prepareAlgorithm( const QVariantMap &parameters, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-    QgsFeatureList processFeature( const QgsFeature &feature,  QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
-    QgsWkbTypes::Type outputWkbType( QgsWkbTypes::Type inputWkbType ) const override;
+    QgsFeatureList processFeature( const QgsFeature &feature, QgsProcessingContext &context, QgsProcessingFeedback *feedback ) override;
+    Qgis::WkbType outputWkbType( Qgis::WkbType inputWkbType ) const override;
 
   private:
-
     double mDeltaX = 0.0;
     bool mDynamicDeltaX = false;
     QgsProperty mDeltaXProperty;
@@ -67,12 +64,9 @@ class QgsTranslateAlgorithm : public QgsProcessingFeatureBasedAlgorithm
     double mDeltaM = 0.0;
     bool mDynamicDeltaM = false;
     QgsProperty mDeltaMProperty;
-
 };
 
 
 ///@endcond PRIVATE
 
 #endif // QGSALGORITHMTRANSLATE_H
-
-
