@@ -20,11 +20,9 @@
 QgsTotalCurvatureFilter::QgsTotalCurvatureFilter( const QString &inputFile, const QString &outputFile, const QString &outputFormat )
   : QgsNineCellFilter( inputFile, outputFile, outputFormat )
 {
-
 }
 
-float QgsTotalCurvatureFilter::processNineCellWindow( float *x11, float *x21, float *x31, float *x12,
-    float *x22, float *x32, float *x13, float *x23, float *x33 )
+float QgsTotalCurvatureFilter::processNineCellWindow( float *x11, float *x21, float *x31, float *x12, float *x22, float *x32, float *x13, float *x23, float *x33 )
 {
   //return nodata if one value is the nodata value
   if ( *x11 == mInputNodataValue || *x21 == mInputNodataValue || *x31 == mInputNodataValue || *x12 == mInputNodataValue
