@@ -22,6 +22,7 @@
 
 #include "qgsgeorefvalidators.h"
 #include "qgsgeorefdelegates.h"
+#include "moc_qgsgeorefdelegates.cpp"
 #include <cmath>
 
 // ------------------------- QgsDmsAndDdDelegate --------------------------- //
@@ -30,8 +31,7 @@ QgsDmsAndDdDelegate::QgsDmsAndDdDelegate( QWidget *parent )
 {
 }
 
-QWidget *QgsDmsAndDdDelegate::createEditor( QWidget *parent, const QStyleOptionViewItem &/*option*/,
-    const QModelIndex &/*index*/ ) const
+QWidget *QgsDmsAndDdDelegate::createEditor( QWidget *parent, const QStyleOptionViewItem & /*option*/, const QModelIndex & /*index*/ ) const
 {
   QLineEdit *editor = new QLineEdit( parent );
   QgsDMSAndDDValidator *validator = new QgsDMSAndDDValidator( editor );
@@ -48,8 +48,7 @@ void QgsDmsAndDdDelegate::setEditorData( QWidget *editor, const QModelIndex &ind
   lineEdit->setText( value );
 }
 
-void QgsDmsAndDdDelegate::setModelData( QWidget *editor, QAbstractItemModel *model,
-                                        const QModelIndex &index ) const
+void QgsDmsAndDdDelegate::setModelData( QWidget *editor, QAbstractItemModel *model, const QModelIndex &index ) const
 {
   QLineEdit *lineEdit = static_cast<QLineEdit *>( editor );
   const QString stringValue = lineEdit->text();
@@ -62,8 +61,7 @@ void QgsDmsAndDdDelegate::setModelData( QWidget *editor, QAbstractItemModel *mod
   model->setData( index, value, Qt::EditRole );
 }
 
-void QgsDmsAndDdDelegate::updateEditorGeometry( QWidget *editor, const QStyleOptionViewItem &option,
-    const QModelIndex &/*index*/ ) const
+void QgsDmsAndDdDelegate::updateEditorGeometry( QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex & /*index*/ ) const
 {
   editor->setGeometry( option.rect );
 }
@@ -91,8 +89,7 @@ QgsCoordDelegate::QgsCoordDelegate( QWidget *parent )
 {
 }
 
-QWidget *QgsCoordDelegate::createEditor( QWidget *parent, const QStyleOptionViewItem &/*option*/,
-    const QModelIndex &/*index*/ ) const
+QWidget *QgsCoordDelegate::createEditor( QWidget *parent, const QStyleOptionViewItem & /*option*/, const QModelIndex & /*index*/ ) const
 {
   QLineEdit *editor = new QLineEdit( parent );
   const thread_local QRegularExpression re( QStringLiteral( "-?\\d*(\\.\\d+)?" ) );
