@@ -52,7 +52,6 @@ class QgsPluginManager : public QgsOptionsDialogBase, private Ui::QgsPluginManag
 {
     Q_OBJECT
   public:
-
     static inline QgsSettingsTreeNode *sTreePluginManager = QgsSettingsTree::treeRoot()->createChildNode( QStringLiteral( "plugin-manager" ) );
 
     static const QgsSettingsEntryBool *settingsAutomaticallyCheckForPluginUpdates;
@@ -151,13 +150,11 @@ class QgsPluginManager : public QgsOptionsDialogBase, private Ui::QgsPluginManag
 
     /**
      * Enable the Install button if selected path is valid
-     * \since QGIS 3.0
      */
     void mZipFileWidget_fileChanged( const QString &filePath );
 
     /**
      * Install plugin from ZIP file
-     * \since QGIS 3.0
      */
     void buttonInstallFromZip_clicked();
 
@@ -214,7 +211,7 @@ class QgsPluginManager : public QgsOptionsDialogBase, private Ui::QgsPluginManag
     void initTabDescriptions();
 
     //! Returns true if given plugin is enabled in QgsSettings
-    bool isPluginEnabled( QString key );
+    bool isPluginEnabled( const QString &key );
 
     //! Returns true if there are plugins available for download in the metadata registry
     bool hasAvailablePlugins();
@@ -248,7 +245,7 @@ class QgsPluginManager : public QgsOptionsDialogBase, private Ui::QgsPluginManag
 
     QMap<QString, QString> mTabDescriptions;
 
-    QMap< QString, QMap< QString, QString > > mPlugins;
+    QMap<QString, QMap<QString, QString>> mPlugins;
 
     QString mCurrentlyDisplayedPlugin;
 
