@@ -22,12 +22,12 @@
 
 class QgsVectorLayer;
 class QgsElevationShadingRendererSettingsWidget;
+class QgsProjectionSelectionWidget;
 
 class QgsProjectElevationSettingsWidget : public QgsOptionsPageWidget, private Ui::QgsProjectElevationSettingsWidgetBase
 {
     Q_OBJECT
   public:
-
     QgsProjectElevationSettingsWidget( QWidget *parent = nullptr );
 
   public slots:
@@ -36,11 +36,12 @@ class QgsProjectElevationSettingsWidget : public QgsOptionsPageWidget, private U
 
   private slots:
 
+    void updateVerticalCrsOptions();
     bool validate();
 
   private:
     QgsElevationShadingRendererSettingsWidget *mElevationShadingSettingsWidget = nullptr;
-
+    QgsProjectionSelectionWidget *mVerticalCrsWidget = nullptr;
 };
 
 
@@ -54,5 +55,4 @@ class QgsProjectElevationSettingsWidgetFactory : public QgsOptionsWidgetFactory
 };
 
 
-
 #endif // QGSPROJECTELEVATIONSETTINGSWIDGET_H
