@@ -19,6 +19,7 @@
 #include "qgisapp.h"
 #include "qgsapplication.h"
 #include "qgsbookmarks.h"
+#include "moc_qgsbookmarks.cpp"
 #include "qgsbookmarkeditordialog.h"
 #include "qgsmapcanvas.h"
 #include "qgsproject.h"
@@ -39,7 +40,7 @@
 #include <QToolButton>
 #include <QUrl>
 
-const int QgsDoubleSpinBoxBookmarksDelegate::DECIMAL_PLACES = 6;
+const int QgsDoubleSpinBoxBookmarksDelegate::DEFAULT_DECIMAL_PLACES = 6;
 
 QgsBookmarks::QgsBookmarks( QWidget *parent )
   : QgsDockWidget( parent )
@@ -49,9 +50,11 @@ QgsBookmarks::QgsBookmarks( QWidget *parent )
   QgsGui::enableAutoGeometryRestore( this );
 
   connect( lstBookmarks, &QTreeView::doubleClicked, this, &QgsBookmarks::lstBookmarks_doubleClicked );
+  lstBookmarks->setContextMenuPolicy( Qt::CustomContextMenu );
+  connect( lstBookmarks, &QTreeView::customContextMenuRequested, this, &QgsBookmarks::lstBookmarks_customContextMenuRequested );
 
   bookmarksDockContents->layout()->setContentsMargins( 0, 0, 0, 0 );
-  static_cast< QGridLayout * >( bookmarksDockContents->layout() )->setVerticalSpacing( 0 );
+  static_cast<QGridLayout *>( bookmarksDockContents->layout() )->setVerticalSpacing( 0 );
 
   QToolButton *btnImpExp = new QToolButton;
   btnImpExp->setAutoRaise( true );
@@ -60,17 +63,15 @@ QgsBookmarks::QgsBookmarks( QWidget *parent )
   btnImpExp->setPopupMode( QToolButton::InstantPopup );
 
   QMenu *share = new QMenu( this );
-  QAction *btnExport = share->addAction( tr( "&Export" ) );
-  QAction *btnImport = share->addAction( tr( "&Import" ) );
-  btnExport->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/mActionSharingExport.svg" ) ) );
-  btnImport->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/mActionSharingImport.svg" ) ) );
-  connect( btnExport, &QAction::triggered, this, &QgsBookmarks::exportToXml );
-  connect( btnImport, &QAction::triggered, this, &QgsBookmarks::importFromXml );
+  share->addAction( actionExport );
+  share->addAction( actionImport );
   btnImpExp->setMenu( share );
 
   connect( actionAdd, &QAction::triggered, this, &QgsBookmarks::addClicked );
   connect( actionDelete, &QAction::triggered, this, &QgsBookmarks::deleteClicked );
   connect( actionZoomTo, &QAction::triggered, this, &QgsBookmarks::zoomToBookmark );
+  connect( actionExport, &QAction::triggered, this, &QgsBookmarks::exportToXml );
+  connect( actionImport, &QAction::triggered, this, &QgsBookmarks::importFromXml );
 
   mBookmarkToolbar->addWidget( btnImpExp );
 
@@ -78,6 +79,7 @@ QgsBookmarks::QgsBookmarks( QWidget *parent )
 
   lstBookmarks->setModel( mBookmarkModel );
   lstBookmarks->setItemDelegate( new QgsDoubleSpinBoxBookmarksDelegate( this ) );
+  lstBookmarks->setItemDelegateForColumn( QgsBookmarkManagerModel::ColumnRotation, new QgsDoubleSpinBoxBookmarksDelegate( this, 1 ) );
   lstBookmarks->setSortingEnabled( true );
   lstBookmarks->sortByColumn( 0, Qt::AscendingOrder );
 
@@ -104,6 +106,7 @@ void QgsBookmarks::addClicked()
   QgsBookmark bookmark;
   bookmark.setName( tr( "New bookmark" ) );
   bookmark.setExtent( QgsReferencedRectangle( canvas->extent(), canvas->mapSettings().destinationCrs() ) );
+  bookmark.setRotation( canvas->rotation() );
   QgsBookmarkEditorDialog *dlg = new QgsBookmarkEditorDialog( bookmark, false, this, canvas );
   dlg->setAttribute( Qt::WA_DeleteOnClose );
   dlg->show();
@@ -123,9 +126,7 @@ void QgsBookmarks::deleteClicked()
     return;
 
   // make sure the user really wants to delete these bookmarks
-  if ( QMessageBox::No == QMessageBox::question( this, tr( "Delete Bookmarks" ),
-       tr( "Are you sure you want to delete %n bookmark(s)?", "number of rows", rows.size() ),
-       QMessageBox::Yes | QMessageBox::No ) )
+  if ( QMessageBox::No == QMessageBox::question( this, tr( "Delete Bookmarks" ), tr( "Are you sure you want to delete %n bookmark(s)?", "number of rows", rows.size() ), QMessageBox::Yes | QMessageBox::No ) )
     return;
 
   // Remove in reverse order to keep the merged model indexes
@@ -143,6 +144,50 @@ void QgsBookmarks::lstBookmarks_doubleClicked( const QModelIndex &index )
   zoomToBookmark();
 }
 
+void QgsBookmarks::lstBookmarks_customContextMenuRequested( QPoint pos )
+{
+  // Get index of item under mouse
+  QModelIndex index = lstBookmarks->indexAt( pos );
+  if ( !index.isValid() )
+  {
+    // No bookmark under mouse, display generic menu
+    QMenu menu;
+    menu.addAction( actionAdd );
+    menu.addSeparator();
+    menu.addAction( actionExport );
+    menu.addAction( actionImport );
+    menu.exec( lstBookmarks->mapToGlobal( pos ) );
+    return;
+  }
+
+  // Create the context menu
+  QMenu menu;
+
+  // Add zoom and delete actions
+  menu.addAction( actionZoomTo );
+  menu.addAction( actionDelete );
+
+  // Get the bookmark
+  const QString id = lstBookmarks->model()->data( index, static_cast<int>( QgsBookmarkManagerModel::CustomRole::Id ) ).toString();
+  QgsBookmark bookmark = QgsApplication::bookmarkManager()->bookmarkById( id );
+  bool inProject = false;
+  if ( bookmark.id().isEmpty() )
+  {
+    inProject = true;
+    bookmark = QgsProject::instance()->bookmarkManager()->bookmarkById( id );
+  }
+
+  // Add an edit action (similar to the one in QgsBookmarksItemGuiProvider)
+  QAction *actionEdit = new QAction( tr( "Edit Spatial Bookmark…" ), &menu );
+  connect( actionEdit, &QAction::triggered, this, [bookmark, inProject] {
+    QgsBookmarkEditorDialog *dlg = new QgsBookmarkEditorDialog( bookmark, inProject, QgisApp::instance(), QgisApp::instance()->mapCanvas() );
+    dlg->setAttribute( Qt::WA_DeleteOnClose );
+    dlg->show();
+  } );
+  menu.addAction( actionEdit );
+  menu.exec( lstBookmarks->viewport()->mapToGlobal( pos ) );
+}
+
 void QgsBookmarks::zoomToBookmark()
 {
   const QModelIndex index = lstBookmarks->currentIndex();
@@ -153,11 +198,12 @@ void QgsBookmarks::zoomToBookmark()
 
 void QgsBookmarks::zoomToBookmarkIndex( const QModelIndex &index )
 {
-  const QgsReferencedRectangle rect = index.data( QgsBookmarkManagerModel::RoleExtent ).value< QgsReferencedRectangle >();
+  const QgsReferencedRectangle rect = index.data( static_cast<int>( QgsBookmarkManagerModel::CustomRole::Extent ) ).value<QgsReferencedRectangle>();
   try
   {
     if ( QgisApp::instance()->mapCanvas()->setReferencedExtent( rect ) )
     {
+      QgisApp::instance()->mapCanvas()->setRotation( index.data( static_cast<int>( QgsBookmarkManagerModel::CustomRole::Rotation ) ).toDouble() );
       QgisApp::instance()->mapCanvas()->refresh();
     }
     else
@@ -176,8 +222,7 @@ void QgsBookmarks::importFromXml()
   const QgsSettings settings;
 
   const QString lastUsedDir = settings.value( QStringLiteral( "Windows/Bookmarks/LastUsedDirectory" ), QDir::homePath() ).toString();
-  const QString fileName = QFileDialog::getOpenFileName( this, tr( "Import Bookmarks" ), lastUsedDir,
-                           tr( "XML files (*.xml *.XML)" ) );
+  const QString fileName = QFileDialog::getOpenFileName( this, tr( "Import Bookmarks" ), lastUsedDir, tr( "XML files (*.xml *.XML)" ) );
   if ( fileName.isEmpty() )
   {
     return;
@@ -214,7 +259,6 @@ QMap<QString, QModelIndex> QgsBookmarks::getIndexMap()
   }
 
   return map;
-
 }
 
 void QgsBookmarks::exportToXml()
@@ -222,8 +266,7 @@ void QgsBookmarks::exportToXml()
   QgsSettings settings;
 
   const QString lastUsedDir = settings.value( QStringLiteral( "Windows/Bookmarks/LastUsedDirectory" ), QDir::homePath() ).toString();
-  QString fileName = QFileDialog::getSaveFileName( this, tr( "Export Bookmarks" ), lastUsedDir,
-                     tr( "XML files (*.xml *.XML)" ) );
+  QString fileName = QFileDialog::getSaveFileName( this, tr( "Export Bookmarks" ), lastUsedDir, tr( "XML files (*.xml *.XML)" ) );
   if ( fileName.isEmpty() )
   {
     return;
@@ -235,15 +278,13 @@ void QgsBookmarks::exportToXml()
     fileName += QLatin1String( ".xml" );
   }
 
-  if ( !QgsBookmarkManager::exportToFile( fileName, QList< const QgsBookmarkManager * >() << QgsApplication::bookmarkManager()
-                                          << QgsProject::instance()->bookmarkManager() ) )
+  if ( !QgsBookmarkManager::exportToFile( fileName, QList<const QgsBookmarkManager *>() << QgsApplication::bookmarkManager() << QgsProject::instance()->bookmarkManager() ) )
   {
     QgisApp::instance()->messageBar()->pushWarning( tr( "Export Bookmarks" ), tr( "Error exporting bookmark file" ) );
   }
   else
   {
-    QgisApp::instance()->messageBar()->pushSuccess( tr( "Export Bookmarks" ), tr( "Successfully exported bookmarks to <a href=\"%1\">%2</a>" )
-        .arg( QUrl::fromLocalFile( fileName ).toString(), QDir::toNativeSeparators( fileName ) ) );
+    QgisApp::instance()->messageBar()->pushSuccess( tr( "Export Bookmarks" ), tr( "Successfully exported bookmarks to <a href=\"%1\">%2</a>" ).arg( QUrl::fromLocalFile( fileName ).toString(), QDir::toNativeSeparators( fileName ) ) );
   }
 
   settings.setValue( QStringLiteral( "Windows/Bookmarks/LastUsedDirectory" ), QFileInfo( fileName ).path() );
@@ -253,22 +294,18 @@ void QgsBookmarks::exportToXml()
 // QgsDoubleSpinBoxBookmarksDelegate
 //
 
-QgsDoubleSpinBoxBookmarksDelegate::QgsDoubleSpinBoxBookmarksDelegate( QObject *parent )
-  : QStyledItemDelegate( parent )
+QgsDoubleSpinBoxBookmarksDelegate::QgsDoubleSpinBoxBookmarksDelegate( QObject *parent, int decimals )
+  : QStyledItemDelegate( parent ), mDecimals( decimals == -1 ? QgsDoubleSpinBoxBookmarksDelegate::DEFAULT_DECIMAL_PLACES : decimals )
 {
-
 }
 
 QString QgsDoubleSpinBoxBookmarksDelegate::displayText( const QVariant &value, const QLocale &locale ) const
 {
-  if ( value.userType() == QVariant::Double )
+  if ( value.userType() == QMetaType::Type::Double )
   {
-    return locale.toString( value.toDouble(), 'f', QgsDoubleSpinBoxBookmarksDelegate::DECIMAL_PLACES );
-  }
-  else
-  {
-    return QStyledItemDelegate::displayText( value, locale );
+    return locale.toString( value.toDouble(), 'f', mDecimals );
   }
+  return QStyledItemDelegate::displayText( value, locale );
 }
 
 QWidget *QgsDoubleSpinBoxBookmarksDelegate::createEditor( QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index ) const
@@ -276,6 +313,12 @@ QWidget *QgsDoubleSpinBoxBookmarksDelegate::createEditor( QWidget *parent, const
   QWidget *widget = QStyledItemDelegate::createEditor( parent, option, index );
   QDoubleSpinBox *spinbox = qobject_cast<QDoubleSpinBox *>( widget );
   if ( spinbox )
-    spinbox->setDecimals( QgsDoubleSpinBoxBookmarksDelegate::DECIMAL_PLACES );
+  {
+    if ( index.column() == QgsBookmarkManagerModel::ColumnRotation )
+    {
+      spinbox->setRange( -360, 360 );
+    }
+    spinbox->setDecimals( mDecimals );
+  }
   return widget;
 }
