@@ -20,6 +20,8 @@
 #include "qgsannotationitemnode.h"
 #include "qgsannotationitemeditoperation.h"
 #include "qgsrendercontext.h"
+#include "qgsapplication.h"
+#include "qgscalloutsregistry.h"
 
 QgsAnnotationPointTextItem::QgsAnnotationPointTextItem( const QString &text, QgsPointXY point )
   : QgsAnnotationItem()
@@ -32,7 +34,9 @@ QgsAnnotationPointTextItem::QgsAnnotationPointTextItem( const QString &text, Qgs
 Qgis::AnnotationItemFlags QgsAnnotationPointTextItem::flags() const
 {
   // in truth this should depend on whether the text format is scale dependent or not!
-  return Qgis::AnnotationItemFlag::ScaleDependentBoundingBox;
+  return Qgis::AnnotationItemFlag::ScaleDependentBoundingBox
+         | Qgis::AnnotationItemFlag::SupportsReferenceScale
+         | Qgis::AnnotationItemFlag::SupportsCallouts;
 }
 
 QgsAnnotationPointTextItem::~QgsAnnotationPointTextItem() = default;
@@ -42,7 +46,7 @@ QString QgsAnnotationPointTextItem::type() const
   return QStringLiteral( "pointtext" );
 }
 
-void QgsAnnotationPointTextItem::render( QgsRenderContext &context, QgsFeedback * )
+void QgsAnnotationPointTextItem::render( QgsRenderContext &context, QgsFeedback *feedback )
 {
   QPointF pt;
   if ( context.coordinateTransform().isValid() )
@@ -70,9 +74,21 @@ void QgsAnnotationPointTextItem::render( QgsRenderContext &context, QgsFeedback
   }
 
   const QString displayText = QgsExpression::replaceExpressionText( mText, &context.expressionContext(), &context.distanceArea() );
+
+  if ( callout() )
+  {
+    const double textWidth = QgsTextRenderer::textWidth(
+                               context, mTextFormat, displayText.split( '\n' ) );
+    const double textHeight = QgsTextRenderer::textHeight(
+                                context, mTextFormat, displayText.split( '\n' ) );
+
+    QgsCallout::QgsCalloutContext calloutContext;
+    renderCallout( context, QRectF( pt.x(), pt.y() - textHeight, textWidth, textHeight ), angle, calloutContext, feedback );
+  }
+
   QgsTextRenderer::drawText( pt, - angle * M_PI / 180.0,
                              QgsTextRenderer::convertQtHAlignment( mAlignment ),
-                             displayText.split( '\n' ), context, mTextFormat );
+                             mTextFormat.allowHtmlFormatting() ? QStringList{displayText }: displayText.split( '\n' ), context, mTextFormat );
 }
 
 bool QgsAnnotationPointTextItem::writeXml( QDomElement &element, QDomDocument &document, const QgsReadWriteContext &context ) const
@@ -118,7 +134,7 @@ bool QgsAnnotationPointTextItem::readXml( const QDomElement &element, const QgsR
   return true;
 }
 
-QgsAnnotationPointTextItem *QgsAnnotationPointTextItem::clone()
+QgsAnnotationPointTextItem *QgsAnnotationPointTextItem::clone() const
 {
   std::unique_ptr< QgsAnnotationPointTextItem > item = std::make_unique< QgsAnnotationPointTextItem >( mText, mPoint );
   item->setFormat( mTextFormat );
@@ -149,8 +165,8 @@ QgsRectangle QgsAnnotationPointTextItem::boundingBox( QgsRenderContext &context
 {
   const QString displayText = QgsExpression::replaceExpressionText( mText, &context.expressionContext(), &context.distanceArea() );
 
-  const double widthInPixels = QgsTextRenderer::textWidth( context, mTextFormat, displayText.split( '\n' ) );
-  const double heightInPixels = QgsTextRenderer::textHeight( context, mTextFormat, displayText.split( '\n' ) );
+  const double widthInPixels = QgsTextRenderer::textWidth( context, mTextFormat, mTextFormat.allowHtmlFormatting() ? QStringList{displayText }: displayText.split( '\n' ) );
+  const double heightInPixels = QgsTextRenderer::textHeight( context, mTextFormat, mTextFormat.allowHtmlFormatting() ? QStringList{displayText }: displayText.split( '\n' ) );
 
   // text size has already been calculated using any symbology reference scale factor above -- we need
   // to temporarily remove the reference scale here or we'll be undoing the scaling
@@ -185,29 +201,61 @@ QgsRectangle QgsAnnotationPointTextItem::boundingBox( QgsRenderContext &context
       break;
   }
 
+  QgsRectangle textRect;
   if ( !qgsDoubleNear( angle, 0 ) )
   {
-    return rotateBoundingBoxAroundPoint( mPoint.x(), mPoint.y(), unrotatedRect, angle );
+    textRect = rotateBoundingBoxAroundPoint( mPoint.x(), mPoint.y(), unrotatedRect, angle );
   }
   else
   {
-    return unrotatedRect;
+    textRect = unrotatedRect;
   }
+
+  if ( callout() && !calloutAnchor().isEmpty() )
+  {
+    QgsGeometry anchor = calloutAnchor();
+    textRect.combineExtentWith( anchor.boundingBox() );
+  }
+  return textRect;
 }
 
-QList<QgsAnnotationItemNode> QgsAnnotationPointTextItem::nodes() const
+QList<QgsAnnotationItemNode> QgsAnnotationPointTextItem::nodesV2( const QgsAnnotationItemEditContext &context ) const
 {
-  return { QgsAnnotationItemNode( QgsVertexId( 0, 0, 0 ), mPoint, Qgis::AnnotationItemNodeType::VertexHandle )};
+  QList<QgsAnnotationItemNode> res = { QgsAnnotationItemNode( QgsVertexId( 0, 0, 0 ), mPoint, Qgis::AnnotationItemNodeType::VertexHandle )};
+
+  QgsPointXY calloutNodePoint;
+  if ( !calloutAnchor().isEmpty() )
+  {
+    calloutNodePoint = calloutAnchor().asPoint();
+  }
+  else
+  {
+    calloutNodePoint = context.currentItemBounds().center();
+  }
+  res.append( QgsAnnotationItemNode( QgsVertexId( 0, 0, 1 ), calloutNodePoint, Qgis::AnnotationItemNodeType::CalloutHandle ) );
+
+  return res;
 }
 
-Qgis::AnnotationItemEditOperationResult QgsAnnotationPointTextItem::applyEdit( QgsAbstractAnnotationItemEditOperation *operation )
+Qgis::AnnotationItemEditOperationResult QgsAnnotationPointTextItem::applyEditV2( QgsAbstractAnnotationItemEditOperation *operation, const QgsAnnotationItemEditContext & )
 {
   switch ( operation->type() )
   {
     case QgsAbstractAnnotationItemEditOperation::Type::MoveNode:
     {
       QgsAnnotationItemEditOperationMoveNode *moveOperation = dynamic_cast< QgsAnnotationItemEditOperationMoveNode * >( operation );
-      mPoint = moveOperation->after();
+      if ( moveOperation->nodeId().vertex == 0 )
+      {
+        mPoint = moveOperation->after();
+      }
+      else if ( moveOperation->nodeId().vertex == 1 )
+      {
+        setCalloutAnchor( QgsGeometry::fromPoint( moveOperation->after() ) );
+        if ( !callout() )
+        {
+          setCallout( QgsApplication::calloutRegistry()->defaultCallout() );
+        }
+      }
       return Qgis::AnnotationItemEditOperationResult::Success;
     }
 
@@ -231,7 +279,7 @@ Qgis::AnnotationItemEditOperationResult QgsAnnotationPointTextItem::applyEdit( Q
   return Qgis::AnnotationItemEditOperationResult::Invalid;
 }
 
-QgsAnnotationItemEditOperationTransientResults *QgsAnnotationPointTextItem::transientEditResults( QgsAbstractAnnotationItemEditOperation *operation )
+QgsAnnotationItemEditOperationTransientResults *QgsAnnotationPointTextItem::transientEditResultsV2( QgsAbstractAnnotationItemEditOperation *operation, const QgsAnnotationItemEditContext & )
 {
   switch ( operation->type() )
   {
