@@ -18,8 +18,11 @@
 #define QGSAUTHCONFIG_H
 
 #include "qgis_core.h"
+
 #include <QHash>
 #include <QString>
+#include <QDomElement>
+#include <QDomDocument>
 
 #ifndef QT_NO_SSL
 #include <QSslCertificate>
@@ -46,10 +49,9 @@ class CORE_EXPORT QgsAuthMethodConfig
      */
     QgsAuthMethodConfig( const QString &method = QString(), int version = 0 );
 
-    //! Operator used to compare configs' equality
-    bool operator==( const QgsAuthMethodConfig &other ) const;
+    // TODO c++20 - replace with = default
 
-    //! Operator used to compare configs' inequality
+    bool operator==( const QgsAuthMethodConfig &other ) const;
     bool operator!=( const QgsAuthMethodConfig &other ) const;
 
     /**
@@ -160,6 +162,22 @@ class CORE_EXPORT QgsAuthMethodConfig
      */
     static bool uriToResource( const QString &accessurl, QString *resource, bool withpath = false );
 
+    /**
+     * Stores the configuration in a DOM
+     * \param parentElement parent DOM element
+     * \param document DOM document
+     * \see readXml()
+     * \since QGIS 3.20
+     */
+    bool writeXml( QDomElement &parentElement, QDomDocument &document );
+
+    /**
+     *  from a DOM element.
+     * \param element is the DOM node corresponding to item (e.g. 'LayoutItem' element)
+     * \since QGIS 3.20
+     */
+    bool readXml( const QDomElement &element );
+
   private:
     QString mId;
     QString mName;
@@ -436,6 +454,9 @@ class CORE_EXPORT QgsAuthConfigSslServer
     QString mSslHostPort;
     QSslCertificate mSslCert;
 
+    static QSsl::SslProtocol decodeSslProtocol( const QString &protocol );
+    static QString encodeSslProtocol( QSsl::SslProtocol protocol );
+
     QSsl::SslProtocol mSslProtocol;
     int mQtVersion;
     QList<QSslError::SslError> mSslIgnoredErrors;
