@@ -28,7 +28,7 @@ email                : marco.hugentobler at sourcepole dot com
 
 QgsMultiCurve::QgsMultiCurve()
 {
-  mWkbType = QgsWkbTypes::MultiCurve;
+  mWkbType = Qgis::WkbType::MultiCurve;
 }
 
 QgsCurve *QgsMultiCurve::curveN( int index )
@@ -61,7 +61,7 @@ QgsMultiCurve *QgsMultiCurve::clone() const
 void QgsMultiCurve::clear()
 {
   QgsGeometryCollection::clear();
-  mWkbType = QgsWkbTypes::MultiCurve;
+  mWkbType = Qgis::WkbType::MultiCurve;
 }
 
 QgsMultiCurve *QgsMultiCurve::toCurveType() const
@@ -151,7 +151,7 @@ bool QgsMultiCurve::addGeometry( QgsAbstractGeometry *g )
 
   if ( mGeometries.empty() )
   {
-    setZMTypeFromSubGeometry( g, QgsWkbTypes::MultiCurve );
+    setZMTypeFromSubGeometry( g, Qgis::WkbType::MultiCurve );
   }
   if ( is3D() && !g->is3D() )
     g->addZValue();
@@ -165,6 +165,39 @@ bool QgsMultiCurve::addGeometry( QgsAbstractGeometry *g )
   return QgsGeometryCollection::addGeometry( g );
 }
 
+bool QgsMultiCurve::addGeometries( const QVector<QgsAbstractGeometry *> &geometries )
+{
+  for ( QgsAbstractGeometry *g : geometries )
+  {
+    if ( !qgsgeometry_cast<QgsCurve *>( g ) )
+    {
+      qDeleteAll( geometries );
+      return false;
+    }
+  }
+
+  if ( mGeometries.empty() && !geometries.empty() )
+  {
+    setZMTypeFromSubGeometry( geometries.at( 0 ), Qgis::WkbType::MultiCurve );
+  }
+  mGeometries.reserve( mGeometries.size() + geometries.size() );
+  for ( QgsAbstractGeometry *g : geometries )
+  {
+    if ( is3D() && !g->is3D() )
+      g->addZValue();
+    else if ( !is3D() && g->is3D() )
+      g->dropZValue();
+    if ( isMeasure() && !g->isMeasure() )
+      g->addMValue();
+    else if ( !isMeasure() && g->isMeasure() )
+      g->dropMValue();
+    mGeometries.append( g );
+  }
+
+  clearCache();
+  return true;
+}
+
 bool QgsMultiCurve::insertGeometry( QgsAbstractGeometry *g, int index )
 {
   if ( !g || !qgsgeometry_cast<QgsCurve *>( g ) )
@@ -176,6 +209,17 @@ bool QgsMultiCurve::insertGeometry( QgsAbstractGeometry *g, int index )
   return QgsGeometryCollection::insertGeometry( g, index );
 }
 
+QgsMultiCurve *QgsMultiCurve::simplifyByDistance( double tolerance ) const
+{
+  std::unique_ptr< QgsMultiCurve > res = std::make_unique< QgsMultiCurve >();
+  res->reserve( mGeometries.size() );
+  for ( int i = 0; i < mGeometries.size(); ++i )
+  {
+    res->addGeometry( mGeometries.at( i )->simplifyByDistance( tolerance ) );
+  }
+  return res.release();
+}
+
 QgsMultiCurve *QgsMultiCurve::reversed() const
 {
   QgsMultiCurve *reversedMultiCurve = new QgsMultiCurve();
