@@ -47,7 +47,7 @@ class QgsMeshExtraDatasetStore: public QgsMeshDatasetSourceInterface
     bool hasTemporalCapabilities() const;
 
     //! Returns the relative times of the dataset index with \a index, returned value in milliseconds
-    quint64 datasetRelativeTime( QgsMeshDatasetIndex index );
+    qint64 datasetRelativeTime( QgsMeshDatasetIndex index ) const;
 
     //! Returns information related to the dataset group with \a groupIndex
     QString description( int groupIndex ) const;
@@ -61,7 +61,7 @@ class QgsMeshExtraDatasetStore: public QgsMeshDatasetSourceInterface
     QgsMeshDatasetMetadata datasetMetadata( QgsMeshDatasetIndex index ) const override;
     QgsMeshDatasetValue datasetValue( QgsMeshDatasetIndex index, int valueIndex ) const override;
     QgsMeshDataBlock datasetValues( QgsMeshDatasetIndex index, int valueIndex, int count ) const override;
-    QgsMesh3dDataBlock dataset3dValues( QgsMeshDatasetIndex index, int faceIndex, int count ) const override;
+    QgsMesh3DDataBlock dataset3dValues( QgsMeshDatasetIndex index, int faceIndex, int count ) const override;
     bool isFaceActive( QgsMeshDatasetIndex index, int faceIndex ) const override;
     QgsMeshDataBlock areFacesActive( QgsMeshDatasetIndex index, int faceIndex, int count ) const override;
 
@@ -120,12 +120,12 @@ class QgsMeshDatasetGroupStore: public QObject
 {
     Q_OBJECT
 
-    //! Contains a pointer to the dataset source inerface and the index on this dataset groups container
+    //! Contains a pointer to the dataset source interface and the index on this dataset groups container
     typedef QPair<QgsMeshDatasetSourceInterface *, int> DatasetGroup;
 
   public:
     //! Constructor
-    QgsMeshDatasetGroupStore( QgsMeshLayer *layer );
+    explicit QgsMeshDatasetGroupStore( QgsMeshLayer *layer );
 
     //!  Sets the persistent mesh data provider with the path of its extra dataset to be loaded by the provider
     void setPersistentProvider( QgsMeshDataProvider *provider, const QStringList &extraDatasetUri );
@@ -187,7 +187,7 @@ class QgsMeshDatasetGroupStore: public QObject
     QgsMeshDataBlock datasetValues( const QgsMeshDatasetIndex &index, int valueIndex, int count ) const;
 
     //! Returns \a count 3D values of the dataset with global \a index and from \a valueIndex
-    QgsMesh3dDataBlock dataset3dValues( const QgsMeshDatasetIndex &index, int faceIndex, int count ) const;
+    QgsMesh3DDataBlock dataset3dValues( const QgsMeshDatasetIndex &index, int faceIndex, int count ) const;
 
     //! Returns whether faces are active for particular dataset
     QgsMeshDataBlock areFacesActive( const QgsMeshDatasetIndex &index, int faceIndex, int count ) const;
@@ -203,7 +203,7 @@ class QgsMeshDatasetGroupStore: public QObject
     /**
      * Returns the global dataset index of the dataset int the dataset group with \a groupIndex, that is between relative times \a time1 and \a time2
      *
-     * Since QGIS 3.22
+     * \since QGIS 3.22
      */
     QList<QgsMeshDatasetIndex> datasetIndexInTimeInterval( qint64 time1, qint64 time2, int groupIndex ) const;
 
@@ -223,10 +223,24 @@ class QgsMeshDatasetGroupStore: public QObject
      * Returns the global dataset group index of the dataset group with native index \a nativeGroupIndex in the \a source
      * Returns -1 if the group or the source is not registered
      *
-     * Since QGIS 3.22
+     * \since QGIS 3.22
      */
     int globalDatasetGroupIndexInSource( QgsMeshDatasetSourceInterface *source, int nativeGroupIndex ) const;
 
+    /**
+     * Returns the global dataset group index of the dataset with name \a groupName
+     *
+     * \since QGIS 3.30.2
+     */
+    int indexFromGroupName( const QString &groupName ) const;
+
+    /**
+     * Returns the name of the dataset group with global index \a groupIndex
+     *
+     * \since QGIS 3.30.2
+     */
+    QString groupName( int groupIndex ) const;
+
   signals:
     //! Emitted after dataset groups are added
     void datasetGroupsAdded( QList<int> indexes );
@@ -237,8 +251,8 @@ class QgsMeshDatasetGroupStore: public QObject
   private:
     QgsMeshLayer *mLayer = nullptr;
     QgsMeshDataProvider *mPersistentProvider = nullptr;
-    std::unique_ptr<QgsMeshExtraDatasetStore> mExtraDatasets;
-    QMap < int, DatasetGroup> mRegistery;
+    QgsMeshExtraDatasetStore mExtraDatasets;
+    QMap < int, DatasetGroup> mRegistry;
     QList<int> mPersistentExtraDatasetGroupIndexes;
     QMap<QString, int> mGroupNameToGlobalIndex;
     std::unique_ptr<QgsMeshDatasetGroupTreeItem> mDatasetGroupTreeRootItem;
