@@ -107,7 +107,7 @@ class CORE_EXPORT QgsMeshRendererScalarSettings
       /**
        * Does not use resampling
        */
-      None = 0,
+      NoResampling = 0,
 
       /**
        * Does a simple average of values defined for all surrounding faces/vertices
@@ -183,7 +183,7 @@ class CORE_EXPORT QgsMeshRendererScalarSettings
 
   private:
     QgsColorRampShader mColorRampShader;
-    DataResamplingMethod mDataResamplingMethod = DataResamplingMethod::None;
+    DataResamplingMethod mDataResamplingMethod = DataResamplingMethod::NoResampling;
     double mClassificationMinimum = 0;
     double mClassificationMaximum = 0;
     double mOpacity = 1;
@@ -395,6 +395,86 @@ class CORE_EXPORT QgsMeshRendererVectorTracesSettings
 
 };
 
+/**
+ * \ingroup core
+ *
+ * \brief Represents a mesh renderer settings for vector datasets displayed with wind barbs
+ *
+ * \note The API is considered EXPERIMENTAL and can be changed without a notice
+ *
+ * \since QGIS 3.38
+ */
+class CORE_EXPORT QgsMeshRendererVectorWindBarbSettings
+{
+  public:
+    //! Wind speed units. Wind barbs use knots so we use this enum for preset conversion values
+    enum class WindSpeedUnit
+    {
+      MetersPerSecond = 0, //!< Meters per second
+      KilometersPerHour, //!< Kilometers per hour
+      Knots, //!< Knots (Nautical miles per hour)
+      MilesPerHour, //!< Miles per hour
+      FeetPerSecond, //!< Feet per second
+      OtherUnit //!< Other unit
+    };
+
+    /**
+     * Returns the multiplier for the magnitude to convert it to knots, according to the units set with setMagnitudeUnits()
+     * A custom multiplier can be set with setMagnitudeMultiplier() for the case when units are set to OtherUnit
+     */
+    double magnitudeMultiplier() const;
+
+    /**
+     * Sets a multiplier for the magnitude to convert it to knots
+     */
+    void setMagnitudeMultiplier( double magnitudeMultiplier );
+
+    /**
+     * Returns the shaft length (in millimeters)
+     */
+    double shaftLength() const;
+
+    /**
+     * Sets the shaft length  (in millimeters)
+     */
+    void setShaftLength( double shaftLength );
+
+    /**
+     * Returns the units for the shaft length.
+     *
+     * \see setShaftLengthUnits()
+     */
+    Qgis::RenderUnit shaftLengthUnits() const;
+
+    /**
+     * Sets the units for the shaft length.
+     *
+     * \see shaftLengthUnits()
+     */
+    void setShaftLengthUnits( Qgis::RenderUnit shaftLengthUnit );
+
+    /**
+     * Returns the units that the data are in
+     */
+    WindSpeedUnit magnitudeUnits() const;
+
+    /**
+     * Sets the units that the data are in
+     */
+    void setMagnitudeUnits( WindSpeedUnit units );
+
+    //! Writes configuration to a new DOM element
+    QDomElement writeXml( QDomDocument &doc ) const;
+    //! Reads configuration from the given DOM element
+    void readXml( const QDomElement &elem );
+
+  private:
+    double mShaftLength = 10;
+    Qgis::RenderUnit mShaftLengthUnits = Qgis::RenderUnit::Millimeters;
+    WindSpeedUnit mMagnitudeUnits = WindSpeedUnit::MetersPerSecond;
+    double mMagnitudeMultiplier = 1;
+};
+
 /**
  * \ingroup core
  *
@@ -419,7 +499,9 @@ class CORE_EXPORT QgsMeshRendererVectorSettings
       //! Displaying vector dataset with streamlines
       Streamlines,
       //! Displaying vector dataset with particle traces
-      Traces
+      Traces,
+      //! Displaying vector dataset with wind barbs
+      WindBarbs
     };
 
     //! Returns line width of the arrow (in millimeters)
@@ -551,6 +633,18 @@ class CORE_EXPORT QgsMeshRendererVectorSettings
      */
     void setTracesSettings( const QgsMeshRendererVectorTracesSettings &tracesSettings );
 
+    /**
+    * Returns settings for vector rendered with wind barbs
+    * \since QGIS 3.38
+    */
+    QgsMeshRendererVectorWindBarbSettings windBarbSettings() const;
+
+    /**
+     * Sets settings for vector rendered with wind barbs
+     * \since QGIS 3.38
+     */
+    void setWindBarbSettings( const QgsMeshRendererVectorWindBarbSettings &windBarbSettings );
+
     //! Writes configuration to a new DOM element
     QDomElement writeXml( QDomDocument &doc, const QgsReadWriteContext &context = QgsReadWriteContext() ) const;
     //! Reads configuration from the given DOM element
@@ -573,6 +667,7 @@ class CORE_EXPORT QgsMeshRendererVectorSettings
     QgsMeshRendererVectorArrowSettings mArrowsSettings;
     QgsMeshRendererVectorStreamlineSettings mStreamLinesSettings;
     QgsMeshRendererVectorTracesSettings mTracesSettings;
+    QgsMeshRendererVectorWindBarbSettings mWindBarbSettings;
 };
 
 /**
@@ -592,7 +687,6 @@ class CORE_EXPORT QgsMeshRendererSettings
      * Constructs renderer with default single layer averaging method
      */
     QgsMeshRendererSettings();
-    //! Destructor
     ~QgsMeshRendererSettings();
 
     //! Returns native mesh renderer settings
