@@ -84,6 +84,7 @@ QgsCoordinateTransformPrivate::QgsCoordinateTransformPrivate( const QgsCoordinat
   , mIsValid( other.mIsValid )
   , mShortCircuit( other.mShortCircuit )
   , mGeographicToWebMercator( other.mGeographicToWebMercator )
+  , mHasVerticalComponent( other.mHasVerticalComponent )
   , mSourceCRS( other.mSourceCRS )
   , mDestCRS( other.mDestCRS )
   , mSourceDatumTransform( other.mSourceDatumTransform )
@@ -163,6 +164,8 @@ bool QgsCoordinateTransformPrivate::initialize()
     mSourceCRS.isGeographic() &&
     mDestCRS.authid() == QLatin1String( "EPSG:3857" );
 
+  mHasVerticalComponent = mSourceCRS.hasVerticalAxis() && mDestCRS.hasVerticalAxis();
+
   mSourceIsDynamic = mSourceCRS.isDynamic();
   mSourceCoordinateEpoch = mSourceCRS.coordinateEpoch();
   mDestIsDynamic = mDestCRS.isDynamic();
