@@ -22,7 +22,9 @@
 #include "qgsfeatureiterator.h"
 #include "qgsgeometry.h"
 #include "qgsvectorlayer.h"
-
+#include "qgsstatisticalsummary.h"
+#include "qgsdatetimestatisticalsummary.h"
+#include "qgsstringstatisticalsummary.h"
 
 
 QgsAggregateCalculator::QgsAggregateCalculator( const QgsVectorLayer *layer )
@@ -49,7 +51,7 @@ void QgsAggregateCalculator::setFidsFilter( const QgsFeatureIds &fids )
   mFidsFilter = fids;
 }
 
-QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate aggregate,
+QVariant QgsAggregateCalculator::calculate( Qgis::Aggregate aggregate,
     const QString &fieldOrExpression, QgsExpressionContext *context, bool *ok, QgsFeedback *feedback ) const
 {
   mLastError.clear();
@@ -87,17 +89,29 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
   else
     lst = expression->referencedColumns();
 
-  request.setFlags( ( expression && expression->needsGeometry() ) ?
-                    QgsFeatureRequest::NoFlags :
-                    QgsFeatureRequest::NoGeometry )
+  bool expressionNeedsGeometry {  expression &&expression->needsGeometry() };
+
+  if ( !mOrderBy.empty() )
+  {
+    request.setOrderBy( mOrderBy );
+    for ( const QgsFeatureRequest::OrderByClause &orderBy : std::as_const( mOrderBy ) )
+    {
+      if ( orderBy.expression().needsGeometry() )
+      {
+        expressionNeedsGeometry = true;
+        break;
+      }
+    }
+  }
+
+  request.setFlags( expressionNeedsGeometry ?
+                    Qgis::FeatureRequestFlag::NoFlags :
+                    Qgis::FeatureRequestFlag::NoGeometry )
   .setSubsetOfAttributes( lst, mLayer->fields() );
 
   if ( mFidsSet )
     request.setFilterFids( mFidsFilter );
 
-  if ( !mOrderBy.empty() )
-    request.setOrderBy( mOrderBy );
-
   if ( !mFilterExpression.isEmpty() )
     request.setFilterExpression( mFilterExpression );
   if ( context )
@@ -106,20 +120,20 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
   request.setFeedback( feedback ? feedback : ( context ? context->feedback() : nullptr ) );
 
   //determine result type
-  QVariant::Type resultType = QVariant::Double;
+  QMetaType::Type resultType = QMetaType::Type::Double;
   int userType = 0;
   if ( attrNum == -1 )
   {
-    if ( aggregate == GeometryCollect )
+    if ( aggregate == Qgis::Aggregate::GeometryCollect )
     {
       // in this case we know the result should be a geometry value, so no need to sniff it out...
-      resultType = QVariant::UserType;
+      resultType = QMetaType::Type::User;
     }
     else
     {
       // check expression result type
       bool foundFeatures = false;
-      std::tuple<QVariant::Type, int> returnType = QgsExpressionUtils::determineResultType( fieldOrExpression, mLayer, request, *context, &foundFeatures );
+      std::tuple<QMetaType::Type, int> returnType = QgsExpressionUtils::determineResultType( fieldOrExpression, mLayer, request, *context, &foundFeatures );
       if ( !foundFeatures )
       {
         if ( ok )
@@ -129,51 +143,51 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
 
       resultType = std::get<0>( returnType );
       userType = std::get<1>( returnType );
-      if ( resultType == QVariant::Invalid )
+      if ( resultType == QMetaType::Type::UnknownType )
       {
         QVariant v;
         switch ( aggregate )
         {
           // string
-          case StringConcatenate:
-          case StringConcatenateUnique:
-          case StringMinimumLength:
-          case StringMaximumLength:
+          case Qgis::Aggregate::StringConcatenate:
+          case Qgis::Aggregate::StringConcatenateUnique:
+          case Qgis::Aggregate::StringMinimumLength:
+          case Qgis::Aggregate::StringMaximumLength:
             v = QString();
             break;
 
           // numerical
-          case Sum:
-          case Mean:
-          case Median:
-          case StDev:
-          case StDevSample:
-          case Range:
-          case FirstQuartile:
-          case ThirdQuartile:
-          case InterQuartileRange:
+          case Qgis::Aggregate::Sum:
+          case Qgis::Aggregate::Mean:
+          case Qgis::Aggregate::Median:
+          case Qgis::Aggregate::StDev:
+          case Qgis::Aggregate::StDevSample:
+          case Qgis::Aggregate::Range:
+          case Qgis::Aggregate::FirstQuartile:
+          case Qgis::Aggregate::ThirdQuartile:
+          case Qgis::Aggregate::InterQuartileRange:
           // mixed type, fallback to numerical
-          case Count:
-          case CountDistinct:
-          case CountMissing:
-          case Minority:
-          case Majority:
-          case Min:
-          case Max:
+          case Qgis::Aggregate::Count:
+          case Qgis::Aggregate::CountDistinct:
+          case Qgis::Aggregate::CountMissing:
+          case Qgis::Aggregate::Minority:
+          case Qgis::Aggregate::Majority:
+          case Qgis::Aggregate::Min:
+          case Qgis::Aggregate::Max:
             v = 0.0;
             break;
 
           // geometry
-          case GeometryCollect:
+          case Qgis::Aggregate::GeometryCollect:
             v = QgsGeometry();
             break;
 
           // list, fallback to string
-          case ArrayAggregate:
+          case Qgis::Aggregate::ArrayAggregate:
             v = QString();
             break;
         }
-        resultType = v.type();
+        resultType = static_cast<QMetaType::Type>( v.userType() );
         userType = v.userType();
       }
     }
@@ -185,7 +199,7 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
   return calculate( aggregate, fit, resultType, userType, attrNum, expression.get(), mDelimiter, context, ok, &mLastError );
 }
 
-QgsAggregateCalculator::Aggregate QgsAggregateCalculator::stringToAggregate( const QString &string, bool *ok )
+Qgis::Aggregate QgsAggregateCalculator::stringToAggregate( const QString &string, bool *ok )
 {
   const QString normalized = string.trimmed().toLower();
 
@@ -193,103 +207,103 @@ QgsAggregateCalculator::Aggregate QgsAggregateCalculator::stringToAggregate( con
     *ok = true;
 
   if ( normalized == QLatin1String( "count" ) )
-    return Count;
+    return Qgis::Aggregate::Count;
   else if ( normalized == QLatin1String( "count_distinct" ) )
-    return CountDistinct;
+    return Qgis::Aggregate::CountDistinct;
   else if ( normalized == QLatin1String( "count_missing" ) )
-    return CountMissing;
-  else if ( normalized == QLatin1String( "min" ) )
-    return Min;
-  else if ( normalized == QLatin1String( "max" ) )
-    return Max;
+    return Qgis::Aggregate::CountMissing;
+  else if ( normalized == QLatin1String( "min" ) || normalized == QLatin1String( "minimum" ) )
+    return Qgis::Aggregate::Min;
+  else if ( normalized == QLatin1String( "max" ) || normalized == QLatin1String( "maximum" ) )
+    return Qgis::Aggregate::Max;
   else if ( normalized == QLatin1String( "sum" ) )
-    return Sum;
+    return Qgis::Aggregate::Sum;
   else if ( normalized == QLatin1String( "mean" ) )
-    return Mean;
+    return Qgis::Aggregate::Mean;
   else if ( normalized == QLatin1String( "median" ) )
-    return Median;
+    return Qgis::Aggregate::Median;
   else if ( normalized == QLatin1String( "stdev" ) )
-    return StDev;
+    return Qgis::Aggregate::StDev;
   else if ( normalized == QLatin1String( "stdevsample" ) )
-    return StDevSample;
+    return Qgis::Aggregate::StDevSample;
   else if ( normalized == QLatin1String( "range" ) )
-    return Range;
+    return Qgis::Aggregate::Range;
   else if ( normalized == QLatin1String( "minority" ) )
-    return Minority;
+    return Qgis::Aggregate::Minority;
   else if ( normalized == QLatin1String( "majority" ) )
-    return Majority;
+    return Qgis::Aggregate::Majority;
   else if ( normalized == QLatin1String( "q1" ) )
-    return FirstQuartile;
+    return Qgis::Aggregate::FirstQuartile;
   else if ( normalized == QLatin1String( "q3" ) )
-    return ThirdQuartile;
+    return Qgis::Aggregate::ThirdQuartile;
   else if ( normalized == QLatin1String( "iqr" ) )
-    return InterQuartileRange;
+    return Qgis::Aggregate::InterQuartileRange;
   else if ( normalized == QLatin1String( "min_length" ) )
-    return StringMinimumLength;
+    return Qgis::Aggregate::StringMinimumLength;
   else if ( normalized == QLatin1String( "max_length" ) )
-    return StringMaximumLength;
+    return Qgis::Aggregate::StringMaximumLength;
   else if ( normalized == QLatin1String( "concatenate" ) )
-    return StringConcatenate;
+    return Qgis::Aggregate::StringConcatenate;
   else if ( normalized == QLatin1String( "concatenate_unique" ) )
-    return StringConcatenateUnique;
+    return Qgis::Aggregate::StringConcatenateUnique;
   else if ( normalized == QLatin1String( "collect" ) )
-    return GeometryCollect;
+    return Qgis::Aggregate::GeometryCollect;
   else if ( normalized == QLatin1String( "array_agg" ) )
-    return ArrayAggregate;
+    return Qgis::Aggregate::ArrayAggregate;
 
   if ( ok )
     *ok = false;
 
-  return Count;
+  return Qgis::Aggregate::Count;
 }
 
-QString QgsAggregateCalculator::displayName( Aggregate aggregate )
+QString QgsAggregateCalculator::displayName( Qgis::Aggregate aggregate )
 {
   switch ( aggregate )
   {
-    case QgsAggregateCalculator::Count:
+    case Qgis::Aggregate::Count:
       return QObject::tr( "count" );
-    case QgsAggregateCalculator::CountDistinct:
+    case Qgis::Aggregate::CountDistinct:
       return QObject::tr( "count distinct" );
-    case QgsAggregateCalculator::CountMissing:
+    case Qgis::Aggregate::CountMissing:
       return QObject::tr( "count missing" );
-    case QgsAggregateCalculator::Min:
+    case Qgis::Aggregate::Min:
       return QObject::tr( "minimum" );
-    case QgsAggregateCalculator::Max:
+    case Qgis::Aggregate::Max:
       return QObject::tr( "maximum" );
-    case QgsAggregateCalculator::Sum:
+    case Qgis::Aggregate::Sum:
       return QObject::tr( "sum" );
-    case QgsAggregateCalculator::Mean:
+    case Qgis::Aggregate::Mean:
       return QObject::tr( "mean" );
-    case QgsAggregateCalculator::Median:
+    case Qgis::Aggregate::Median:
       return QObject::tr( "median" );
-    case QgsAggregateCalculator::StDev:
+    case Qgis::Aggregate::StDev:
       return QObject::tr( "standard deviation" );
-    case QgsAggregateCalculator::StDevSample:
+    case Qgis::Aggregate::StDevSample:
       return QObject::tr( "standard deviation (sample)" );
-    case QgsAggregateCalculator::Range:
+    case Qgis::Aggregate::Range:
       return QObject::tr( "range" );
-    case QgsAggregateCalculator::Minority:
+    case Qgis::Aggregate::Minority:
       return QObject::tr( "minority" );
-    case QgsAggregateCalculator::Majority:
+    case Qgis::Aggregate::Majority:
       return QObject::tr( "majority" );
-    case QgsAggregateCalculator::FirstQuartile:
+    case Qgis::Aggregate::FirstQuartile:
       return QObject::tr( "first quartile" );
-    case QgsAggregateCalculator::ThirdQuartile:
+    case Qgis::Aggregate::ThirdQuartile:
       return QObject::tr( "third quartile" );
-    case QgsAggregateCalculator::InterQuartileRange:
+    case Qgis::Aggregate::InterQuartileRange:
       return QObject::tr( "inter quartile range" );
-    case QgsAggregateCalculator::StringMinimumLength:
+    case Qgis::Aggregate::StringMinimumLength:
       return QObject::tr( "minimum length" );
-    case QgsAggregateCalculator::StringMaximumLength:
+    case Qgis::Aggregate::StringMaximumLength:
       return QObject::tr( "maximum length" );
-    case QgsAggregateCalculator::StringConcatenate:
+    case Qgis::Aggregate::StringConcatenate:
       return QObject::tr( "concatenate" );
-    case QgsAggregateCalculator::GeometryCollect:
+    case Qgis::Aggregate::GeometryCollect:
       return QObject::tr( "collection" );
-    case QgsAggregateCalculator::ArrayAggregate:
+    case Qgis::Aggregate::ArrayAggregate:
       return QObject::tr( "array aggregate" );
-    case QgsAggregateCalculator::StringConcatenateUnique:
+    case Qgis::Aggregate::StringConcatenateUnique:
       return QObject::tr( "concatenate (unique)" );
   }
   return QString();
@@ -303,235 +317,235 @@ QList<QgsAggregateCalculator::AggregateInfo> QgsAggregateCalculator::aggregates(
   {
     QStringLiteral( "count" ),
     QCoreApplication::tr( "Count" ),
-    QSet<QVariant::Type>()
-        << QVariant::DateTime
-        << QVariant::Date
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QDateTime
+        << QMetaType::Type::QDate
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "count_distinct" ),
     QCoreApplication::tr( "Count Distinct" ),
-    QSet<QVariant::Type>()
-        << QVariant::DateTime
-        << QVariant::Date
-        << QVariant::UInt
-        << QVariant::Int
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QDateTime
+        << QMetaType::Type::QDate
+        << QMetaType::Type::UInt
+        << QMetaType::Type::Int
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "count_missing" ),
     QCoreApplication::tr( "Count Missing" ),
-    QSet<QVariant::Type>()
-        << QVariant::DateTime
-        << QVariant::Date
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QDateTime
+        << QMetaType::Type::QDate
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "min" ),
     QCoreApplication::tr( "Min" ),
-    QSet<QVariant::Type>()
-        << QVariant::DateTime
-        << QVariant::Date
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QDateTime
+        << QMetaType::Type::QDate
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "max" ),
     QCoreApplication::tr( "Max" ),
-    QSet<QVariant::Type>()
-        << QVariant::DateTime
-        << QVariant::Date
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QDateTime
+        << QMetaType::Type::QDate
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "sum" ),
     QCoreApplication::tr( "Sum" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "mean" ),
     QCoreApplication::tr( "Mean" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "median" ),
     QCoreApplication::tr( "Median" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "stdev" ),
     QCoreApplication::tr( "Stdev" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "stdevsample" ),
     QCoreApplication::tr( "Stdev Sample" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "range" ),
     QCoreApplication::tr( "Range" ),
-    QSet<QVariant::Type>()
-        << QVariant::Date
-        << QVariant::DateTime
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QDate
+        << QMetaType::Type::QDateTime
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "minority" ),
     QCoreApplication::tr( "Minority" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "majority" ),
     QCoreApplication::tr( "Majority" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "q1" ),
     QCoreApplication::tr( "Q1" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "q3" ),
     QCoreApplication::tr( "Q3" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "iqr" ),
     QCoreApplication::tr( "InterQuartileRange" ),
-    QSet<QVariant::Type>()
-        << QVariant::Int
-        << QVariant::UInt
-        << QVariant::LongLong
-        << QVariant::ULongLong
-        << QVariant::Double
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::Int
+        << QMetaType::Type::UInt
+        << QMetaType::Type::LongLong
+        << QMetaType::Type::ULongLong
+        << QMetaType::Type::Double
   }
       << AggregateInfo
   {
     QStringLiteral( "min_length" ),
     QCoreApplication::tr( "Min Length" ),
-    QSet<QVariant::Type>()
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "max_length" ),
     QCoreApplication::tr( "Max Length" ),
-    QSet<QVariant::Type>()
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "concatenate" ),
     QCoreApplication::tr( "Concatenate" ),
-    QSet<QVariant::Type>()
-        << QVariant::String
+    QSet<QMetaType::Type>()
+        << QMetaType::Type::QString
   }
       << AggregateInfo
   {
     QStringLiteral( "collect" ),
     QCoreApplication::tr( "Collect" ),
-    QSet<QVariant::Type>()
+    QSet<QMetaType::Type>()
   }
       << AggregateInfo
   {
     QStringLiteral( "array_agg" ),
     QCoreApplication::tr( "Array Aggregate" ),
-    QSet<QVariant::Type>()
+    QSet<QMetaType::Type>()
   };
 
   return aggregates;
 }
 
-QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate aggregate, QgsFeatureIterator &fit, QVariant::Type resultType, int userType,
+QVariant QgsAggregateCalculator::calculate( Qgis::Aggregate aggregate, QgsFeatureIterator &fit, QMetaType::Type resultType, int userType,
     int attr, QgsExpression *expression, const QString &delimiter, QgsExpressionContext *context, bool *ok, QString *error )
 {
   if ( ok )
     *ok = false;
 
-  if ( aggregate == QgsAggregateCalculator::ArrayAggregate )
+  if ( aggregate == Qgis::Aggregate::ArrayAggregate )
   {
     if ( ok )
       *ok = true;
@@ -540,14 +554,14 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
 
   switch ( resultType )
   {
-    case QVariant::Int:
-    case QVariant::UInt:
-    case QVariant::LongLong:
-    case QVariant::ULongLong:
-    case QVariant::Double:
+    case QMetaType::Type::Int:
+    case QMetaType::Type::UInt:
+    case QMetaType::Type::LongLong:
+    case QMetaType::Type::ULongLong:
+    case QMetaType::Type::Double:
     {
       bool statOk = false;
-      const QgsStatisticalSummary::Statistic stat = numericStatFromAggregate( aggregate, &statOk );
+      const Qgis::Statistic stat = numericStatFromAggregate( aggregate, &statOk );
       if ( !statOk )
       {
         if ( error )
@@ -561,16 +575,16 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
       return calculateNumericAggregate( fit, attr, expression, context, stat );
     }
 
-    case QVariant::Date:
-    case QVariant::DateTime:
+    case QMetaType::Type::QDate:
+    case QMetaType::Type::QDateTime:
     {
       bool statOk = false;
-      const QgsDateTimeStatisticalSummary::Statistic stat = dateTimeStatFromAggregate( aggregate, &statOk );
+      const Qgis::DateTimeStatistic stat = dateTimeStatFromAggregate( aggregate, &statOk );
       if ( !statOk )
       {
         if ( error )
           *error = ( expression ? QObject::tr( "Cannot calculate %1 on %2 values" ).arg( displayName( aggregate ) ) :
-                     QObject::tr( "Cannot calculate %1 on %2 fields" ).arg( displayName( aggregate ) ) ).arg( resultType == QVariant::Date ? QObject::tr( "date" ) : QObject::tr( "datetime" ) );
+                     QObject::tr( "Cannot calculate %1 on %2 fields" ).arg( displayName( aggregate ) ) ).arg( resultType == QMetaType::Type::QDate ? QObject::tr( "date" ) : QObject::tr( "datetime" ) );
         return QVariant();
       }
 
@@ -579,9 +593,9 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
       return calculateDateTimeAggregate( fit, attr, expression, context, stat );
     }
 
-    case QVariant::UserType:
+    case QMetaType::Type::User:
     {
-      if ( aggregate == GeometryCollect )
+      if ( aggregate == Qgis::Aggregate::GeometryCollect )
       {
         if ( ok )
           *ok = true;
@@ -596,14 +610,14 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
     default:
     {
       // treat as string
-      if ( aggregate == StringConcatenate )
+      if ( aggregate == Qgis::Aggregate::StringConcatenate )
       {
         //special case
         if ( ok )
           *ok = true;
         return concatenateStrings( fit, attr, expression, context, delimiter );
       }
-      else if ( aggregate == StringConcatenateUnique )
+      else if ( aggregate == Qgis::Aggregate::StringConcatenateUnique )
       {
         //special case
         if ( ok )
@@ -612,16 +626,16 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
       }
 
       bool statOk = false;
-      const QgsStringStatisticalSummary::Statistic stat = stringStatFromAggregate( aggregate, &statOk );
+      const Qgis::StringStatistic stat = stringStatFromAggregate( aggregate, &statOk );
       if ( !statOk )
       {
         QString typeString;
-        if ( resultType == QVariant::Invalid )
+        if ( resultType == QMetaType::Type::UnknownType )
           typeString = QObject::tr( "null" );
-        else if ( resultType == QVariant::UserType )
+        else if ( resultType == QMetaType::Type::User )
           typeString = QMetaType::typeName( userType );
         else
-          typeString = resultType == QVariant::String ? QObject::tr( "string" ) : QVariant::typeToName( resultType );
+          typeString = resultType == QMetaType::Type::QString ? QObject::tr( "string" ) : QVariant::typeToName( resultType );
 
         if ( error )
           *error = expression ? QObject::tr( "Cannot calculate %1 on %3 values" ).arg( displayName( aggregate ), typeString )
@@ -640,164 +654,164 @@ QVariant QgsAggregateCalculator::calculate( QgsAggregateCalculator::Aggregate ag
 #endif
 }
 
-QgsStatisticalSummary::Statistic QgsAggregateCalculator::numericStatFromAggregate( QgsAggregateCalculator::Aggregate aggregate, bool *ok )
+Qgis::Statistic QgsAggregateCalculator::numericStatFromAggregate( Qgis::Aggregate aggregate, bool *ok )
 {
   if ( ok )
     *ok = true;
 
   switch ( aggregate )
   {
-    case Count:
-      return QgsStatisticalSummary::Count;
-    case CountDistinct:
-      return QgsStatisticalSummary::Variety;
-    case CountMissing:
-      return QgsStatisticalSummary::CountMissing;
-    case Min:
-      return QgsStatisticalSummary::Min;
-    case Max:
-      return QgsStatisticalSummary::Max;
-    case Sum:
-      return QgsStatisticalSummary::Sum;
-    case Mean:
-      return QgsStatisticalSummary::Mean;
-    case Median:
-      return QgsStatisticalSummary::Median;
-    case StDev:
-      return QgsStatisticalSummary::StDev;
-    case StDevSample:
-      return QgsStatisticalSummary::StDevSample;
-    case Range:
-      return QgsStatisticalSummary::Range;
-    case Minority:
-      return QgsStatisticalSummary::Minority;
-    case Majority:
-      return QgsStatisticalSummary::Majority;
-    case FirstQuartile:
-      return QgsStatisticalSummary::FirstQuartile;
-    case ThirdQuartile:
-      return QgsStatisticalSummary::ThirdQuartile;
-    case InterQuartileRange:
-      return QgsStatisticalSummary::InterQuartileRange;
-    case StringMinimumLength:
-    case StringMaximumLength:
-    case StringConcatenate:
-    case StringConcatenateUnique:
-    case GeometryCollect:
-    case ArrayAggregate:
+    case Qgis::Aggregate::Count:
+      return Qgis::Statistic::Count;
+    case Qgis::Aggregate::CountDistinct:
+      return Qgis::Statistic::Variety;
+    case Qgis::Aggregate::CountMissing:
+      return Qgis::Statistic::CountMissing;
+    case Qgis::Aggregate::Min:
+      return Qgis::Statistic::Min;
+    case Qgis::Aggregate::Max:
+      return Qgis::Statistic::Max;
+    case Qgis::Aggregate::Sum:
+      return Qgis::Statistic::Sum;
+    case Qgis::Aggregate::Mean:
+      return Qgis::Statistic::Mean;
+    case Qgis::Aggregate::Median:
+      return Qgis::Statistic::Median;
+    case Qgis::Aggregate::StDev:
+      return Qgis::Statistic::StDev;
+    case Qgis::Aggregate::StDevSample:
+      return Qgis::Statistic::StDevSample;
+    case Qgis::Aggregate::Range:
+      return Qgis::Statistic::Range;
+    case Qgis::Aggregate::Minority:
+      return Qgis::Statistic::Minority;
+    case Qgis::Aggregate::Majority:
+      return Qgis::Statistic::Majority;
+    case Qgis::Aggregate::FirstQuartile:
+      return Qgis::Statistic::FirstQuartile;
+    case Qgis::Aggregate::ThirdQuartile:
+      return Qgis::Statistic::ThirdQuartile;
+    case Qgis::Aggregate::InterQuartileRange:
+      return Qgis::Statistic::InterQuartileRange;
+    case Qgis::Aggregate::StringMinimumLength:
+    case Qgis::Aggregate::StringMaximumLength:
+    case Qgis::Aggregate::StringConcatenate:
+    case Qgis::Aggregate::StringConcatenateUnique:
+    case Qgis::Aggregate::GeometryCollect:
+    case Qgis::Aggregate::ArrayAggregate:
     {
       if ( ok )
         *ok = false;
-      return QgsStatisticalSummary::Count;
+      return Qgis::Statistic::Count;
     }
   }
 
   if ( ok )
     *ok = false;
-  return QgsStatisticalSummary::Count;
+  return Qgis::Statistic::Count;
 }
 
-QgsStringStatisticalSummary::Statistic QgsAggregateCalculator::stringStatFromAggregate( QgsAggregateCalculator::Aggregate aggregate, bool *ok )
+Qgis::StringStatistic QgsAggregateCalculator::stringStatFromAggregate( Qgis::Aggregate aggregate, bool *ok )
 {
   if ( ok )
     *ok = true;
 
   switch ( aggregate )
   {
-    case Count:
-      return QgsStringStatisticalSummary::Count;
-    case CountDistinct:
-      return QgsStringStatisticalSummary::CountDistinct;
-    case CountMissing:
-      return QgsStringStatisticalSummary::CountMissing;
-    case Min:
-      return QgsStringStatisticalSummary::Min;
-    case Max:
-      return QgsStringStatisticalSummary::Max;
-    case StringMinimumLength:
-      return QgsStringStatisticalSummary::MinimumLength;
-    case StringMaximumLength:
-      return QgsStringStatisticalSummary::MaximumLength;
-    case Minority:
-      return QgsStringStatisticalSummary::Minority;
-    case Majority:
-      return QgsStringStatisticalSummary::Majority;
+    case Qgis::Aggregate::Count:
+      return Qgis::StringStatistic::Count;
+    case Qgis::Aggregate::CountDistinct:
+      return Qgis::StringStatistic::CountDistinct;
+    case Qgis::Aggregate::CountMissing:
+      return Qgis::StringStatistic::CountMissing;
+    case Qgis::Aggregate::Min:
+      return Qgis::StringStatistic::Min;
+    case Qgis::Aggregate::Max:
+      return Qgis::StringStatistic::Max;
+    case Qgis::Aggregate::StringMinimumLength:
+      return Qgis::StringStatistic::MinimumLength;
+    case Qgis::Aggregate::StringMaximumLength:
+      return Qgis::StringStatistic::MaximumLength;
+    case Qgis::Aggregate::Minority:
+      return Qgis::StringStatistic::Minority;
+    case Qgis::Aggregate::Majority:
+      return Qgis::StringStatistic::Majority;
 
-    case Sum:
-    case Mean:
-    case Median:
-    case StDev:
-    case StDevSample:
-    case Range:
-    case FirstQuartile:
-    case ThirdQuartile:
-    case InterQuartileRange:
-    case StringConcatenate:
-    case StringConcatenateUnique:
-    case GeometryCollect:
-    case ArrayAggregate:
+    case Qgis::Aggregate::Sum:
+    case Qgis::Aggregate::Mean:
+    case Qgis::Aggregate::Median:
+    case Qgis::Aggregate::StDev:
+    case Qgis::Aggregate::StDevSample:
+    case Qgis::Aggregate::Range:
+    case Qgis::Aggregate::FirstQuartile:
+    case Qgis::Aggregate::ThirdQuartile:
+    case Qgis::Aggregate::InterQuartileRange:
+    case Qgis::Aggregate::StringConcatenate:
+    case Qgis::Aggregate::StringConcatenateUnique:
+    case Qgis::Aggregate::GeometryCollect:
+    case Qgis::Aggregate::ArrayAggregate:
     {
       if ( ok )
         *ok = false;
-      return QgsStringStatisticalSummary::Count;
+      return Qgis::StringStatistic::Count;
     }
   }
 
   if ( ok )
     *ok = false;
-  return QgsStringStatisticalSummary::Count;
+  return Qgis::StringStatistic::Count;
 }
 
-QgsDateTimeStatisticalSummary::Statistic QgsAggregateCalculator::dateTimeStatFromAggregate( QgsAggregateCalculator::Aggregate aggregate, bool *ok )
+Qgis::DateTimeStatistic QgsAggregateCalculator::dateTimeStatFromAggregate( Qgis::Aggregate aggregate, bool *ok )
 {
   if ( ok )
     *ok = true;
 
   switch ( aggregate )
   {
-    case Count:
-      return QgsDateTimeStatisticalSummary::Count;
-    case CountDistinct:
-      return QgsDateTimeStatisticalSummary::CountDistinct;
-    case CountMissing:
-      return QgsDateTimeStatisticalSummary::CountMissing;
-    case Min:
-      return QgsDateTimeStatisticalSummary::Min;
-    case Max:
-      return QgsDateTimeStatisticalSummary::Max;
-    case Range:
-      return QgsDateTimeStatisticalSummary::Range;
+    case Qgis::Aggregate::Count:
+      return Qgis::DateTimeStatistic::Count;
+    case Qgis::Aggregate::CountDistinct:
+      return Qgis::DateTimeStatistic::CountDistinct;
+    case Qgis::Aggregate::CountMissing:
+      return Qgis::DateTimeStatistic::CountMissing;
+    case Qgis::Aggregate::Min:
+      return Qgis::DateTimeStatistic::Min;
+    case Qgis::Aggregate::Max:
+      return Qgis::DateTimeStatistic::Max;
+    case Qgis::Aggregate::Range:
+      return Qgis::DateTimeStatistic::Range;
 
-    case Sum:
-    case Mean:
-    case Median:
-    case StDev:
-    case StDevSample:
-    case Minority:
-    case Majority:
-    case FirstQuartile:
-    case ThirdQuartile:
-    case InterQuartileRange:
-    case StringMinimumLength:
-    case StringMaximumLength:
-    case StringConcatenate:
-    case StringConcatenateUnique:
-    case GeometryCollect:
-    case ArrayAggregate:
+    case Qgis::Aggregate::Sum:
+    case Qgis::Aggregate::Mean:
+    case Qgis::Aggregate::Median:
+    case Qgis::Aggregate::StDev:
+    case Qgis::Aggregate::StDevSample:
+    case Qgis::Aggregate::Minority:
+    case Qgis::Aggregate::Majority:
+    case Qgis::Aggregate::FirstQuartile:
+    case Qgis::Aggregate::ThirdQuartile:
+    case Qgis::Aggregate::InterQuartileRange:
+    case Qgis::Aggregate::StringMinimumLength:
+    case Qgis::Aggregate::StringMaximumLength:
+    case Qgis::Aggregate::StringConcatenate:
+    case Qgis::Aggregate::StringConcatenateUnique:
+    case Qgis::Aggregate::GeometryCollect:
+    case Qgis::Aggregate::ArrayAggregate:
     {
       if ( ok )
         *ok = false;
-      return QgsDateTimeStatisticalSummary::Count;
+      return Qgis::DateTimeStatistic::Count;
     }
   }
 
   if ( ok )
     *ok = false;
-  return QgsDateTimeStatisticalSummary::Count;
+  return Qgis::DateTimeStatistic::Count;
 }
 
 QVariant QgsAggregateCalculator::calculateNumericAggregate( QgsFeatureIterator &fit, int attr, QgsExpression *expression,
-    QgsExpressionContext *context, QgsStatisticalSummary::Statistic stat )
+    QgsExpressionContext *context, Qgis::Statistic stat )
 {
   Q_ASSERT( expression || attr >= 0 );
 
@@ -824,7 +838,7 @@ QVariant QgsAggregateCalculator::calculateNumericAggregate( QgsFeatureIterator &
 }
 
 QVariant QgsAggregateCalculator::calculateStringAggregate( QgsFeatureIterator &fit, int attr, QgsExpression *expression,
-    QgsExpressionContext *context, QgsStringStatisticalSummary::Statistic stat )
+    QgsExpressionContext *context, Qgis::StringStatistic stat )
 {
   Q_ASSERT( expression || attr >= 0 );
 
@@ -860,7 +874,7 @@ QVariant QgsAggregateCalculator::calculateGeometryAggregate( QgsFeatureIterator
     Q_ASSERT( context );
     context->setFeature( f );
     const QVariant v = expression->evaluate( context );
-    if ( v.userType() == QMetaType::type( "QgsGeometry" ) )
+    if ( v.userType() == qMetaTypeId< QgsGeometry>() )
     {
       geometries << v.value<QgsGeometry>();
     }
@@ -898,48 +912,48 @@ QVariant QgsAggregateCalculator::concatenateStrings( QgsFeatureIterator &fit, in
   return results.join( delimiter );
 }
 
-QVariant QgsAggregateCalculator::defaultValue( QgsAggregateCalculator::Aggregate aggregate ) const
+QVariant QgsAggregateCalculator::defaultValue( Qgis::Aggregate aggregate ) const
 {
   // value to return when NO features are aggregated:
   switch ( aggregate )
   {
     // sensible values:
-    case Count:
-    case CountDistinct:
-    case CountMissing:
+    case Qgis::Aggregate::Count:
+    case Qgis::Aggregate::CountDistinct:
+    case Qgis::Aggregate::CountMissing:
       return 0;
 
-    case StringConcatenate:
-    case StringConcatenateUnique:
+    case Qgis::Aggregate::StringConcatenate:
+    case Qgis::Aggregate::StringConcatenateUnique:
       return ""; // zero length string - not null!
 
-    case ArrayAggregate:
+    case Qgis::Aggregate::ArrayAggregate:
       return QVariantList(); // empty list
 
     // undefined - nothing makes sense here
-    case Sum:
-    case Min:
-    case Max:
-    case Mean:
-    case Median:
-    case StDev:
-    case StDevSample:
-    case Range:
-    case Minority:
-    case Majority:
-    case FirstQuartile:
-    case ThirdQuartile:
-    case InterQuartileRange:
-    case StringMinimumLength:
-    case StringMaximumLength:
-    case GeometryCollect:
+    case Qgis::Aggregate::Sum:
+    case Qgis::Aggregate::Min:
+    case Qgis::Aggregate::Max:
+    case Qgis::Aggregate::Mean:
+    case Qgis::Aggregate::Median:
+    case Qgis::Aggregate::StDev:
+    case Qgis::Aggregate::StDevSample:
+    case Qgis::Aggregate::Range:
+    case Qgis::Aggregate::Minority:
+    case Qgis::Aggregate::Majority:
+    case Qgis::Aggregate::FirstQuartile:
+    case Qgis::Aggregate::ThirdQuartile:
+    case Qgis::Aggregate::InterQuartileRange:
+    case Qgis::Aggregate::StringMinimumLength:
+    case Qgis::Aggregate::StringMaximumLength:
+    case Qgis::Aggregate::GeometryCollect:
       return QVariant();
   }
   return QVariant();
 }
 
 QVariant QgsAggregateCalculator::calculateDateTimeAggregate( QgsFeatureIterator &fit, int attr, QgsExpression *expression,
-    QgsExpressionContext *context, QgsDateTimeStatisticalSummary::Statistic stat )
+    QgsExpressionContext *context, Qgis::DateTimeStatistic stat )
 {
   Q_ASSERT( expression || attr >= 0 );
 
