@@ -17,12 +17,9 @@
 #include <QIcon>
 
 #include "qgsfieldmodel.h"
-#include "qgsmaplayermodel.h"
-#include "qgsmaplayerproxymodel.h"
-#include "qgslogger.h"
-#include "qgsapplication.h"
 #include "qgsvectorlayer.h"
 #include "qgsvectorlayerjoinbuffer.h"
+#include "moc_qgsfieldmodel.cpp"
 
 QgsFieldModel::QgsFieldModel( QObject *parent )
   : QAbstractItemModel( parent )
@@ -283,7 +280,7 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
 
   switch ( role )
   {
-    case FieldNameRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::FieldName ):
     {
       if ( isEmpty || exprIdx >= 0 )
       {
@@ -293,7 +290,7 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       return field.name();
     }
 
-    case ExpressionRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::Expression ):
     {
       if ( exprIdx >= 0 )
       {
@@ -310,7 +307,7 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       }
     }
 
-    case FieldIndexRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::FieldIndex ):
     {
       if ( isEmpty || exprIdx >= 0 )
       {
@@ -319,12 +316,12 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       return index.row() - fieldOffset;
     }
 
-    case IsExpressionRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::IsExpression ):
     {
       return exprIdx >= 0;
     }
 
-    case ExpressionValidityRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::ExpressionValidity ):
     {
       if ( exprIdx >= 0 )
       {
@@ -339,7 +336,7 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       return true;
     }
 
-    case FieldTypeRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::FieldType ):
     {
       if ( exprIdx < 0 && !isEmpty )
       {
@@ -349,7 +346,7 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       return QVariant();
     }
 
-    case FieldOriginRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::FieldOrigin ):
     {
       if ( exprIdx < 0 && !isEmpty )
       {
@@ -358,12 +355,12 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       return QVariant();
     }
 
-    case IsEmptyRole:
+    case static_cast< int >( QgsFieldModel::CustomRole::IsEmpty ):
     {
       return isEmpty;
     }
 
-    case EditorWidgetType:
+    case static_cast< int >( QgsFieldModel::CustomRole::EditorWidgetType ):
     {
       if ( exprIdx < 0 && !isEmpty )
       {
@@ -372,11 +369,11 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       return QVariant();
     }
 
-    case JoinedFieldIsEditable:
+    case static_cast< int >( QgsFieldModel::CustomRole::JoinedFieldIsEditable ):
     {
       if ( exprIdx < 0 && !isEmpty )
       {
-        if ( mLayer && mFields.fieldOrigin( index.row() - fieldOffset ) == QgsFields::OriginJoin )
+        if ( mLayer && mFields.fieldOrigin( index.row() - fieldOffset ) == Qgis::FieldOrigin::Join )
         {
           int srcFieldIndex;
           const QgsVectorLayerJoinInfo *info = mLayer->joinBuffer()->joinForFieldIndex( index.row() - fieldOffset, mLayer->fields(), srcFieldIndex );
@@ -390,7 +387,7 @@ QVariant QgsFieldModel::data( const QModelIndex &index, int role ) const
       return QVariant();
     }
 
-    case FieldIsWidgetEditable:
+    case static_cast< int >( QgsFieldModel::CustomRole::FieldIsWidgetEditable ):
     {
       return !( mLayer->editFormConfig().readOnly( index.row() - fieldOffset ) );
     }
@@ -506,7 +503,7 @@ QString QgsFieldModel::fieldToolTipExtended( const QgsField &field, const QgsVec
   if ( fieldIdx < 0 )
     return QString();
 
-  const QString expressionString = fields.fieldOrigin( fieldIdx ) == QgsFields::OriginExpression
+  const QString expressionString = fields.fieldOrigin( fieldIdx ) == Qgis::FieldOrigin::Expression
                                    ? layer->expressionField( fieldIdx )
                                    : QString();
 
