@@ -17,16 +17,22 @@
 
 #include "qgssqliteexpressioncompiler.h"
 #include "qgssqlexpressioncompiler.h"
+#include "qgsexpressionfunction.h"
 #include "qgsexpressionnodeimpl.h"
+#include "qgsexpression.h"
 #include "qgssqliteutils.h"
 
-QgsSQLiteExpressionCompiler::QgsSQLiteExpressionCompiler( const QgsFields &fields )
-  : QgsSqlExpressionCompiler( fields, QgsSqlExpressionCompiler::LikeIsCaseInsensitive | QgsSqlExpressionCompiler::IntegerDivisionResultsInInteger )
+QgsSQLiteExpressionCompiler::QgsSQLiteExpressionCompiler( const QgsFields &fields, bool ignoreStaticNodes )
+  : QgsSqlExpressionCompiler( fields, QgsSqlExpressionCompiler::LikeIsCaseInsensitive | QgsSqlExpressionCompiler::IntegerDivisionResultsInInteger, ignoreStaticNodes )
 {
 }
 
 QgsSqlExpressionCompiler::Result QgsSQLiteExpressionCompiler::compileNode( const QgsExpressionNode *node, QString &result )
 {
+  const QgsSqlExpressionCompiler::Result staticRes = replaceNodeByStaticCachedValueIfPossible( node, result );
+  if ( staticRes != Fail )
+    return staticRes;
+
   switch ( node->nodeType() )
   {
     case QgsExpressionNode::ntBinaryOperator:
@@ -61,6 +67,24 @@ QgsSqlExpressionCompiler::Result QgsSQLiteExpressionCompiler::compileNode( const
       }
     }
 
+    case QgsExpressionNode::ntFunction:
+    {
+      const QgsExpressionNodeFunction *n = static_cast<const QgsExpressionNodeFunction *>( node );
+      QgsExpressionFunction *fd = QgsExpression::Functions()[n->fnIndex()];
+
+      if ( fd->name() == QLatin1String( "make_datetime" ) || fd->name() == QLatin1String( "make_date" ) || fd->name() == QLatin1String( "make_time" ) )
+      {
+        const auto constList = n->args()->list();
+        for ( const QgsExpressionNode *ln : constList )
+        {
+          if ( ln->nodeType() != QgsExpressionNode::ntLiteral )
+            return Fail;
+        }
+      }
+
+      return QgsSqlExpressionCompiler::compileNode( node, result );
+    }
+
     default:
       break;
   }
@@ -90,11 +114,41 @@ QString QgsSQLiteExpressionCompiler::sqlFunctionFromFunctionName( const QString
     { "round", "round" },
     { "trim", "trim" },
     { "upper", "upper" },
+    { "make_datetime", "" },
+    { "make_date", "" },
+    { "make_time", "" },
   };
 
   return FN_NAMES.value( fnName, QString() );
 }
 
+QStringList QgsSQLiteExpressionCompiler::sqlArgumentsFromFunctionName( const QString &fnName, const QStringList &fnArgs ) const
+{
+  QStringList args( fnArgs );
+  if ( fnName == QLatin1String( "make_datetime" ) )
+  {
+    args = QStringList( QStringLiteral( "'%1-%2-%3T%4:%5:%6Z'" ).arg( args[0].rightJustified( 4, '0' ) )
+                        .arg( args[1].rightJustified( 2, '0' ) )
+                        .arg( args[2].rightJustified( 2, '0' ) )
+                        .arg( args[3].rightJustified( 2, '0' ) )
+                        .arg( args[4].rightJustified( 2, '0' ) )
+                        .arg( args[5].rightJustified( 2, '0' ) ) );
+  }
+  else if ( fnName == QLatin1String( "make_date" ) )
+  {
+    args = QStringList( QStringLiteral( "'%1-%2-%3'" ).arg( args[0].rightJustified( 4, '0' ) )
+                        .arg( args[1].rightJustified( 2, '0' ) )
+                        .arg( args[2].rightJustified( 2, '0' ) ) );
+  }
+  else if ( fnName == QLatin1String( "make_time" ) )
+  {
+    args = QStringList( QStringLiteral( "'%1:%2:%3'" ).arg( args[0].rightJustified( 2, '0' ) )
+                        .arg( args[1].rightJustified( 2, '0' ) )
+                        .arg( args[2].rightJustified( 2, '0' ) ) );
+  }
+  return args;
+}
+
 QString QgsSQLiteExpressionCompiler::castToReal( const QString &value ) const
 {
   return QStringLiteral( "CAST((%1) AS REAL)" ).arg( value );
