@@ -43,22 +43,19 @@ namespace QgsZipUtils
    * \param dir The output directory
    * \param files The absolute path of unzipped files
    * \param checkConsistency Perform additional stricter consistency checks on the archive, and error if they fail (since QGIS 3.30)
-   * \returns FALSE if the zip filename does not exist, the output directory
-   * does not exist or is not writable.
-   * \since QGIS 3.0
+   * \returns FALSE if the zip filename does not exist, the output directory does not exist or is not writable.
    */
   CORE_EXPORT bool unzip( const QString &zip, const QString &dir, QStringList &files SIP_OUT, bool checkConsistency = true );
 
   /**
    * Zip the list of files in the zip file. If the zip file already exists or is
-   *  empty, an error is returned. If an input file does not exist, an error is
-   *  also returned.
+   * empty, an error is returned. If an input file does not exist, an error is
+   * also returned.
    * \param zip The zip filename
    * \param files The absolute path to files to embed within the zip
-   * \since QGIS 3.0
+   * \param overwrite Set to TRUE to allow overwriting existing files (since QGIS 3.44)
    */
-  CORE_EXPORT bool zip( const QString &zip, const QStringList &files );
-
+  CORE_EXPORT bool zip( const QString &zip, const QStringList &files, bool overwrite = false );
 
   /**
    * Decodes gzip byte stream, returns TRUE on success. Useful for reading vector tiles.
