@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgscombinedstylemodel.h"
+#include "moc_qgscombinedstylemodel.cpp"
 #include "qgsstyle.h"
 #include "qgsstylemodel.h"
 #include "qgssingleitemmodel.h"
@@ -57,13 +58,13 @@ void QgsCombinedStyleModel::addStyle( QgsStyle *style )
     {
       { Qt::DisplayRole, style->name() },
       { Qt::ToolTipRole, style->name() },
-      { QgsStyleModel::IsTitleRole, true },
-      { QgsStyleModel::StyleFileName, style->fileName() },
-      { QgsStyleModel::StyleName, style->name() },
+      { static_cast< int >( QgsStyleModel::CustomRole::IsTitle ), true },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleFileName ), style->fileName() },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleName ), style->name() },
     }, {
-      { QgsStyleModel::IsTitleRole, true },
-      { QgsStyleModel::StyleFileName, style->fileName() },
-      { QgsStyleModel::StyleName, style->name() }
+      { static_cast< int >( QgsStyleModel::CustomRole::IsTitle ), true },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleFileName ), style->fileName() },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleName ), style->name() }
     }
   } );
   addSourceModel( titleModel );
@@ -105,7 +106,7 @@ void QgsCombinedStyleModel::removeStyle( QgsStyle *style )
 
 void QgsCombinedStyleModel::addDefaultStyle()
 {
-  QgsStyle *defaultStyle = QgsStyle::defaultStyle();
+  QgsStyle *defaultStyle = QgsStyle::defaultStyle( false );
   QgsStyleModel *styleModel = QgsApplication::defaultStyleModel();
   if ( !defaultStyle || !styleModel )
     return;
@@ -117,13 +118,13 @@ void QgsCombinedStyleModel::addDefaultStyle()
     {
       { Qt::DisplayRole, defaultStyle->name() },
       { Qt::ToolTipRole, defaultStyle->name() },
-      { QgsStyleModel::IsTitleRole, true },
-      { QgsStyleModel::StyleFileName, defaultStyle->fileName() },
-      { QgsStyleModel::StyleName, defaultStyle->name() },
+      { static_cast< int >( QgsStyleModel::CustomRole::IsTitle ), true },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleFileName ), defaultStyle->fileName() },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleName ), defaultStyle->name() },
     }, {
-      { QgsStyleModel::IsTitleRole, true },
-      { QgsStyleModel::StyleFileName, defaultStyle->fileName() },
-      { QgsStyleModel::StyleName, defaultStyle->name() }
+      { static_cast< int >( QgsStyleModel::CustomRole::IsTitle ), true },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleFileName ), defaultStyle->fileName() },
+      { static_cast< int >( QgsStyleModel::CustomRole::StyleName ), defaultStyle->name() }
     }
   } );
 
