@@ -34,6 +34,7 @@
 #include "qgscoordinatetransform.h"
 
 #include <QProgressDialog>
+#include <QThread>
 
 typedef Qgis::VectorExportResult createEmptyLayer_t(
   const QString &uri,
@@ -520,12 +521,13 @@ QgsVectorLayerExporterTask::QgsVectorLayerExporterTask( QgsVectorLayer *layer, c
 {
   if ( mLayer )
     setDependentLayers( QList< QgsMapLayer * >() << mLayer );
+  if ( mLayer && mOwnsLayer )
+    mLayer->moveToThread( nullptr );
 }
 
 QgsVectorLayerExporterTask *QgsVectorLayerExporterTask::withLayerOwnership( QgsVectorLayer *layer, const QString &uri, const QString &providerKey, const QgsCoordinateReferenceSystem &destinationCrs, const QMap<QString, QVariant> &options )
 {
-  std::unique_ptr< QgsVectorLayerExporterTask > newTask( new QgsVectorLayerExporterTask( layer, uri, providerKey, destinationCrs, options ) );
-  newTask->mOwnsLayer = true;
+  std::unique_ptr< QgsVectorLayerExporterTask > newTask( new QgsVectorLayerExporterTask( layer, uri, providerKey, destinationCrs, options, true ) );
   return newTask.release();
 }
 
@@ -540,6 +542,9 @@ bool QgsVectorLayerExporterTask::run()
   if ( !mLayer )
     return false;
 
+  if ( mOwnsLayer )
+    mLayer->moveToThread( QThread::currentThread() );
+
   connect( mOwnedFeedback.get(), &QgsFeedback::progressChanged, this, &QgsVectorLayerExporterTask::setProgress );
 
 
@@ -547,11 +552,17 @@ bool QgsVectorLayerExporterTask::run()
              mLayer.data(), mDestUri, mDestProviderKey, mDestCrs, false, &mErrorMessage,
              mOptions, mOwnedFeedback.get() );
 
+  if ( mOwnsLayer )
+    mLayer->moveToThread( nullptr );
+
   return mError == Qgis::VectorExportResult::Success;
 }
 
 void QgsVectorLayerExporterTask::finished( bool result )
 {
+  if ( mOwnsLayer && mLayer )
+    mLayer->moveToThread( QThread::currentThread() );
+
   // QgsMapLayer has QTimer member, which must not be destroyed from another thread
   if ( mOwnsLayer )
     delete mLayer;
