@@ -16,6 +16,7 @@
 #include "qgsfeaturemodel.h"
 #include "qgsifeatureselectionmanager.h"
 #include "qgsfeatureselectionmodel.h"
+#include "moc_qgsfeatureselectionmodel.cpp"
 #include "qgsvectorlayer.h"
 #include "qgslogger.h"
 
@@ -66,7 +67,7 @@ bool QgsFeatureSelectionModel::isSelected( QgsFeatureId fid )
 
 bool QgsFeatureSelectionModel::isSelected( const QModelIndex &index )
 {
-  return isSelected( index.model()->data( index, QgsAttributeTableModel::FeatureIdRole ).toLongLong() );
+  return isSelected( index.model()->data( index, static_cast<int>( QgsAttributeTableModel::CustomRole::FeatureId ) ).toLongLong() );
 }
 
 void QgsFeatureSelectionModel::selectFeatures( const QItemSelection &selection, QItemSelectionModel::SelectionFlags command )
@@ -78,7 +79,7 @@ void QgsFeatureSelectionModel::selectFeatures( const QItemSelection &selection,
   const auto constIndexes = selection.indexes();
   for ( const QModelIndex &index : constIndexes )
   {
-    const QgsFeatureId id = index.model()->data( index, QgsAttributeTableModel::FeatureIdRole ).toLongLong();
+    const QgsFeatureId id = index.model()->data( index, static_cast<int>( QgsAttributeTableModel::CustomRole::FeatureId ) ).toLongLong();
 
     ids << id;
   }
