@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgscodeeditorjs.h"
+#include "moc_qgscodeeditorjs.cpp"
 
 #include <QWidget>
 #include <QString>
@@ -22,11 +23,7 @@
 
 
 QgsCodeEditorJavascript::QgsCodeEditorJavascript( QWidget *parent )
-  : QgsCodeEditor( parent,
-                   QString(),
-                   false,
-                   false,
-                   QgsCodeEditor::Flag::CodeFolding )
+  : QgsCodeEditor( parent, QString(), false, false, QgsCodeEditor::Flag::CodeFolding )
 {
   if ( !parent )
   {
