@@ -42,7 +42,6 @@ class QgsSearchWidgetWrapper;
 class GUI_EXPORT QgsEditorWidgetFactory
 {
   public:
-
     /**
      * Constructor
      *
@@ -73,7 +72,7 @@ class GUI_EXPORT QgsEditorWidgetFactory
      *
      * \returns a name
      */
-    QString name();
+    QString name() const;
 
     /**
      * Override this in your implementation.
@@ -96,7 +95,7 @@ class GUI_EXPORT QgsEditorWidgetFactory
      *
      * \see fieldScore()
      */
-    inline bool supportsField( const QgsVectorLayer *vl, int fieldIdx ) { return fieldScore( vl, fieldIdx ) > 0; }
+    inline bool supportsField( const QgsVectorLayer *vl, int fieldIdx ) const { return fieldScore( vl, fieldIdx ) > 0; }
 
     /**
      * Returns a list of widget types which this editor widget supports.
@@ -106,7 +105,10 @@ class GUI_EXPORT QgsEditorWidgetFactory
      * \returns A map of widget type names and weight values
      * \note not available in Python bindings
      */
-    virtual QHash<const char *, int> supportedWidgetTypes() { return QHash<const char *, int>(); } SIP_SKIP
+    virtual QHash<const char *, int> supportedWidgetTypes() SIP_SKIP
+    {
+      return QHash<const char *, int>();
+    }
 
     /**
      * This method allows disabling this editor widget type for a certain field.
