@@ -265,7 +265,6 @@ class GUI_EXPORT QgsRelationReferenceWidget : public QWidget
      */
     void setFetchLimit( int fetchLimit ) { mFetchLimit = fetchLimit; }
 
-
   public slots:
     //! open the form of the related feature in a new dialog
     void openForm();
@@ -276,6 +275,14 @@ class GUI_EXPORT QgsRelationReferenceWidget : public QWidget
     //! unset the currently related feature
     void deleteForeignKeys();
 
+    /**
+      * Trigger save of the embedded referenced attribute form.
+      * Returns TRUE on success or if no embedded form is present.
+      *
+      * \since QGIS 3.40
+      */
+    bool saveReferencedAttributeForm();
+
   protected:
     void showEvent( QShowEvent *e ) override;
 
