@@ -36,12 +36,11 @@ class QgsGeospatialPdfLayerFilteredTreeModel;
  * \note This class is not a part of public API
  * \since QGIS 3.12
  */
-class GUI_EXPORT QgsLayoutPdfExportOptionsDialog: public QDialog, private Ui::QgsPdfExportOptionsDialog
+class GUI_EXPORT QgsLayoutPdfExportOptionsDialog : public QDialog, private Ui::QgsPdfExportOptionsDialog
 {
     Q_OBJECT
 
   public:
-
     /**
      * Constructor for QgsLayoutPdfExportOptionsDialog
      * \param parent parent widget
@@ -51,11 +50,7 @@ class GUI_EXPORT QgsLayoutPdfExportOptionsDialog: public QDialog, private Ui::Qg
      * will instead be appended to the end of the geospatial PDF layer list
      * \param flags window flags
      */
-    QgsLayoutPdfExportOptionsDialog( QWidget *parent = nullptr,
-                                     bool allowGeospatialPdfExport = true,
-                                     const QString &geospatialPdfReason = QString(),
-                                     const QStringList &geospatialPdfLayerOrder = QStringList(),
-                                     Qt::WindowFlags flags = Qt::WindowFlags() );
+    QgsLayoutPdfExportOptionsDialog( QWidget *parent = nullptr, bool allowGeospatialPdfExport = true, const QString &geospatialPdfReason = QString(), const QStringList &geospatialPdfLayerOrder = QStringList(), Qt::WindowFlags flags = Qt::WindowFlags() );
 
     //! Sets the text render format
     void setTextRenderFormat( Qgis::TextRenderFormat format );
@@ -107,6 +102,9 @@ class GUI_EXPORT QgsLayoutPdfExportOptionsDialog: public QDialog, private Ui::Qg
     //! Returns a list of map layer IDs in the desired order they should appear in a generated Geospatial PDF file
     QStringList geospatialPdfLayerOrder() const;
 
+    //! Returns a list of groups in the desired order they should appear in a generated Geospatial PDF file
+    QStringList geospatialPdfGroupOrder() const;
+
     //! Sets whether to open the pdf after exporting it
     void setOpenAfterExporting( bool enabled );
     //! Returns whether the pdf should be opened after exporting it
@@ -118,12 +116,10 @@ class GUI_EXPORT QgsLayoutPdfExportOptionsDialog: public QDialog, private Ui::Qg
     void showContextMenuForGeospatialPdfStructure( QPoint point, const QModelIndex &index );
 
   private:
-
     bool mGeospatialPdfAvailable = true;
     QgsGeospatialPdfLayerTreeModel *mGeospatialPdfStructureModel = nullptr;
     QgsGeospatialPdfLayerFilteredTreeModel *mGeospatialPdfStructureProxyModel = nullptr;
     QMenu *mGeospatialPdfStructureTreeMenu = nullptr;
-
 };
 
 #endif // QGSLAYOUTPDFEXPORTOPTIONSDIALOG_H
