@@ -28,14 +28,12 @@
  * \brief Offers a toolbutton to choose between different aggregate functions.
  * Functions are filtered based on the type.
  *
- * \since QGIS 3.0
  */
 class GUI_EXPORT QgsAggregateToolButton : public QToolButton
 {
     Q_OBJECT
 
   public:
-
     /**
      * Constructor
      */
@@ -44,12 +42,18 @@ class GUI_EXPORT QgsAggregateToolButton : public QToolButton
     /**
      * Based on the \a type of underlying data, some aggregates will be available or not.
      */
-    void setType( QVariant::Type type );
+    void setType( QMetaType::Type type );
+
+    /**
+     * Based on the \a type of underlying data, some aggregates will be available or not.
+     * \deprecated QGIS 3.38. Use the method with a QMetaType::Type argument instead.
+     */
+    Q_DECL_DEPRECATED void setType( QVariant::Type type ) SIP_DEPRECATED;
 
     /**
      * Based on the \a type of underlying data, some aggregates will be available or not.
      */
-    QVariant::Type type() const;
+    QMetaType::Type type() const;
 
     /**
      * When this flag is FALSE, the aggregate will be deactivated. I.e. no aggregate is chosen.
@@ -89,7 +93,7 @@ class GUI_EXPORT QgsAggregateToolButton : public QToolButton
   private:
     void updateAvailableAggregates();
     QMenu *mMenu = nullptr;
-    QVariant::Type mType = QVariant::Invalid;
+    QMetaType::Type mType = QMetaType::Type::UnknownType;
     bool mActive = false;
     QString mAggregate;
     QList<QgsAggregateCalculator::AggregateInfo> mAvailableAggregates;
