@@ -18,12 +18,12 @@
 #include "qaction.h"
 #include "qgsapplication.h"
 #include "qgsexpressionpreviewwidget.h"
+#include "moc_qgsexpressionpreviewwidget.cpp"
 #include "qgsmessageviewer.h"
 #include "qgsvectorlayer.h"
 #include "qgsfeaturepickerwidget.h"
 
 
-
 QgsExpressionPreviewWidget::QgsExpressionPreviewWidget( QWidget *parent )
   : QWidget( parent )
 {
@@ -33,30 +33,64 @@ QgsExpressionPreviewWidget::QgsExpressionPreviewWidget( QWidget *parent )
   mCopyPreviewAction = new QAction( QgsApplication::getThemeIcon( QStringLiteral( "/mActionEditCopy.svg" ) ), tr( "Copy Expression Value" ), this );
   mPreviewLabel->addAction( mCopyPreviewAction );
   mFeaturePickerWidget->setShowBrowserButtons( true );
+  mStackedWidget->setSizeMode( QgsStackedWidget::SizeMode::CurrentPageOnly );
+  mStackedWidget->setCurrentWidget( mPageFeaturePicker );
 
+  mCustomButtonNext->setEnabled( false );
+  mCustomButtonPrev->setEnabled( false );
   connect( mFeaturePickerWidget, &QgsFeaturePickerWidget::featureChanged, this, &QgsExpressionPreviewWidget::setCurrentFeature );
+  connect( mCustomComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsExpressionPreviewWidget::setCustomChoice );
   connect( mPreviewLabel, &QLabel::linkActivated, this, &QgsExpressionPreviewWidget::linkActivated );
   connect( mCopyPreviewAction, &QAction::triggered, this, &QgsExpressionPreviewWidget::copyFullExpressionValue );
+  connect( mCustomButtonPrev, &QToolButton::clicked, this, [this] {
+    mCustomComboBox->setCurrentIndex( std::max( 0, mCustomComboBox->currentIndex() - 1 ) );
+  } );
+  connect( mCustomButtonNext, &QToolButton::clicked, this, [this] {
+    mCustomComboBox->setCurrentIndex( std::min( mCustomComboBox->count() - 1, mCustomComboBox->currentIndex() + 1 ) );
+  } );
 }
 
 void QgsExpressionPreviewWidget::setLayer( QgsVectorLayer *layer )
 {
-  mLayer = layer;
-  mFeaturePickerWidget->setLayer( layer );
+  if ( layer != mLayer )
+  {
+    mLayer = layer;
+    mFeaturePickerWidget->setLayer( layer );
+  }
+}
+
+void QgsExpressionPreviewWidget::setCustomPreviewGenerator( const QString &label, const QList<QPair<QString, QVariant>> &choices, const std::function<QgsExpressionContext( const QVariant & )> &previewContextGenerator )
+{
+  mCustomPreviewGeneratorFunction = previewContextGenerator;
+  mStackedWidget->setCurrentWidget( mPageCustomPicker );
+  mCustomLabel->setText( label );
+  mCustomComboBox->blockSignals( true );
+  mCustomComboBox->clear();
+  for ( const auto &choice : choices )
+  {
+    mCustomComboBox->addItem( choice.first, choice.second );
+  }
+  mCustomComboBox->blockSignals( false );
+  setCustomChoice( 0 );
 }
 
 void QgsExpressionPreviewWidget::setExpressionText( const QString &expression )
 {
-  mExpressionText = expression;
-  refreshPreview();
+  if ( expression != mExpressionText )
+  {
+    mExpressionText = expression;
+    refreshPreview();
+  }
 }
 
 void QgsExpressionPreviewWidget::setCurrentFeature( const QgsFeature &feature )
 {
-  // todo: update the combo box if it has been set externaly?
-
-  mExpressionContext.setFeature( feature );
-  refreshPreview();
+  // todo: update the combo box if it has been set externally?
+  if ( feature != mExpressionContext.feature() )
+  {
+    mExpressionContext.setFeature( feature );
+    refreshPreview();
+  }
 }
 
 void QgsExpressionPreviewWidget::setGeomCalculator( const QgsDistanceArea &da )
@@ -123,12 +157,15 @@ void QgsExpressionPreviewWidget::refreshPreview()
       QString tooltip;
       if ( mExpression.hasParserError() )
         tooltip = QStringLiteral( "<b>%1:</b>"
-                                  "%2" ).arg( tr( "Parser Errors" ), errorString );
+                                  "%2" )
+                    .arg( tr( "Parser Errors" ), errorString );
       // Only show the eval error if there is no parser error.
       if ( !mExpression.hasParserError() && mExpression.hasEvalError() )
         tooltip += QStringLiteral( "<b>%1:</b> %2" ).arg( tr( "Eval Error" ), mExpression.evalErrorString() );
 
-      mPreviewLabel->setText( tr( "Expression is invalid <a href=""more"">(more info)</a>" ) );
+      mPreviewLabel->setText( tr( "Expression is invalid <a href="
+                                  "more"
+                                  ">(more info)</a>" ) );
       mPreviewLabel->setStyleSheet( QStringLiteral( "color: rgba(255, 6, 10, 255);" ) );
       setExpressionToolTip( tooltip );
       emit expressionParsed( false );
@@ -190,6 +227,11 @@ bool QgsExpressionPreviewWidget::parserError() const
   return mParserError;
 }
 
+QString QgsExpressionPreviewWidget::currentPreviewText() const
+{
+  return mPreviewLabel->text();
+}
+
 void QgsExpressionPreviewWidget::setEvalError( bool evalError )
 {
   if ( evalError == mEvalError )
@@ -212,3 +254,15 @@ void QgsExpressionPreviewWidget::copyFullExpressionValue()
   QgsDebugMsgLevel( QStringLiteral( "set clipboard: %1" ).arg( copiedValue ), 4 );
   clipboard->setText( copiedValue );
 }
+
+void QgsExpressionPreviewWidget::setCustomChoice( int )
+{
+  const QVariant selectedValue = mCustomComboBox->currentData();
+
+  mCustomButtonPrev->setEnabled( mCustomComboBox->currentIndex() > 0 && mCustomComboBox->count() > 0 );
+  mCustomButtonNext->setEnabled( mCustomComboBox->currentIndex() < ( mCustomComboBox->count() - 1 ) && mCustomComboBox->count() > 0 );
+
+  mExpressionContext = mCustomPreviewGeneratorFunction( selectedValue );
+
+  refreshPreview();
+}
