@@ -14,6 +14,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "qgslayermetadataresultsmodel.h"
+#include "moc_qgslayermetadataresultsmodel.cpp"
 #include "qgsfeedback.h"
 #include "qgsapplication.h"
 #include "qgslayermetadataproviderregistry.h"
@@ -27,8 +28,8 @@ QgsLayerMetadataResultsModel::QgsLayerMetadataResultsModel( const QgsMetadataSea
   : QAbstractTableModel( parent )
   , mSearchContext( searchContext )
 {
-  qRegisterMetaType< QgsLayerMetadataSearchResults>( "QgsLayerMetadataSearchResults" );
-  qRegisterMetaType< QgsLayerMetadataProviderResult>( "QgsLayerMetadataProviderResult" );
+  qRegisterMetaType<QgsLayerMetadataSearchResults>( "QgsLayerMetadataSearchResults" );
+  qRegisterMetaType<QgsLayerMetadataProviderResult>( "QgsLayerMetadataProviderResult" );
 }
 
 QgsLayerMetadataResultsModel::~QgsLayerMetadataResultsModel()
@@ -48,7 +49,7 @@ int QgsLayerMetadataResultsModel::columnCount( const QModelIndex &parent ) const
 
 QVariant QgsLayerMetadataResultsModel::data( const QModelIndex &index, int role ) const
 {
-  if ( index.isValid() && index.row() < mResult.metadata().count( ) )
+  if ( index.isValid() && index.row() < mResult.metadata().count() )
   {
     switch ( role )
     {
@@ -57,7 +58,7 @@ QVariant QgsLayerMetadataResultsModel::data( const QModelIndex &index, int role
         switch ( index.column() )
         {
           case Sections::Identifier:
-            return mResult.metadata().at( index.row() ).identifier( );
+            return mResult.metadata().at( index.row() ).identifier();
           case Sections::Title:
             return mResult.metadata().at( index.row() ).title();
           case Sections::Abstract:
@@ -85,8 +86,9 @@ QVariant QgsLayerMetadataResultsModel::data( const QModelIndex &index, int role
       {
         const QgsLayerMetadataFormatter formatter { mResult.metadata().at( index.row() ) };
         return tr( R"HTML(<html><body><!-- metadata headers ---><h3>Identification</h3>%1</body></html>)HTML" )
-               .arg(
-                 formatter.identificationSectionHtml() );
+          .arg(
+            formatter.identificationSectionHtml()
+          );
         break;
       }
       case Qt::ItemDataRole::DecorationRole:
@@ -101,14 +103,13 @@ QVariant QgsLayerMetadataResultsModel::data( const QModelIndex &index, int role
         }
         break;
       }
-      case Roles::Metadata:
+      case static_cast<int>( CustomRole::Metadata ):
       {
         return QVariant::fromValue( mResult.metadata().at( index.row() ) );
       }
       default:
         // Ignore
         break;
-
     }
   }
   return QVariant();
@@ -172,8 +173,7 @@ void QgsLayerMetadataResultsModel::reloadAsync()
     std::unique_ptr<QThread> thread = std::make_unique<QThread>();
     fetcher->moveToThread( thread.get() );
     // Forward signals to the model
-    connect( fetcher.get(), &QgsMetadataResultsFetcher::resultsReady, this, [ = ]( const QgsLayerMetadataSearchResults & results )
-    {
+    connect( fetcher.get(), &QgsMetadataResultsFetcher::resultsReady, this, [=]( const QgsLayerMetadataSearchResults &results ) {
       resultsReady( results );
     } );
     connect( thread.get(), &QThread::started, fetcher.get(), &QgsMetadataResultsFetcher::fetchMetadata );
@@ -185,7 +185,7 @@ void QgsLayerMetadataResultsModel::reloadAsync()
 
 void QgsLayerMetadataResultsModel::resultsReady( const QgsLayerMetadataSearchResults &results )
 {
-  mFeedback->setProgress( mFeedback->progress() + 100 / QgsApplication::instance()->layerMetadataProviderRegistry()->layerMetadataProviders().count() );
+  mFeedback->setProgress( mFeedback->progress() + static_cast<double>( 100 ) / QgsApplication::instance()->layerMetadataProviderRegistry()->layerMetadataProviders().count() );
   beginInsertRows( QModelIndex(), mResult.metadata().count(), mResult.metadata().count() + results.metadata().count() - 1 );
   const QList<QgsLayerMetadataProviderResult> metadata { results.metadata() };
   for ( const QgsLayerMetadataProviderResult &result : std::as_const( metadata ) )
