@@ -42,36 +42,37 @@
 #include <QHBoxLayout>
 
 #include "qgsmaptip.h"
+#include "moc_qgsmaptip.cpp"
 
 
 const QString QgsMapTip::sMapTipTemplate = "<html>\n"
-    "  <head>\n"
-    "    <style>\n"
-    "    body {\n"
-    "        margin: 0;\n"
-    "        font: %1pt \"%2\";\n"
-    "        color: %3;\n"
-    "        width: %4px;\n"
-    "    }\n"
-    "    #QgsWebViewContainer {\n"
-    "        background-color: %5;\n"
-    "        border: 1px solid %6;\n"
-    "        display: inline-block;\n"
-    "        margin: 0\n"
-    "    }\n"
-    "    #QgsWebViewContainerInner {\n"
-    "        margin: 5px\n"
-    "    }\n"
-    "    </style>\n"
-    "  </head>\n"
-    "  <body>\n"
-    "    <div id='QgsWebViewContainer'>\n"
-    "      <div id='QgsWebViewContainerInner'>\n"
-    "      %7\n"
-    "      </div>\n"
-    "    </div>\n"
-    "  </body>\n"
-    "</html>\n";
+                                           "  <head>\n"
+                                           "    <style>\n"
+                                           "    body {\n"
+                                           "        margin: 0;\n"
+                                           "        font: %1pt \"%2\";\n"
+                                           "        color: %3;\n"
+                                           "        width: %4px;\n"
+                                           "    }\n"
+                                           "    #QgsWebViewContainer {\n"
+                                           "        background-color: %5;\n"
+                                           "        border: 1px solid %6;\n"
+                                           "        display: inline-block;\n"
+                                           "        margin: 0\n"
+                                           "    }\n"
+                                           "    #QgsWebViewContainerInner {\n"
+                                           "        margin: 5px\n"
+                                           "    }\n"
+                                           "    </style>\n"
+                                           "  </head>\n"
+                                           "  <body>\n"
+                                           "    <div id='QgsWebViewContainer'>\n"
+                                           "      <div id='QgsWebViewContainerInner'>\n"
+                                           "      %7\n"
+                                           "      </div>\n"
+                                           "    </div>\n"
+                                           "  </body>\n"
+                                           "</html>\n";
 
 
 QgsMapTip::QgsMapTip()
@@ -80,13 +81,10 @@ QgsMapTip::QgsMapTip()
   mMapTipVisible = false;
 
   mDelayedClearTimer.setSingleShot( true );
-  connect( &mDelayedClearTimer, &QTimer::timeout, this, [ = ]() {this->clear();} );
+  connect( &mDelayedClearTimer, &QTimer::timeout, this, [=]() { this->clear(); } );
 }
 
-void QgsMapTip::showMapTip( QgsMapLayer *pLayer,
-                            QgsPointXY &mapPosition,
-                            const QPoint &pixelPosition,
-                            QgsMapCanvas *pMapCanvas )
+void QgsMapTip::showMapTip( QgsMapLayer *pLayer, QgsPointXY &mapPosition, const QPoint &pixelPosition, QgsMapCanvas *pMapCanvas )
 {
   // Do the search using the active layer and the preferred label field for the
   // layer. The label field must be defined in the layer configuration
@@ -109,7 +107,7 @@ void QgsMapTip::showMapTip( QgsMapLayer *pLayer,
   // Show the maptip on the canvas
   QString tipText, lastTipText, tipHtml;
 
-  if ( ! mWebView )
+  if ( !mWebView )
   {
     mWebView = new QgsWebView( pMapCanvas );
     // Make the webwiew transparent
@@ -122,10 +120,10 @@ void QgsMapTip::showMapTip( QgsMapLayer *pLayer,
 
 
 #if WITH_QTWEBKIT
-    mWebView->page()->setLinkDelegationPolicy( QWebPage::DelegateAllLinks );//Handle link clicks by yourself
-    mWebView->setContextMenuPolicy( Qt::NoContextMenu ); //No context menu is allowed if you don't need it
+    mWebView->page()->setLinkDelegationPolicy( QWebPage::DelegateAllLinks ); //Handle link clicks by yourself
+    mWebView->setContextMenuPolicy( Qt::NoContextMenu );                     //No context menu is allowed if you don't need it
     connect( mWebView, &QWebView::linkClicked, this, &QgsMapTip::onLinkClicked );
-    connect( mWebView, &QWebView::loadFinished, this, [ = ]( bool ) { resizeAndMoveToolTip(); } );
+    connect( mWebView, &QWebView::loadFinished, this, [=]( bool ) { resizeAndMoveToolTip(); } );
 #endif
 
     mWebView->page()->settings()->setAttribute( QWebSettings::DeveloperExtrasEnabled, true );
@@ -135,7 +133,6 @@ void QgsMapTip::showMapTip( QgsMapLayer *pLayer,
     // Disable scrollbars, avoid random resizing issues
     mWebView->page()->mainFrame()->setScrollBarPolicy( Qt::Horizontal, Qt::ScrollBarAlwaysOff );
     mWebView->page()->mainFrame()->setScrollBarPolicy( Qt::Vertical, Qt::ScrollBarAlwaysOff );
-
   }
 
   // Only supported layer types here:
@@ -171,7 +168,7 @@ void QgsMapTip::showMapTip( QgsMapLayer *pLayer,
     // from QgsApplication::getThemeCursor, and are used to calculate the correct cursor size
     // for both hi-dpi and non-hi-dpi screens.
     double scale = Qgis::UI_SCALE_FACTOR * QgsApplication::instance()->fontMetrics().height() / 32.0;
-    cursorOffset = static_cast< int >( std::ceil( scale * 32 ) );
+    cursorOffset = static_cast<int>( std::ceil( scale * 32 ) );
   }
 
   // Ensures the map tip is never larger than the available space
@@ -192,7 +189,6 @@ void QgsMapTip::showMapTip( QgsMapLayer *pLayer,
 #if !WITH_QTWEBKIT
   resizeAndMoveToolTip();
 #endif
-
 }
 
 void QgsMapTip::resizeAndMoveToolTip()
@@ -200,7 +196,8 @@ void QgsMapTip::resizeAndMoveToolTip()
 #if WITH_QTWEBKIT
   // Get the content size
   const QWebElement container = mWebView->page()->mainFrame()->findFirstElement(
-                                  QStringLiteral( "#QgsWebViewContainer" ) );
+    QStringLiteral( "#QgsWebViewContainer" )
+  );
   const int width = container.geometry().width();
   const int height = container.geometry().height();
   mWebView->resize( width, height );
@@ -216,10 +213,10 @@ void QgsMapTip::resizeAndMoveToolTip()
     // from QgsApplication::getThemeCursor, and are used to calculate the correct cursor size
     // for both hi-dpi and non-hi-dpi screens.
     double scale = Qgis::UI_SCALE_FACTOR * QgsApplication::instance()->fontMetrics().height() / 32.0;
-    cursorOffset = static_cast< int >( std::ceil( scale * 32 ) );
+    cursorOffset = static_cast<int>( std::ceil( scale * 32 ) );
   }
 
-  if ( mMapCanvas == nullptr )
+  if ( !mMapCanvas )
   {
     mWebView->move( mPosition );
     mWebView->show();
@@ -290,8 +287,7 @@ QString QgsMapTip::fetchFeature( QgsMapLayer *layer, QgsPointXY &mapPosition, Qg
     return QString();
   }
 
-  if ( !layer->isInScaleRange( mapCanvas->mapSettings().scale() ) ||
-       ( mapCanvas->mapSettings().isTemporal() && layer->temporalProperties() && !layer->temporalProperties()->isVisibleInTemporalRange( mapCanvas->temporalRange() ) ) )
+  if ( !layer->isInScaleRange( mapCanvas->mapSettings().scale() ) || ( mapCanvas->mapSettings().isTemporal() && layer->temporalProperties() && !layer->temporalProperties()->isVisibleInTemporalRange( mapCanvas->temporalRange() ) ) )
   {
     return QString();
   }
@@ -311,7 +307,7 @@ QString QgsMapTip::fetchFeature( QgsMapLayer *layer, QgsPointXY &mapPosition, Qg
   context.appendScope( QgsExpressionContextUtils::mapLayerPositionScope( r.center() ) );
 
   const QString canvasFilter = QgsMapCanvasUtils::filterForLayer( mapCanvas, vlayer );
-  if ( canvasFilter ==  QLatin1String( "FALSE" ) )
+  if ( canvasFilter == QLatin1String( "FALSE" ) )
   {
     return QString();
   }
@@ -323,7 +319,7 @@ QString QgsMapTip::fetchFeature( QgsMapLayer *layer, QgsPointXY &mapPosition, Qg
 
   QgsFeatureRequest request;
   request.setFilterRect( r );
-  request.setFlags( QgsFeatureRequest::ExactIntersect );
+  request.setFlags( Qgis::FeatureRequestFlag::ExactIntersect );
   if ( !canvasFilter.isEmpty() )
   {
     request.setFilterExpression( canvasFilter );
@@ -340,7 +336,7 @@ QString QgsMapTip::fetchFeature( QgsMapLayer *layer, QgsPointXY &mapPosition, Qg
   renderCtx.expressionContext() << QgsExpressionContextUtils::layerScope( vlayer );
 
   bool filter = false;
-  std::unique_ptr< QgsFeatureRenderer > renderer;
+  std::unique_ptr<QgsFeatureRenderer> renderer;
   if ( vlayer->renderer() )
   {
     renderer.reset( vlayer->renderer()->clone() );
@@ -348,7 +344,7 @@ QString QgsMapTip::fetchFeature( QgsMapLayer *layer, QgsPointXY &mapPosition, Qg
     filter = renderer->capabilities() & QgsFeatureRenderer::Filter;
 
     const QString filterExpression = renderer->filter( vlayer->fields() );
-    if ( ! filterExpression.isEmpty() )
+    if ( !filterExpression.isEmpty() )
     {
       request.combineFilterExpression( filterExpression );
     }
@@ -399,8 +395,7 @@ QString QgsMapTip::fetchRaster( QgsMapLayer *layer, QgsPointXY &mapPosition, Qgs
     return QString();
   }
 
-  if ( !layer->isInScaleRange( mapCanvas->mapSettings().scale() ) ||
-       ( mapCanvas->mapSettings().isTemporal() && !layer->temporalProperties()->isVisibleInTemporalRange( mapCanvas->temporalRange() ) ) )
+  if ( !layer->isInScaleRange( mapCanvas->mapSettings().scale() ) || ( mapCanvas->mapSettings().isTemporal() && !layer->temporalProperties()->isVisibleInTemporalRange( mapCanvas->temporalRange() ) ) )
   {
     return QString();
   }
@@ -412,7 +407,7 @@ QString QgsMapTip::fetchRaster( QgsMapLayer *layer, QgsPointXY &mapPosition, Qgs
 
   const QgsPointXY mappedPosition { mapCanvas->mapSettings().mapToLayerCoordinates( layer, mapPosition ) };
 
-  if ( ! layer->extent().contains( mappedPosition ) )
+  if ( !layer->extent().contains( mappedPosition ) )
   {
     return QString();
   }
@@ -420,12 +415,11 @@ QString QgsMapTip::fetchRaster( QgsMapLayer *layer, QgsPointXY &mapPosition, Qgs
   QgsExpressionContext context( QgsExpressionContextUtils::globalProjectLayerScopes( layer ) );
   context.appendScope( QgsExpressionContextUtils::mapSettingsScope( mapCanvas->mapSettings() ) );
   context.appendScope( QgsExpressionContextUtils::mapLayerPositionScope( mappedPosition ) );
-  return  QgsExpression::replaceExpressionText( rlayer->mapTipTemplate(), &context );
+  return QgsExpression::replaceExpressionText( rlayer->mapTipTemplate(), &context );
 }
 
 QString QgsMapTip::htmlText( const QString &text, int maxWidth )
 {
-
   const QgsSettings settings;
   const QFont defaultFont = qApp->font();
   const int fontSize = defaultFont.pointSize();
@@ -486,7 +480,6 @@ QString QgsMapTip::vectorMapTipPreviewText( QgsMapLayer *layer, QgsMapCanvas *ma
 
   // Insert the map tip text into the html template
   return QgsMapTip::htmlText( tipText, mapCanvas->width() / 2 );
-
 }
 
 QString QgsMapTip::rasterMapTipPreviewText( QgsMapLayer *layer, QgsMapCanvas *mapCanvas, const QString &mapTemplate )
