@@ -32,7 +32,7 @@
 #include "qgstiledsceneproviderguimetadata.h"
 #include "qgsmbtilesvectortileguiprovider.h"
 #include "qgsvtpkvectortileguiprovider.h"
-
+#include "qgssensorthingsguiprovider.h"
 #ifdef HAVE_EPT
 #include "qgseptproviderguimetadata.h"
 #endif
@@ -64,9 +64,7 @@
  * very reason.  So there needs to be a convenient way to find a data provider
  * without accidentally adding a null meta data item to the metadata map.
 */
-static
-QgsProviderGuiMetadata *findMetadata_( QgsProviderGuiRegistry::GuiProviders const &metaData,
-                                       QString const &providerKey )
+static QgsProviderGuiMetadata *findMetadata_( QgsProviderGuiRegistry::GuiProviders const &metaData, QString const &providerKey )
 {
   const QgsProviderGuiRegistry::GuiProviders::const_iterator i = metaData.find( providerKey );
   if ( i != metaData.end() )
@@ -83,64 +81,67 @@ QgsProviderGuiRegistry::QgsProviderGuiRegistry( const QString &pluginPath )
   loadDynamicProviders( pluginPath );
 }
 
-void QgsProviderGuiRegistry::loadStaticProviders( )
+void QgsProviderGuiRegistry::loadStaticProviders()
 {
   // Register static providers
   QgsProviderGuiMetadata *gdal = new QgsGdalGuiProviderMetadata();
-  mProviders[ gdal->key() ] = gdal;
+  mProviders[gdal->key()] = gdal;
 
   QgsProviderGuiMetadata *ogr = new QgsOgrGuiProviderMetadata();
-  mProviders[ ogr->key() ] = ogr;
+  mProviders[ogr->key()] = ogr;
 
   QgsProviderGuiMetadata *vt = new QgsVectorTileProviderGuiMetadata();
-  mProviders[ vt->key() ] = vt;
+  mProviders[vt->key()] = vt;
 
   QgsProviderGuiMetadata *mbtilesVectorTiles = new QgsMbtilesVectorTileGuiProviderMetadata();
-  mProviders[ mbtilesVectorTiles->key() ] = mbtilesVectorTiles;
+  mProviders[mbtilesVectorTiles->key()] = mbtilesVectorTiles;
 
   QgsProviderGuiMetadata *vtpkVectorTiles = new QgsVtpkVectorTileGuiProviderMetadata();
-  mProviders[ vtpkVectorTiles->key() ] = vtpkVectorTiles;
+  mProviders[vtpkVectorTiles->key()] = vtpkVectorTiles;
 
 #ifdef HAVE_EPT
   QgsProviderGuiMetadata *ept = new QgsEptProviderGuiMetadata();
-  mProviders[ ept->key() ] = ept;
+  mProviders[ept->key()] = ept;
 #endif
 
 #ifdef HAVE_COPC
   QgsProviderGuiMetadata *copc = new QgsCopcProviderGuiMetadata();
-  mProviders[ copc->key() ] = copc;
+  mProviders[copc->key()] = copc;
 #endif
 
   // only show point cloud option if we have at least one point cloud provider available!
   if ( !QgsProviderRegistry::instance()->filePointCloudFilters().isEmpty() )
   {
     QgsProviderGuiMetadata *pointcloud = new QgsPointCloudProviderGuiMetadata();
-    mProviders[ pointcloud->key() ] = pointcloud;
+    mProviders[pointcloud->key()] = pointcloud;
   }
 
   QgsProviderGuiMetadata *tiledScene = new QgsTiledSceneProviderGuiMetadata();
-  mProviders[ tiledScene ->key() ] = tiledScene ;
+  mProviders[tiledScene->key()] = tiledScene;
+
+  QgsProviderGuiMetadata *sensorThings = new QgsSensorThingsProviderGuiMetadata();
+  mProviders[sensorThings->key()] = sensorThings;
 
 #ifdef HAVE_STATIC_PROVIDERS
   QgsProviderGuiMetadata *wms = new QgsWmsProviderGuiMetadata();
-  mProviders[ wms->key() ] = wms;
+  mProviders[wms->key()] = wms;
   QgsProviderGuiMetadata *wcs = new QgsWcsProviderGuiMetadata();
-  mProviders[ wcs->key() ] = wcs;
+  mProviders[wcs->key()] = wcs;
   QgsProviderGuiMetadata *delimitedtext = new QgsDelimitedTextProviderGuiMetadata();
-  mProviders[ delimitedtext->key() ] = delimitedtext;
+  mProviders[delimitedtext->key()] = delimitedtext;
   QgsProviderGuiMetadata *arc = new QgsArcGisRestProviderGuiMetadata();
-  mProviders[ arc->key() ] = arc;
+  mProviders[arc->key()] = arc;
 #ifdef HAVE_SPATIALITE
   QgsProviderGuiMetadata *spatialite = new QgsSpatiaLiteProviderGuiMetadata();
-  mProviders[ spatialite->key() ] = spatialite;
+  mProviders[spatialite->key()] = spatialite;
   QgsProviderGuiMetadata *wfs = new QgsWfsProviderGuiMetadata();
-  mProviders[ wfs->key() ] = wfs;
+  mProviders[wfs->key()] = wfs;
   QgsProviderGuiMetadata *virtuallayer = new QgsVirtualLayerProviderGuiMetadata();
-  mProviders[ virtuallayer->key() ] = virtuallayer;
+  mProviders[virtuallayer->key()] = virtuallayer;
 #endif
 #ifdef HAVE_POSTGRESQL
   QgsProviderGuiMetadata *postgres = new QgsPostgresProviderGuiMetadata();
-  mProviders[ postgres->key() ] = postgres;
+  mProviders[postgres->key()] = postgres;
 #endif
 #endif
 }
@@ -151,16 +152,16 @@ void QgsProviderGuiRegistry::loadDynamicProviders( const QString &pluginPath )
   Q_UNUSED( pluginPath )
   QgsDebugMsgLevel( QStringLiteral( "Forced only static GUI providers" ), 2 );
 #else
-  typedef QgsProviderGuiMetadata *factory_function( );
+  typedef QgsProviderGuiMetadata *factory_function();
 
   // add dynamic providers
   QDir mLibraryDirectory( pluginPath );
   mLibraryDirectory.setSorting( QDir::Name | QDir::IgnoreCase );
   mLibraryDirectory.setFilter( QDir::Files | QDir::NoSymLinks );
 
-#if defined(Q_OS_WIN) || defined(__CYGWIN__)
+#if defined( Q_OS_WIN ) || defined( __CYGWIN__ )
   mLibraryDirectory.setNameFilters( QStringList( "*.dll" ) );
-#elif defined(ANDROID)
+#elif defined( ANDROID )
   mLibraryDirectory.setNameFilters( QStringList( "*provider.so" ) );
 #else
   mLibraryDirectory.setNameFilters( QStringList( QStringLiteral( "*.so" ) ) );
@@ -198,11 +199,11 @@ void QgsProviderGuiRegistry::loadDynamicProviders( const QString &pluginPath )
     if ( myLib.load() )
     {
       QFunctionPointer func = myLib.resolve( QStringLiteral( "providerGuiMetadataFactory" ).toLatin1().data() );
-      factory_function *function = reinterpret_cast< factory_function * >( cast_to_fptr( func ) );
+      factory_function *function = reinterpret_cast<factory_function *>( cast_to_fptr( func ) );
       if ( !function )
         continue;
 
-      QgsProviderGuiMetadata *meta = function( );
+      QgsProviderGuiMetadata *meta = function();
 
       if ( !meta )
         continue;
@@ -251,7 +252,7 @@ QList<QgsSourceSelectProvider *> QgsProviderGuiRegistry::sourceSelectProviders(
   QgsProviderGuiMetadata *meta = findMetadata_( mProviders, providerKey );
   if ( meta )
     return meta->sourceSelectProviders();
-  return QList<QgsSourceSelectProvider *> ();
+  return QList<QgsSourceSelectProvider *>();
 }
 
 QList<QgsProjectStorageGuiProvider *> QgsProviderGuiRegistry::projectStorageGuiProviders( const QString &providerKey )
