@@ -20,6 +20,7 @@
 #include "qgsrasterresampler.h"
 #include "qgsrasterresamplefilter.h"
 #include "qgsresamplingutils.h"
+#include "moc_qgsresamplingutils.cpp"
 #include "qgsbilinearrasterresampler.h"
 #include "qgscubicrasterresampler.h"
 
@@ -32,11 +33,7 @@
 
 QgsResamplingUtils::QgsResamplingUtils() = default;
 
-void QgsResamplingUtils::initWidgets( QgsRasterLayer *rasterLayer,
-                                      QComboBox  *zoomedInResamplingComboBox,
-                                      QComboBox *zoomedOutResamplingComboBox,
-                                      QDoubleSpinBox *maximumOversamplingSpinBox,
-                                      QCheckBox *cbEarlyResampling )
+void QgsResamplingUtils::initWidgets( QgsRasterLayer *rasterLayer, QComboBox *zoomedInResamplingComboBox, QComboBox *zoomedOutResamplingComboBox, QDoubleSpinBox *maximumOversamplingSpinBox, QCheckBox *cbEarlyResampling )
 {
   mRasterLayer = rasterLayer;
   mZoomedInResamplingComboBox = zoomedInResamplingComboBox;
@@ -44,7 +41,7 @@ void QgsResamplingUtils::initWidgets( QgsRasterLayer *rasterLayer,
   mMaximumOversamplingSpinBox = maximumOversamplingSpinBox;
   mCbEarlyResampling = cbEarlyResampling;
 
-  for ( QComboBox *combo :  {mZoomedInResamplingComboBox, mZoomedOutResamplingComboBox } )
+  for ( QComboBox *combo : { mZoomedInResamplingComboBox, mZoomedOutResamplingComboBox } )
   {
     combo->addItem( QObject::tr( "Nearest Neighbour" ), static_cast<int>( QgsRasterDataProvider::ResamplingMethod::Nearest ) );
     combo->addItem( QObject::tr( "Bilinear (2x2 Kernel)" ), static_cast<int>( QgsRasterDataProvider::ResamplingMethod::Bilinear ) );
@@ -56,8 +53,7 @@ void QgsResamplingUtils::initWidgets( QgsRasterLayer *rasterLayer,
     addExtraEarlyResamplingMethodsToCombos();
   }
 
-  QObject::connect( mCbEarlyResampling, &QCheckBox::toggled, this, [ = ]( bool state )
-  {
+  QObject::connect( mCbEarlyResampling, &QCheckBox::toggled, this, [=]( bool state ) {
     if ( state )
       addExtraEarlyResamplingMethodsToCombos();
     else
@@ -69,7 +65,8 @@ void QgsResamplingUtils::refreshWidgetsFromLayer()
 {
   QgsRasterDataProvider *provider = mRasterLayer->dataProvider();
   mCbEarlyResampling->setVisible(
-    provider && ( provider->providerCapabilities() & QgsRasterDataProvider::ProviderHintCanPerformProviderResampling ) );
+    provider && ( provider->providerCapabilities() & Qgis::RasterProviderCapability::ProviderHintCanPerformProviderResampling )
+  );
   mCbEarlyResampling->setChecked( mRasterLayer->resamplingStage() == Qgis::RasterResamplingStage::Provider );
 
   switch ( mRasterLayer->resamplingStage() )
@@ -136,12 +133,12 @@ void QgsResamplingUtils::refreshWidgetsFromLayer()
 
 void QgsResamplingUtils::refreshLayerFromWidgets()
 {
-  const QgsRasterDataProvider::ResamplingMethod zoomedInMethod =
-    static_cast< QgsRasterDataProvider::ResamplingMethod >(
-      mZoomedInResamplingComboBox->itemData( mZoomedInResamplingComboBox->currentIndex() ).toInt() );
-  const QgsRasterDataProvider::ResamplingMethod zoomedOutMethod =
-    static_cast< QgsRasterDataProvider::ResamplingMethod >(
-      mZoomedOutResamplingComboBox->itemData( mZoomedOutResamplingComboBox->currentIndex() ).toInt() );
+  const QgsRasterDataProvider::ResamplingMethod zoomedInMethod = static_cast<QgsRasterDataProvider::ResamplingMethod>(
+    mZoomedInResamplingComboBox->itemData( mZoomedInResamplingComboBox->currentIndex() ).toInt()
+  );
+  const QgsRasterDataProvider::ResamplingMethod zoomedOutMethod = static_cast<QgsRasterDataProvider::ResamplingMethod>(
+    mZoomedOutResamplingComboBox->itemData( mZoomedOutResamplingComboBox->currentIndex() ).toInt()
+  );
 
   mRasterLayer->setResamplingStage( mCbEarlyResampling->isChecked() ? Qgis::RasterResamplingStage::Provider : Qgis::RasterResamplingStage::ResampleFilter );
   QgsRasterDataProvider *provider = mRasterLayer->dataProvider();
@@ -156,7 +153,7 @@ void QgsResamplingUtils::refreshLayerFromWidgets()
   QgsRasterResampleFilter *resampleFilter = mRasterLayer->resampleFilter();
   if ( resampleFilter )
   {
-    std::unique_ptr< QgsRasterResampler > zoomedInResampler;
+    std::unique_ptr<QgsRasterResampler> zoomedInResampler;
 
     switch ( zoomedInMethod )
     {
@@ -164,11 +161,11 @@ void QgsResamplingUtils::refreshLayerFromWidgets()
         break;
 
       case QgsRasterDataProvider::ResamplingMethod::Bilinear:
-        zoomedInResampler = std::make_unique< QgsBilinearRasterResampler >();
+        zoomedInResampler = std::make_unique<QgsBilinearRasterResampler>();
         break;
 
       case QgsRasterDataProvider::ResamplingMethod::Cubic:
-        zoomedInResampler = std::make_unique< QgsCubicRasterResampler >();
+        zoomedInResampler = std::make_unique<QgsCubicRasterResampler>();
         break;
 
       case QgsRasterDataProvider::ResamplingMethod::CubicSpline:
@@ -184,7 +181,7 @@ void QgsResamplingUtils::refreshLayerFromWidgets()
     resampleFilter->setZoomedInResampler( zoomedInResampler.release() );
 
     //raster resampling
-    std::unique_ptr< QgsRasterResampler > zoomedOutResampler;
+    std::unique_ptr<QgsRasterResampler> zoomedOutResampler;
 
     switch ( zoomedOutMethod )
     {
@@ -192,11 +189,11 @@ void QgsResamplingUtils::refreshLayerFromWidgets()
         break;
 
       case QgsRasterDataProvider::ResamplingMethod::Bilinear:
-        zoomedOutResampler = std::make_unique< QgsBilinearRasterResampler >();
+        zoomedOutResampler = std::make_unique<QgsBilinearRasterResampler>();
         break;
 
       case QgsRasterDataProvider::ResamplingMethod::Cubic:
-        zoomedOutResampler = std::make_unique< QgsCubicRasterResampler >();
+        zoomedOutResampler = std::make_unique<QgsCubicRasterResampler>();
         break;
 
 
@@ -220,7 +217,7 @@ void QgsResamplingUtils::addExtraEarlyResamplingMethodsToCombos()
   if ( mZoomedInResamplingComboBox->findData( static_cast<int>( QgsRasterDataProvider::ResamplingMethod::CubicSpline ) ) != -1 )
     return; // already present
 
-  for ( QComboBox *combo : {mZoomedInResamplingComboBox, mZoomedOutResamplingComboBox } )
+  for ( QComboBox *combo : { mZoomedInResamplingComboBox, mZoomedOutResamplingComboBox } )
   {
     combo->addItem( QObject::tr( "Cubic B-Spline (4x4 Kernel)" ), static_cast<int>( QgsRasterDataProvider::ResamplingMethod::CubicSpline ) );
     combo->addItem( QObject::tr( "Lanczos (6x6 Kernel)" ), static_cast<int>( QgsRasterDataProvider::ResamplingMethod::Lanczos ) );
@@ -235,7 +232,7 @@ void QgsResamplingUtils::removeExtraEarlyResamplingMethodsFromCombos()
   if ( mZoomedInResamplingComboBox->findData( static_cast<int>( QgsRasterDataProvider::ResamplingMethod::CubicSpline ) ) == -1 )
     return; // already removed
 
-  for ( QComboBox *combo : {mZoomedInResamplingComboBox, mZoomedOutResamplingComboBox } )
+  for ( QComboBox *combo : { mZoomedInResamplingComboBox, mZoomedOutResamplingComboBox } )
   {
     for ( const QgsRasterDataProvider::ResamplingMethod method :
           {
@@ -246,7 +243,7 @@ void QgsResamplingUtils::removeExtraEarlyResamplingMethodsFromCombos()
             QgsRasterDataProvider::ResamplingMethod::Gauss
           } )
     {
-      combo->removeItem( combo->findData( static_cast< int >( method ) ) );
+      combo->removeItem( combo->findData( static_cast<int>( method ) ) );
     }
   }
 }
