@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsdelimitedtextprovider.h"
+#include "moc_qgsdelimitedtextprovider.cpp"
 
 #include <QtGlobal>
 #include <QFile>
@@ -60,28 +61,19 @@ static const int SUBSET_ID_THRESHOLD_FACTOR = 10;
 QRegularExpression QgsDelimitedTextProvider::sWktPrefixRegexp( QStringLiteral( "^\\s*(?:\\d+\\s+|SRID\\=\\d+\\;)" ), QRegularExpression::CaseInsensitiveOption );
 QRegularExpression QgsDelimitedTextProvider::sCrdDmsRegexp( QStringLiteral( "^\\s*(?:([-+nsew])\\s*)?(\\d{1,3})(?:[^0-9.]+([0-5]?\\d))?[^0-9.]+([0-5]?\\d(?:\\.\\d+)?)[^0-9.]*([-+nsew])?\\s*$" ), QRegularExpression::CaseInsensitiveOption );
 
-QgsDelimitedTextProvider::QgsDelimitedTextProvider( const QString &uri, const ProviderOptions &options, QgsDataProvider::ReadFlags flags )
+QgsDelimitedTextProvider::QgsDelimitedTextProvider( const QString &uri, const ProviderOptions &options, Qgis::DataProviderReadFlags flags )
   : QgsVectorDataProvider( uri, options, flags )
 {
-
   // Add supported types to enable creating expression fields in field calculator
-  setNativeTypes( QList< NativeType >()
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Int ), QStringLiteral( "integer" ), QVariant::Int, 0, 10 )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::LongLong ), QStringLiteral( "longlong" ), QVariant::LongLong )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Double ), QStringLiteral( "double" ), QVariant::Double, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Bool ), QStringLiteral( "bool" ), QVariant::Bool, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( tr( "Text, unlimited length (text)" ), QStringLiteral( "text" ), QVariant::String, -1, -1, -1, -1 )
+  setNativeTypes( QList<NativeType>() << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::Int ), QStringLiteral( "integer" ), QMetaType::Type::Int, 0, 10 ) << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::LongLong ), QStringLiteral( "longlong" ), QMetaType::Type::LongLong ) << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::Double ), QStringLiteral( "double" ), QMetaType::Type::Double, -1, -1, -1, -1 ) << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::Bool ), QStringLiteral( "bool" ), QMetaType::Type::Bool, -1, -1, -1, -1 ) << QgsVectorDataProvider::NativeType( tr( "Text, unlimited length (text)" ), QStringLiteral( "text" ), QMetaType::Type::QString, -1, -1, -1, -1 )
 
-                  // date type
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Date ), QStringLiteral( "date" ), QVariant::Date, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Time ), QStringLiteral( "time" ), QVariant::Time, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::DateTime ), QStringLiteral( "datetime" ), QVariant::DateTime, -1, -1, -1, -1 )
-                );
+                                      // date type
+                                      << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QDate ), QStringLiteral( "date" ), QMetaType::Type::QDate, -1, -1, -1, -1 ) << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QTime ), QStringLiteral( "time" ), QMetaType::Type::QTime, -1, -1, -1, -1 ) << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QDateTime ), QStringLiteral( "datetime" ), QMetaType::Type::QDateTime, -1, -1, -1, -1 ) );
 
   QgsDebugMsgLevel( "Delimited text file uri is " + uri, 2 );
 
   const QUrl url = QUrl::fromEncoded( uri.toUtf8() );
-  mFile = std::make_unique< QgsDelimitedTextFile >();
+  mFile = std::make_unique<QgsDelimitedTextFile>();
   mFile->setFromUrl( url );
 
   QString subset;
@@ -125,7 +117,7 @@ QgsDelimitedTextProvider::QgsDelimitedTextProvider( const QString &uri, const Pr
 
       if ( query.hasQueryItem( QStringLiteral( "xyDms" ) ) )
       {
-        mXyDms = ! query.queryItemValue( QStringLiteral( "xyDms" ) ).toLower().startsWith( 'n' );
+        mXyDms = !query.queryItemValue( QStringLiteral( "xyDms" ) ).toLower().startsWith( 'n' );
       }
     }
     else
@@ -136,7 +128,7 @@ QgsDelimitedTextProvider::QgsDelimitedTextProvider( const QString &uri, const Pr
 
   mDetectTypes = true;
   if ( query.hasQueryItem( QStringLiteral( "detectTypes" ) ) )
-    mDetectTypes = ! query.queryItemValue( QStringLiteral( "detectTypes" ) ).toLower().startsWith( 'n' );
+    mDetectTypes = !query.queryItemValue( QStringLiteral( "detectTypes" ) ).toLower().startsWith( 'n' );
 
   if ( query.hasQueryItem( QStringLiteral( "decimalPoint" ) ) )
     mDecimalPoint = query.queryItemValue( QStringLiteral( "decimalPoint" ) );
@@ -146,12 +138,12 @@ QgsDelimitedTextProvider::QgsDelimitedTextProvider( const QString &uri, const Pr
 
   if ( query.hasQueryItem( QStringLiteral( "subsetIndex" ) ) )
   {
-    mBuildSubsetIndex = ! query.queryItemValue( QStringLiteral( "subsetIndex" ) ).toLower().startsWith( 'n' );
+    mBuildSubsetIndex = !query.queryItemValue( QStringLiteral( "subsetIndex" ) ).toLower().startsWith( 'n' );
   }
 
   if ( query.hasQueryItem( QStringLiteral( "spatialIndex" ) ) )
   {
-    mBuildSpatialIndex = ! query.queryItemValue( QStringLiteral( "spatialIndex" ) ).toLower().startsWith( 'n' );
+    mBuildSpatialIndex = !query.queryItemValue( QStringLiteral( "spatialIndex" ) ).toLower().startsWith( 'n' );
   }
 
   if ( query.hasQueryItem( QStringLiteral( "subset" ) ) )
@@ -161,10 +153,11 @@ QgsDelimitedTextProvider::QgsDelimitedTextProvider( const QString &uri, const Pr
     QgsDebugMsgLevel( "subset is: " + subset, 2 );
   }
 
-  if ( query.hasQueryItem( QStringLiteral( "quiet" ) ) ) mShowInvalidLines = false;
+  if ( query.hasQueryItem( QStringLiteral( "quiet" ) ) )
+    mShowInvalidLines = false;
 
   // Parse and store user-defined field types and boolean literals
-  const QList<QPair<QString, QString> > queryItems { query.queryItems( QUrl::ComponentFormattingOption::FullyDecoded ) };
+  const QList<QPair<QString, QString>> queryItems { query.queryItems( QUrl::ComponentFormattingOption::FullyDecoded ) };
   for ( const QPair<QString, QString> &queryItem : std::as_const( queryItems ) )
   {
     if ( queryItem.first.compare( QStringLiteral( "field" ), Qt::CaseSensitivity::CaseInsensitive ) == 0 )
@@ -182,17 +175,18 @@ QgsDelimitedTextProvider::QgsDelimitedTextProvider( const QString &uri, const Pr
   if ( query.hasQueryItem( QStringLiteral( "booleanTrue" ) ) && query.hasQueryItem( QStringLiteral( "booleanFalse" ) ) )
   {
     mUserDefinedBooleanLiterals = qMakePair<QString, QString>(
-                                    query.queryItemValue( QStringLiteral( "booleanTrue" ), QUrl::ComponentFormattingOption::FullyDecoded ),
-                                    query.queryItemValue( QStringLiteral( "booleanFalse" ), QUrl::ComponentFormattingOption::FullyDecoded ) );
+      query.queryItemValue( QStringLiteral( "booleanTrue" ), QUrl::ComponentFormattingOption::FullyDecoded ),
+      query.queryItemValue( QStringLiteral( "booleanFalse" ), QUrl::ComponentFormattingOption::FullyDecoded )
+    );
   }
 
   // Do an initial scan of the file to determine field names, types,
   // geometry type (for Wkt), extents, etc.  Parameter value subset.isEmpty()
   // avoid redundant building indexes if we will be building a subset string,
   // in which case indexes will be rebuilt.
-  scanFile( subset.isEmpty() && ! flags.testFlag( QgsDataProvider::ReadFlag::SkipGetExtent ), /* force full scan */ false );
+  scanFile( subset.isEmpty() && !flags.testFlag( Qgis::DataProviderReadFlag::SkipGetExtent ), /* force full scan */ false );
 
-  if ( ! subset.isEmpty() )
+  if ( !subset.isEmpty() )
   {
     setSubsetString( subset );
   }
@@ -204,7 +198,7 @@ QgsAbstractFeatureSource *QgsDelimitedTextProvider::featureSource() const
 {
   // If the file has become invalid, rescan to check that it is still invalid.
   //
-  if ( ( mLayerValid && ! mValid ) || mRescanRequired )
+  if ( ( mLayerValid && !mValid ) || mRescanRequired )
     const_cast<QgsDelimitedTextProvider *>( this )->rescanFile();
 
   return new QgsDelimitedTextFeatureSource( this );
@@ -215,10 +209,13 @@ QStringList QgsDelimitedTextProvider::readCsvtFieldTypes( const QString &filenam
   // Look for a file with the same name as the data file, but an extra 't' or 'T' at the end
   QStringList types;
   QFileInfo csvtInfo( filename + 't' );
-  if ( ! csvtInfo.exists() ) csvtInfo.setFile( filename + 'T' );
-  if ( ! csvtInfo.exists() ) return types;
+  if ( !csvtInfo.exists() )
+    csvtInfo.setFile( filename + 'T' );
+  if ( !csvtInfo.exists() )
+    return types;
   QFile csvtFile( csvtInfo.filePath() );
-  if ( ! csvtFile.open( QIODevice::ReadOnly ) ) return types;
+  if ( !csvtFile.open( QIODevice::ReadOnly ) )
+    return types;
 
 
   // If anything goes wrong here, just ignore it, as the file
@@ -232,11 +229,13 @@ QStringList QgsDelimitedTextProvider::readCsvtFieldTypes( const QString &filenam
   {
     QTextStream csvtStream( &csvtFile );
     strTypeList = csvtStream.readLine();
-    if ( strTypeList.isEmpty() ) return types;
+    if ( strTypeList.isEmpty() )
+      return types;
     QString extra = csvtStream.readLine();
-    while ( ! extra.isNull() )
+    while ( !extra.isNull() )
     {
-      if ( ! extra.isEmpty() ) return types;
+      if ( !extra.isEmpty() )
+        return types;
       extra = csvtStream.readLine();
     }
   }
@@ -257,7 +256,10 @@ QStringList QgsDelimitedTextProvider::readCsvtFieldTypes( const QString &filenam
   if ( !match.hasMatch() )
   {
     // Looks like this was supposed to be a CSVT file, so report bad formatted string
-    if ( message ) { *message = tr( "File type string in %1 is not correctly formatted" ).arg( csvtInfo.fileName() ); }
+    if ( message )
+    {
+      *message = tr( "File type string in %1 is not correctly formatted" ).arg( csvtInfo.fileName() );
+    }
     return types;
   }
 
@@ -302,7 +304,7 @@ void QgsDelimitedTextProvider::resetIndexes() const
 
   mSubsetIndex.clear();
   if ( mBuildSpatialIndex && mGeomRep != GeomNone )
-    mSpatialIndex = std::make_unique< QgsSpatialIndex >();
+    mSpatialIndex = std::make_unique<QgsSpatialIndex>();
 }
 
 bool QgsDelimitedTextProvider::createSpatialIndex()
@@ -321,9 +323,9 @@ bool QgsDelimitedTextProvider::createSpatialIndex()
   return true;
 }
 
-QgsFeatureSource::SpatialIndexPresence QgsDelimitedTextProvider::hasSpatialIndex() const
+Qgis::SpatialIndexPresence QgsDelimitedTextProvider::hasSpatialIndex() const
 {
-  return mSpatialIndex ? QgsFeatureSource::SpatialIndexPresent : QgsFeatureSource::SpatialIndexNotPresent;
+  return mSpatialIndex ? Qgis::SpatialIndexPresence::Present : Qgis::SpatialIndexPresence::NotPresent;
 }
 
 // Really want to merge scanFile and rescan into single code.  Currently the reason
@@ -358,7 +360,7 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
 
   const bool buildSubsetIndex = buildIndexes && mBuildSubsetIndex && mGeomRep != GeomNone;
 
-  if ( ! mFile->isValid() )
+  if ( !mFile->isValid() )
   {
     // uri is invalid so the layer must be too...
 
@@ -376,7 +378,7 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
   if ( forceFullScan )
   {
     const QUrl url { mFile->url() };
-    mFile.reset( new QgsDelimitedTextFile( ) );
+    mFile.reset( new QgsDelimitedTextFile() );
     mFile->setFromUrl( url );
   }
 
@@ -439,18 +441,18 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
   long nInvalidGeometry = 0;
   long nEmptyGeometry = 0;
   mNumberFeatures = 0;
-  mExtent = QgsRectangle();
+  mExtent = QgsBox3D();
 
   struct FieldTypeInformation
   {
-    bool isEmpty = true;
-    bool couldBeInt = false;
-    bool couldBeLongLong = false;
-    bool couldBeDouble = false;
-    bool couldBeDateTime = false;
-    bool couldBeDate = false;
-    bool couldBeTime = false;
-    bool couldBeBool = false;
+      bool isEmpty = true;
+      bool couldBeInt = false;
+      bool couldBeLongLong = false;
+      bool couldBeDouble = false;
+      bool couldBeDateTime = false;
+      bool couldBeDate = false;
+      bool couldBeTime = false;
+      bool couldBeBool = false;
   };
 
   QVector<FieldTypeInformation> fieldTypeInformation;
@@ -513,7 +515,7 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
               {
                 mNumberFeatures++;
                 mWkbType = type;
-                mExtent = geom.boundingBox();
+                mExtent = geom.boundingBox3D();
                 foundFirstGeometry = true;
               }
               else
@@ -521,8 +523,8 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
                 mNumberFeatures++;
                 if ( geom.isMultipart() )
                   mWkbType = type;
-                const QgsRectangle bbox( geom.boundingBox() );
-                mExtent.combineExtentWith( bbox );
+                const QgsBox3D bbox( geom.boundingBox3D() );
+                mExtent.combineWith( bbox );
               }
               if ( buildSpatialIndex )
               {
@@ -576,12 +578,12 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
 
           if ( foundFirstGeometry )
           {
-            mExtent.combineExtentWith( pt.x(), pt.y() );
+            mExtent.combineWith( pt.x(), pt.y(), pt.z() );
           }
           else
           {
             // Extent for the first point is just the first point
-            mExtent.set( pt.x(), pt.y(), pt.x(), pt.y() );
+            mExtent = QgsBox3D( pt.x(), pt.y(), pt.z(), pt.x(), pt.y(), pt.z() );
             mWkbType = Qgis::WkbType::Point;
             if ( mZFieldIndex > -1 )
               mWkbType = QgsWkbTypes::addZ( mWkbType );
@@ -606,6 +608,12 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
           recordInvalidLine( tr( "Invalid X or Y fields at line %1" ) );
         }
       }
+
+      if ( !QgsWkbTypes::hasZ( mWkbType ) )
+      {
+        mExtent.setZMinimum( std::numeric_limits<double>::quiet_NaN() );
+        mExtent.setZMinimum( std::numeric_limits<double>::quiet_NaN() );
+      }
     }
     else
     {
@@ -613,6 +621,8 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
       mNumberFeatures++;
     }
 
+    elevationProperties()->setContainsElevationData( QgsWkbTypes::hasZ( mWkbType ) );
+
     // Progress changed every 100 features
     if ( feedback && mNumberFeatures % 100 == 0 )
     {
@@ -659,7 +669,7 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
         typeInformation->couldBeBool = true;
       }
 
-      if ( ! mDetectTypes )
+      if ( !mDetectTypes )
       {
         continue;
       }
@@ -670,11 +680,11 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
       if ( typeInformation->couldBeBool )
       {
         typeInformation->couldBeBool = false;
-        if ( ! boolCandidates.contains( i ) )
+        if ( !boolCandidates.contains( i ) )
         {
-          boolCandidates[ i ] = QPair<QString, QString>();
+          boolCandidates[i] = QPair<QString, QString>();
         }
-        if ( ! boolCandidates[i].first.isEmpty() )
+        if ( !boolCandidates[i].first.isEmpty() )
         {
           typeInformation->couldBeBool = value.compare( boolCandidates[i].first, Qt::CaseSensitivity::CaseInsensitive ) == 0 || value.compare( boolCandidates[i].second, Qt::CaseSensitivity::CaseInsensitive ) == 0;
         }
@@ -694,21 +704,21 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
 
       if ( typeInformation->couldBeInt )
       {
-        ( void )value.toInt( &typeInformation->couldBeInt );
+        ( void ) value.toInt( &typeInformation->couldBeInt );
       }
 
       if ( typeInformation->couldBeLongLong && !typeInformation->couldBeInt )
       {
-        ( void )value.toLongLong( &typeInformation->couldBeLongLong );
+        ( void ) value.toLongLong( &typeInformation->couldBeLongLong );
       }
 
       if ( typeInformation->couldBeDouble && !typeInformation->couldBeLongLong )
       {
-        if ( ! mDecimalPoint.isEmpty() )
+        if ( !mDecimalPoint.isEmpty() )
         {
           value.replace( mDecimalPoint, QLatin1String( "." ) );
         }
-        ( void )value.toDouble( &typeInformation->couldBeDouble );
+        ( void ) value.toDouble( &typeInformation->couldBeDouble );
       }
 
       if ( typeInformation->couldBeDateTime )
@@ -735,7 +745,7 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
     }
 
     // In case of fast scan we exit after the third record (to avoid detecting booleans)
-    if ( ! forceFullScan && mReadFlags.testFlag( ReadFlag::SkipFullScan ) && mNumberFeatures > 2 )
+    if ( !forceFullScan && mReadFlags.testFlag( Qgis::DataProviderReadFlag::SkipFullScan ) && mNumberFeatures > 2 )
     {
       break;
     }
@@ -770,13 +780,13 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
 
     // Add the field index lookup for the column
     attributeColumns.append( fieldIdx );
-    QVariant::Type fieldType = QVariant::String;
+    QMetaType::Type fieldType = QMetaType::Type::QString;
     QString typeName = QStringLiteral( "text" );
 
     // User-defined types take precedence over all
-    if ( ! mUserDefinedFieldTypes.value( fieldNames[ fieldIdx ] ).isEmpty() )
+    if ( !mUserDefinedFieldTypes.value( fieldNames[fieldIdx] ).isEmpty() )
     {
-      typeName = mUserDefinedFieldTypes.value( fieldNames[ fieldIdx ] );
+      typeName = mUserDefinedFieldTypes.value( fieldNames[fieldIdx] );
     }
     else
     {
@@ -837,32 +847,32 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
 
     if ( typeName == QLatin1String( "bool" ) )
     {
-      fieldType = QVariant::Bool;
+      fieldType = QMetaType::Type::Bool;
       mFieldBooleanLiterals.insert( fieldIdx - fieldIdxOffset, boolCandidates[fieldIdx] );
     }
     else if ( typeName == QLatin1String( "integer" ) )
     {
-      fieldType = QVariant::Int;
+      fieldType = QMetaType::Type::Int;
     }
     else if ( typeName == QLatin1String( "longlong" ) )
     {
-      fieldType = QVariant::LongLong;
+      fieldType = QMetaType::Type::LongLong;
     }
     else if ( typeName == QLatin1String( "double" ) )
     {
-      fieldType = QVariant::Double;
+      fieldType = QMetaType::Type::Double;
     }
     else if ( typeName == QLatin1String( "datetime" ) )
     {
-      fieldType = QVariant::DateTime;
+      fieldType = QMetaType::Type::QDateTime;
     }
     else if ( typeName == QLatin1String( "date" ) )
     {
-      fieldType = QVariant::Date;
+      fieldType = QMetaType::Type::QDate;
     }
     else if ( typeName == QLatin1String( "time" ) )
     {
-      fieldType = QVariant::Time;
+      fieldType = QMetaType::Type::QTime;
     }
     else
     {
@@ -873,11 +883,11 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
   }
 
   QgsDebugMsgLevel( "Field count for the delimited text file is " + QString::number( attributeFields.size() ), 2 );
-  QgsDebugMsgLevel( "geometry type is: " + QString::number( static_cast< quint32>( mWkbType ) ), 2 );
+  QgsDebugMsgLevel( "geometry type is: " + QString::number( static_cast<quint32>( mWkbType ) ), 2 );
   QgsDebugMsgLevel( "feature count is: " + QString::number( mNumberFeatures ), 2 );
 
   QStringList warnings;
-  if ( ! csvtMessage.isEmpty() )
+  if ( !csvtMessage.isEmpty() )
     warnings.append( csvtMessage );
   if ( nBadFormatRecords > 0 )
     warnings.append( tr( "%n record(s) discarded due to invalid format", nullptr, nBadFormatRecords ) );
@@ -899,7 +909,7 @@ void QgsDelimitedTextProvider::scanFile( bool buildIndexes, bool forceFullScan,
     long recordCount = mFile->recordCount();
     recordCount -= recordCount / SUBSET_ID_THRESHOLD_FACTOR;
     mUseSubsetIndex = mSubsetIndex.size() < recordCount;
-    if ( ! mUseSubsetIndex )
+    if ( !mUseSubsetIndex )
       mSubsetIndex = QList<quintptr>();
   }
 
@@ -926,7 +936,7 @@ void QgsDelimitedTextProvider::rescanFile() const
   // In case file has been rewritten check that it is still valid
 
   mValid = mLayerValid && mFile->isValid();
-  if ( ! mValid )
+  if ( !mValid )
     return;
 
   // Open the file and get number of rows, etc. We assume that the
@@ -977,7 +987,7 @@ void QgsDelimitedTextProvider::rescanFile() const
   mUseSubsetIndex = false;
   QgsFeatureIterator fi = getFeatures( QgsFeatureRequest() );
   mNumberFeatures = 0;
-  mExtent = QgsRectangle();
+  mExtent = QgsBox3D();
   QgsFeature f;
   bool foundFirstGeometry = false;
   while ( fi.nextFeature( f ) )
@@ -986,13 +996,13 @@ void QgsDelimitedTextProvider::rescanFile() const
     {
       if ( !foundFirstGeometry )
       {
-        mExtent = f.geometry().boundingBox();
+        mExtent = f.geometry().boundingBox3D();
         foundFirstGeometry = true;
       }
       else
       {
-        const QgsRectangle bbox( f.geometry().boundingBox() );
-        mExtent.combineExtentWith( bbox );
+        const QgsBox3D bbox( f.geometry().boundingBox3D() );
+        mExtent.combineWith( bbox );
       }
       if ( buildSpatialIndex )
         mSpatialIndex->addFeature( f );
@@ -1001,12 +1011,19 @@ void QgsDelimitedTextProvider::rescanFile() const
       mSubsetIndex.append( ( quintptr ) f.id() );
     mNumberFeatures++;
   }
+
+  if ( !QgsWkbTypes::hasZ( mWkbType ) )
+  {
+    mExtent.setZMinimum( std::numeric_limits<double>::quiet_NaN() );
+    mExtent.setZMinimum( std::numeric_limits<double>::quiet_NaN() );
+  }
+
   if ( buildSubsetIndex )
   {
     long recordCount = mFile->recordCount();
     recordCount -= recordCount / SUBSET_ID_THRESHOLD_FACTOR;
     mUseSubsetIndex = recordCount < mSubsetIndex.size();
-    if ( ! mUseSubsetIndex )
+    if ( !mUseSubsetIndex )
       mSubsetIndex.clear();
   }
 
@@ -1034,7 +1051,7 @@ QgsGeometry QgsDelimitedTextProvider::geomFromWkt( QString &sWkt, bool wktHasPre
 
 void QgsDelimitedTextProvider::appendZM( QString &sZ, QString &sM, QgsPoint &point, const QString &decimalPoint )
 {
-  if ( ! decimalPoint.isEmpty() )
+  if ( !decimalPoint.isEmpty() )
   {
     sZ.replace( decimalPoint, QLatin1String( "." ) );
     sM.replace( decimalPoint, QLatin1String( "." ) );
@@ -1056,16 +1073,15 @@ void QgsDelimitedTextProvider::appendZM( QString &sZ, QString &sM, QgsPoint &poi
   }
 }
 
-QList<QPair<QString, QString> > QgsDelimitedTextProvider::booleanLiterals() const
+QList<QPair<QString, QString>> QgsDelimitedTextProvider::booleanLiterals() const
 {
-  QList<QPair<QString, QString> > booleans
-  {
+  QList<QPair<QString, QString>> booleans {
     { QStringLiteral( "true" ), QStringLiteral( "false" ) },
     { QStringLiteral( "t" ), QStringLiteral( "f" ) },
     { QStringLiteral( "yes" ), QStringLiteral( "no" ) },
     { QStringLiteral( "1" ), QStringLiteral( "0" ) },
   };
-  if ( ! mUserDefinedBooleanLiterals.first.isEmpty() )
+  if ( !mUserDefinedBooleanLiterals.first.isEmpty() )
   {
     booleans.append( mUserDefinedBooleanLiterals );
   }
@@ -1074,7 +1090,7 @@ QList<QPair<QString, QString> > QgsDelimitedTextProvider::booleanLiterals() cons
 
 bool QgsDelimitedTextProvider::pointFromXY( QString &sX, QString &sY, QgsPoint &pt, const QString &decimalPoint, bool xyDms )
 {
-  if ( ! decimalPoint.isEmpty() )
+  if ( !decimalPoint.isEmpty() )
   {
     sX.replace( decimalPoint, QLatin1String( "." ) );
     sY.replace( decimalPoint, QLatin1String( "." ) );
@@ -1112,7 +1128,7 @@ QgsFeatureIterator QgsDelimitedTextProvider::getFeatures( const QgsFeatureReques
 {
   // If the file has become invalid, rescan to check that it is still invalid.
   //
-  if ( ( mLayerValid && ! mValid ) || mRescanRequired )
+  if ( ( mLayerValid && !mValid ) || mRescanRequired )
     rescanFile();
 
   return QgsFeatureIterator( new QgsDelimitedTextFeatureIterator( new QgsDelimitedTextFeatureSource( this ), true, request ) );
@@ -1129,7 +1145,7 @@ bool QgsDelimitedTextProvider::recordIsEmpty( QStringList &record )
   const auto constRecord = record;
   for ( const QString &s : constRecord )
   {
-    if ( ! s.isEmpty() )
+    if ( !s.isEmpty() )
       return false;
   }
   return true;
@@ -1149,7 +1165,7 @@ void QgsDelimitedTextProvider::recordInvalidLine( const QString &message )
 
 void QgsDelimitedTextProvider::reportErrors( const QStringList &messages, bool showDialog ) const
 {
-  if ( !mInvalidLines.isEmpty() || ! messages.isEmpty() )
+  if ( !mInvalidLines.isEmpty() || !messages.isEmpty() )
   {
     const QString tag( QStringLiteral( "DelimitedText" ) );
     QgsMessageLog::logMessage( tr( "Errors in file %1" ).arg( mFile->fileName() ), tag );
@@ -1158,7 +1174,7 @@ void QgsDelimitedTextProvider::reportErrors( const QStringList &messages, bool s
     {
       QgsMessageLog::logMessage( message, tag );
     }
-    if ( ! mInvalidLines.isEmpty() )
+    if ( !mInvalidLines.isEmpty() )
     {
       QgsMessageLog::logMessage( tr( "The following lines were not loaded into QGIS due to errors:" ), tag );
       for ( int i = 0; i < mInvalidLines.size(); ++i )
@@ -1178,7 +1194,7 @@ void QgsDelimitedTextProvider::reportErrors( const QStringList &messages, bool s
       {
         output->appendMessage( message );
       }
-      if ( ! mInvalidLines.isEmpty() )
+      if ( !mInvalidLines.isEmpty() )
       {
         output->appendMessage( tr( "The following lines were not loaded into QGIS due to errors:" ) );
         for ( int i = 0; i < mInvalidLines.size(); ++i )
@@ -1206,11 +1222,10 @@ bool QgsDelimitedTextProvider::setSubsetString( const QString &subset, bool upda
 
   // If there is a new subset string then encode it..
 
-  std::unique_ptr< QgsExpression > expression;
-  if ( ! nonNullSubset.isEmpty() )
+  std::unique_ptr<QgsExpression> expression;
+  if ( !nonNullSubset.isEmpty() )
   {
-
-    expression = std::make_unique< QgsExpression >( nonNullSubset );
+    expression = std::make_unique<QgsExpression>( nonNullSubset );
     QString error;
     if ( expression->hasParserError() )
     {
@@ -1225,7 +1240,7 @@ bool QgsDelimitedTextProvider::setSubsetString( const QString &subset, bool upda
         error = expression->evalErrorString();
       }
     }
-    if ( ! error.isEmpty() )
+    if ( !error.isEmpty() )
     {
       valid = false;
       expression.reset();
@@ -1256,7 +1271,7 @@ bool QgsDelimitedTextProvider::setSubsetString( const QString &subset, bool upda
 
     if ( updateFeatureCount )
     {
-      if ( ! mCachedSubsetString.isNull() && mSubsetString == mCachedSubsetString )
+      if ( !mCachedSubsetString.isNull() && mSubsetString == mCachedSubsetString )
       {
         QgsDebugMsgLevel( QStringLiteral( "DelimitedText: Resetting cached subset string %1" ).arg( mSubsetString ), 3 );
         mUseSpatialIndex = mCachedUseSpatialIndex;
@@ -1293,13 +1308,29 @@ bool QgsDelimitedTextProvider::setSubsetString( const QString &subset, bool upda
   return valid;
 }
 
+bool QgsDelimitedTextProvider::supportsSubsetString() const
+{
+  return true;
+}
+
+QString QgsDelimitedTextProvider::subsetStringDialect() const
+{
+  return tr( "QGIS expression" );
+}
+
+QString QgsDelimitedTextProvider::subsetStringHelpUrl() const
+{
+  // unfortunately we can't access QgsHelp here, that's a GUI class!
+  return QString();
+}
+
 void QgsDelimitedTextProvider::setUriParameter( const QString &parameter, const QString &value )
 {
   QUrl url = QUrl::fromEncoded( dataSourceUri().toUtf8() );
   QUrlQuery query( url );
   if ( query.hasQueryItem( parameter ) )
     query.removeAllQueryItems( parameter );
-  if ( ! value.isEmpty() )
+  if ( !value.isEmpty() )
     query.addQueryItem( parameter, value );
   url.setQuery( query );
   setDataSourceUri( QString::fromUtf8( url.toEncoded() ) );
@@ -1307,7 +1338,7 @@ void QgsDelimitedTextProvider::setUriParameter( const QString &parameter, const
 
 void QgsDelimitedTextProvider::onFileUpdated()
 {
-  if ( ! mRescanRequired )
+  if ( !mRescanRequired )
   {
     QStringList messages;
     messages.append( tr( "The file has been updated by another application - reloading" ) );
@@ -1318,6 +1349,13 @@ void QgsDelimitedTextProvider::onFileUpdated()
 }
 
 QgsRectangle QgsDelimitedTextProvider::extent() const
+{
+  if ( mRescanRequired )
+    rescanFile();
+  return mExtent.toRectangle();
+}
+
+QgsBox3D QgsDelimitedTextProvider::extent3D() const
 {
   if ( mRescanRequired )
     rescanFile();
@@ -1347,9 +1385,9 @@ bool QgsDelimitedTextProvider::isValid() const
   return mLayerValid;
 }
 
-QgsVectorDataProvider::Capabilities QgsDelimitedTextProvider::capabilities() const
+Qgis::VectorProviderCapabilities QgsDelimitedTextProvider::capabilities() const
 {
-  return SelectAtId | CreateSpatialIndex | CircularGeometries;
+  return Qgis::VectorProviderCapability::SelectAtId | Qgis::VectorProviderCapability::CreateSpatialIndex | Qgis::VectorProviderCapability::CircularGeometries;
 }
 
 QgsCoordinateReferenceSystem QgsDelimitedTextProvider::crs() const
@@ -1357,7 +1395,7 @@ QgsCoordinateReferenceSystem QgsDelimitedTextProvider::crs() const
   return mCrs;
 }
 
-QString  QgsDelimitedTextProvider::name() const
+QString QgsDelimitedTextProvider::name() const
 {
   return TEXT_PROVIDER_KEY;
 }
@@ -1367,7 +1405,7 @@ QString QgsDelimitedTextProvider::providerKey()
   return TEXT_PROVIDER_KEY;
 }
 
-QString  QgsDelimitedTextProvider::description() const
+QString QgsDelimitedTextProvider::description() const
 {
   return TEXT_PROVIDER_DESCRIPTION;
 }
@@ -1458,14 +1496,14 @@ QList<Qgis::LayerType> QgsDelimitedTextProviderMetadata::supportedLayerTypes() c
   return { Qgis::LayerType::Vector };
 }
 
-QgsDataProvider *QgsDelimitedTextProviderMetadata::createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, QgsDataProvider::ReadFlags flags )
+QgsDataProvider *QgsDelimitedTextProviderMetadata::createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, Qgis::DataProviderReadFlags flags )
 {
   return new QgsDelimitedTextProvider( uri, options, flags );
 }
 
 
-QgsDelimitedTextProviderMetadata::QgsDelimitedTextProviderMetadata():
-  QgsProviderMetadata( QgsDelimitedTextProvider::TEXT_PROVIDER_KEY, QgsDelimitedTextProvider::TEXT_PROVIDER_DESCRIPTION )
+QgsDelimitedTextProviderMetadata::QgsDelimitedTextProviderMetadata()
+  : QgsProviderMetadata( QgsDelimitedTextProvider::TEXT_PROVIDER_KEY, QgsDelimitedTextProvider::TEXT_PROVIDER_DESCRIPTION )
 {
 }
 
