@@ -17,13 +17,13 @@
 #include "qgsmessageoutput.h"
 #include "qgsmimedatautils.h"
 #include "qgsproviderregistry.h"
-#include "qgsrasterlayer.h"
 #include "qgsrasterdataprovider.h"
 #include "qgsrasterprojector.h"
 #include "qgslogger.h"
 #include "qgssettings.h"
 #include "qgsdataitemprovider.h"
 #include "qgsgrassprovidermodule.h"
+#include "moc_qgsgrassprovidermodule.cpp"
 #include "qgsgrassprovider.h"
 #include "qgsgrass.h"
 #include "qgsgrassvector.h"
@@ -32,7 +32,6 @@
 
 #ifdef HAVE_GUI
 #include "qgsnewnamedialog.h"
-#include "qgsgrassoptions.h"
 #endif
 
 #include <QAction>
@@ -98,7 +97,8 @@ QList<QAction *> QgsGrassItemActions::actions( QWidget *parent )
   }
 
   if ( ( mGrassObject.type() == QgsGrassObject::Raster || mGrassObject.type() == QgsGrassObject::Vector
-         ||  mGrassObject.type() == QgsGrassObject::Group ) && isMapsetOwner )
+         || mGrassObject.type() == QgsGrassObject::Group )
+       && isMapsetOwner )
   {
     QAction *renameAction = new QAction( tr( "Rename…" ), parent );
     connect( renameAction, &QAction::triggered, this, &QgsGrassItemActions::renameGrassObject );
@@ -131,7 +131,6 @@ QList<QAction *> QgsGrassItemActions::actions( QWidget *parent )
 
 void QgsGrassItemActions::newMapset()
 {
-
   QStringList existingNames = QgsGrass::mapsets( mGrassObject.gisdbase(), mGrassObject.mapsetPath() );
   QgsDebugMsgLevel( QStringLiteral( "existingNames = " ) + existingNames.join( ',' ), 2 );
   Qt::CaseSensitivity caseSensitivity = QgsGrass::caseSensitivity();
@@ -187,7 +186,6 @@ void QgsGrassItemActions::removeMapsetFromSearchPath()
 
 void QgsGrassItemActions::renameGrassObject()
 {
-
   QStringList existingNames = QgsGrass::grassObjects( mGrassObject, mGrassObject.type() );
   // remove current name to avoid warning that exists
   existingNames.removeOne( mGrassObject.name() );
@@ -222,15 +220,12 @@ void QgsGrassItemActions::renameGrassObject()
   }
   catch ( QgsGrass::Exception &e )
   {
-    QgsMessageOutput::showMessage( errorTitle,
-                                   QObject::tr( "Cannot rename %1 to %2" ).arg( mGrassObject.name(), obj.name() ) + "\n" + e.what(),
-                                   QgsMessageOutput::MessageText );
+    QgsMessageOutput::showMessage( errorTitle, QObject::tr( "Cannot rename %1 to %2" ).arg( mGrassObject.name(), obj.name() ) + "\n" + e.what(), QgsMessageOutput::MessageText );
   }
 }
 
 void QgsGrassItemActions::deleteGrassObject()
 {
-
   if ( !QgsGrass::deleteObjectDialog( mGrassObject ) )
     return;
 
@@ -243,7 +238,6 @@ void QgsGrassItemActions::deleteGrassObject()
 
 QString QgsGrassItemActions::newVectorMap()
 {
-
   QStringList existingNames = QgsGrass::grassObjects( mGrassObject, QgsGrassObject::Vector );
   QgsDebugMsgLevel( QStringLiteral( "existingNames = " ) + existingNames.join( ',' ), 2 );
   Qt::CaseSensitivity caseSensitivity = QgsGrass::caseSensitivity();
@@ -354,7 +348,7 @@ QgsGrassLocationItem::QgsGrassLocationItem( QgsDataItem *parent, const QString &
   mType = Qgis::BrowserItemType::Directory;
 }
 
-QVector<QgsDataItem *>QgsGrassLocationItem::createChildren()
+QVector<QgsDataItem *> QgsGrassLocationItem::createChildren()
 {
   QVector<QgsDataItem *> mapsets;
 
@@ -427,7 +421,6 @@ QIcon QgsGrassMapsetItem::icon()
 
 void QgsGrassMapsetItem::setState( Qgis::BrowserItemState state )
 {
-
   // TODO: it seems to be causing strange icon switching during import, sometimes
   if ( state == Qgis::BrowserItemState::Populated )
   {
@@ -475,7 +468,6 @@ bool QgsGrassMapsetItem::objectInImports( const QgsGrassObject &grassObject )
 
 QVector<QgsDataItem *> QgsGrassMapsetItem::createChildren()
 {
-
   QVector<QgsDataItem *> items;
 
   QStringList vectorNames = QgsGrass::vectors( mDirPath );
@@ -530,7 +522,7 @@ QVector<QgsDataItem *> QgsGrassMapsetItem::createChildren()
     {
       topoError = tr( "topology version not supported" );
     }
-    else if ( topoMinor == 0 &&  GRASS_VERSION_MAJOR == 7 )
+    else if ( topoMinor == 0 && GRASS_VERSION_MAJOR == 7 )
     {
       topoError = tr( "topology version 6" );
     }
@@ -603,10 +595,8 @@ QVector<QgsDataItem *> QgsGrassMapsetItem::createChildren()
     }
   }
 
-  QStringList rasterNames = QgsGrass::rasters( mDirPath );
-
-  const auto constRasterNames = rasterNames;
-  for ( const QString &name : constRasterNames )
+  const QStringList rasterNames = QgsGrass::rasters( mDirPath );
+  for ( const QString &name : rasterNames )
   {
     if ( mRefreshLater )
     {
@@ -820,7 +810,7 @@ bool QgsGrassMapsetItem::handleDrop( const QMimeData *data, Qt::DropAction )
       int newXSize;
       int newYSize;
       bool useSrcRegion = true;
-      if ( rasterProvider->capabilities() & QgsRasterInterface::Size )
+      if ( rasterProvider->capabilities() & Qgis::RasterInterfaceCapability::Size )
       {
         newXSize = rasterProvider->xSize();
         newYSize = rasterProvider->ySize();
@@ -867,8 +857,7 @@ bool QgsGrassMapsetItem::handleDrop( const QMimeData *data, Qt::DropAction )
           projector->setCrs( providerCrs, mapsetCrs, QgsProject::instance()->transformContext() );
           if ( useSrcRegion )
           {
-            projector->destExtentSize( rasterProvider->extent(), rasterProvider->xSize(), rasterProvider->ySize(),
-                                       newExtent, newXSize, newYSize );
+            projector->destExtentSize( rasterProvider->extent(), rasterProvider->xSize(), rasterProvider->ySize(), newExtent, newXSize, newYSize );
           }
           QgsRasterProjector::Precision precision = settings.enumValue( QStringLiteral( "GRASS/browser/import/crsTransform" ), QgsRasterProjector::Approximate );
           projector->setPrecision( precision );
@@ -932,9 +921,7 @@ bool QgsGrassMapsetItem::handleDrop( const QMimeData *data, Qt::DropAction )
 
   if ( !errors.isEmpty() )
   {
-    QgsMessageOutput::showMessage( tr( "Import to GRASS mapset" ),
-                                   tr( "Failed to import some layers!\n\n" ) + errors.join( QLatin1Char( '\n' ) ),
-                                   QgsMessageOutput::MessageText );
+    QgsMessageOutput::showMessage( tr( "Import to GRASS mapset" ), tr( "Failed to import some layers!\n\n" ) + errors.join( QLatin1Char( '\n' ) ), QgsMessageOutput::MessageText );
   }
 
   return true;
@@ -946,9 +933,7 @@ void QgsGrassMapsetItem::onImportFinished( QgsGrassImport *import )
   {
     QgsMessageOutput *output = QgsMessageOutput::createMessageOutput();
     output->setTitle( tr( "Import to GRASS mapset failed" ) );
-    output->setMessage( tr( "Failed to import %1 to %2: %3" ).arg( import->srcDescription(),
-                        import->grassObject().mapsetPath(),
-                        import->error() ), QgsMessageOutput::MessageText );
+    output->setMessage( tr( "Failed to import %1 to %2: %3" ).arg( import->srcDescription(), import->grassObject().mapsetPath(), import->error() ), QgsMessageOutput::MessageText );
     output->showMessage();
   }
 
@@ -976,7 +961,7 @@ void QgsGrassMapsetItem::childrenCreated()
 
   if ( mRefreshLater )
   {
-    QgsDebugMsgLevel( QStringLiteral( "directory changed during createChidren() -> refresh() again" ), 2 );
+    QgsDebugMsgLevel( QStringLiteral( "directory changed during createChildren() -> refresh() again" ), 2 );
     mRefreshLater = false;
     setState( Qgis::BrowserItemState::Populated );
     refresh();
@@ -989,9 +974,7 @@ void QgsGrassMapsetItem::childrenCreated()
 
 //------------------------ QgsGrassObjectItem ----------------------------------
 
-QgsGrassObjectItem::QgsGrassObjectItem( QgsDataItem *parent, const QgsGrassObject &grassObject,
-                                        const QString &name, const QString &path, const QString &uri,
-                                        Qgis::BrowserLayerType layerType, const QString &providerKey )
+QgsGrassObjectItem::QgsGrassObjectItem( QgsDataItem *parent, const QgsGrassObject &grassObject, const QString &name, const QString &path, const QString &uri, Qgis::BrowserLayerType layerType, const QString &providerKey )
   : QgsLayerItem( parent, name, path, uri, layerType, providerKey )
   , QgsGrassObjectItemBase( grassObject )
 {
@@ -1015,7 +998,7 @@ QgsGrassVectorItem::QgsGrassVectorItem( QgsDataItem *parent, const QgsGrassObjec
   , mValid( valid )
 {
   QgsDebugMsgLevel( "name = " + grassObject.name() + " path = " + path, 2 );
-  mCapabilities = Qgis::BrowserItemCapability::NoCapabilities; // disable Fertile from QgsDataCollectionItem
+  mCapabilities = Qgis::BrowserItemCapability::NoCapabilities;    // disable Fertile from QgsDataCollectionItem
   setCapabilities( Qgis::BrowserItemCapability::NoCapabilities ); // disable fertility
   if ( !mValid )
   {
@@ -1075,9 +1058,7 @@ bool QgsGrassVectorItem::equal( const QgsDataItem *other )
 
 //----------------------- QgsGrassVectorLayerItem ------------------------------
 
-QgsGrassVectorLayerItem::QgsGrassVectorLayerItem( QgsDataItem *parent, const QgsGrassObject &grassObject, const QString &layerName,
-    const QString &path, const QString &uri,
-    Qgis::BrowserLayerType layerType, bool singleLayer )
+QgsGrassVectorLayerItem::QgsGrassVectorLayerItem( QgsDataItem *parent, const QgsGrassObject &grassObject, const QString &layerName, const QString &path, const QString &uri, Qgis::BrowserLayerType layerType, bool singleLayer )
   : QgsGrassObjectItem( parent, grassObject, layerName, path, uri, layerType, QStringLiteral( "grass" ) )
   , mSingleLayer( singleLayer )
 {
@@ -1104,8 +1085,7 @@ bool QgsGrassVectorLayerItem::equal( const QgsDataItem *other )
 
 //----------------------- QgsGrassRasterItem ------------------------------
 
-QgsGrassRasterItem::QgsGrassRasterItem( QgsDataItem *parent, const QgsGrassObject &grassObject,
-                                        const QString &path, const QString &uri, bool isExternal )
+QgsGrassRasterItem::QgsGrassRasterItem( QgsDataItem *parent, const QgsGrassObject &grassObject, const QString &path, const QString &uri, bool isExternal )
   : QgsGrassObjectItem( parent, grassObject, grassObject.name(), path, uri, Qgis::BrowserLayerType::Raster, QStringLiteral( "grassraster" ) )
   , mExternal( isExternal )
 {
@@ -1123,13 +1103,12 @@ QIcon QgsGrassRasterItem::icon()
 bool QgsGrassRasterItem::equal( const QgsDataItem *other )
 {
   const QgsGrassRasterItem *item = qobject_cast<const QgsGrassRasterItem *>( other );
-  return QgsGrassObjectItem::equal( other )  && item && mExternal == item->mExternal;
+  return QgsGrassObjectItem::equal( other ) && item && mExternal == item->mExternal;
 }
 
 //----------------------- QgsGrassGroupItem ------------------------------
 
-QgsGrassGroupItem::QgsGrassGroupItem( QgsDataItem *parent, const QgsGrassObject &grassObject,
-                                      const QString &path, const QString &uri )
+QgsGrassGroupItem::QgsGrassGroupItem( QgsDataItem *parent, const QgsGrassObject &grassObject, const QString &path, const QString &uri )
   : QgsGrassObjectItem( parent, grassObject, grassObject.name(), path, uri, Qgis::BrowserLayerType::Raster, QStringLiteral( "grassraster" ) )
 {
 }
@@ -1214,8 +1193,7 @@ QWidget *QgsGrassImportItem::paramWidget()
 
   if ( mImport && mImport->progress() )
   {
-    connect( mImport->progress(), &QgsGrassImportProgress::progressChanged,
-             widget, &QgsGrassImportItemWidget::onProgressChanged );
+    connect( mImport->progress(), &QgsGrassImportProgress::progressChanged, widget, &QgsGrassImportItemWidget::onProgressChanged );
 
     widget->setHtml( mImport->progress()->progressHtml() );
   }
@@ -1263,7 +1241,7 @@ class QgsGrassDataItemProvider : public QgsDataItemProvider
   public:
     QString name() override { return QStringLiteral( "GRASS" ); }
 
-    int capabilities() const override { return QgsDataProvider::Dir; }
+    Qgis::DataItemProviderCapabilities capabilities() const override { return Qgis::DataItemProviderCapability::Directories; }
 
     QgsDataItem *createDataItem( const QString &dirPath, QgsDataItem *parentItem ) override
     {
@@ -1298,7 +1276,7 @@ QgsGrassProviderMetadata::QgsGrassProviderMetadata()
   : QgsProviderMetadata( PROVIDER_KEY, PROVIDER_DESCRIPTION )
 {}
 
-QgsDataProvider *QgsGrassProviderMetadata::createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, QgsDataProvider::ReadFlags flags )
+QgsDataProvider *QgsGrassProviderMetadata::createProvider( const QString &uri, const QgsDataProvider::ProviderOptions &options, Qgis::DataProviderReadFlags flags )
 {
   Q_UNUSED( options )
   Q_UNUSED( flags )
@@ -1307,7 +1285,7 @@ QgsDataProvider *QgsGrassProviderMetadata::createProvider( const QString &uri, c
 
 QList<QgsDataItemProvider *> QgsGrassProviderMetadata::dataItemProviders() const
 {
-  QList< QgsDataItemProvider * > providers;
+  QList<QgsDataItemProvider *> providers;
   providers << new QgsGrassDataItemProvider;
   return providers;
 }
