@@ -16,10 +16,11 @@
 #include "qgsapplication.h"
 #include "qgslogger.h"
 #include "qgscachedirectorymanager.h"
+#include "moc_qgscachedirectorymanager.cpp"
 #include "qgssettings.h"
 
 // 1 minute
-#define KEEP_ALIVE_DELAY        (60 * 1000)
+#define KEEP_ALIVE_DELAY ( 60 * 1000 )
 
 #include <QFile>
 #include <QDir>
@@ -63,7 +64,7 @@ QString QgsCacheDirectoryManager::getBaseCacheDirectory( bool createIfNotExistin
     const QMutexLocker locker( &mMutex );
     if ( !QDir( cacheDirectory ).exists( subDir ) )
     {
-      QgsDebugMsgLevel( QStringLiteral( "Creating main cache dir %1/%2" ).arg( cacheDirectory ). arg( subDir ), 2 );
+      QgsDebugMsgLevel( QStringLiteral( "Creating main cache dir %1/%2" ).arg( cacheDirectory ).arg( subDir ), 2 );
       QDir( cacheDirectory ).mkpath( subDir );
     }
   }
@@ -89,7 +90,7 @@ QString QgsCacheDirectoryManager::getCacheDirectory( bool createIfNotExisting )
       mThread->start();
     }
 #endif
-    mCounter ++;
+    mCounter++;
   }
   return QDir( baseDirectory ).filePath( processPath );
 }
@@ -102,7 +103,7 @@ QString QgsCacheDirectoryManager::acquireCacheDirectory()
 void QgsCacheDirectoryManager::releaseCacheDirectory()
 {
   const QMutexLocker locker( &mMutex );
-  mCounter --;
+  mCounter--;
   if ( mCounter == 0 )
   {
     if ( mThread )
@@ -176,8 +177,7 @@ std::unique_ptr<QSharedMemory> QgsCacheDirectoryManager::createAndAttachSHM()
       // Would happen on Unix in the quite unlikely situation where a past process
       // with the same PID as ours would have been killed before it destroyed
       // its shared memory segment. So we will recycle it.
-      if ( sharedMemory->error() == QSharedMemory::AlreadyExists &&
-           sharedMemory->attach() && sharedMemory->size() == static_cast<int>( sizeof( qint64 ) ) )
+      if ( sharedMemory->error() == QSharedMemory::AlreadyExists && sharedMemory->attach() && sharedMemory->size() == static_cast<int>( sizeof( qint64 ) ) )
       {
         return sharedMemory;
       }
@@ -239,8 +239,7 @@ void QgsCacheDirectoryManager::init()
                 qint64 otherTimestamp;
                 memcpy( &otherTimestamp, otherSharedMemory.data(), sizeof( qint64 ) );
                 otherSharedMemory.unlock();
-                if ( currentTimestamp > otherTimestamp && otherTimestamp > 0 &&
-                     currentTimestamp - otherTimestamp < 2 * KEEP_ALIVE_DELAY )
+                if ( currentTimestamp > otherTimestamp && otherTimestamp > 0 && currentTimestamp - otherTimestamp < 2 * KEEP_ALIVE_DELAY )
                 {
                   QgsDebugMsgLevel( QStringLiteral( "Cache dir %1 kept since process seems to be still alive" ).arg( info.absoluteFilePath() ), 4 );
                   canDelete = false;
@@ -266,8 +265,7 @@ void QgsCacheDirectoryManager::init()
           // Fallback to a file timestamp based method, if for some reason,
           // the shared memory stuff doesn't seem to work
           const qint64 fileTimestamp = info.lastModified().toMSecsSinceEpoch();
-          if ( currentTimestamp > fileTimestamp &&
-               currentTimestamp - fileTimestamp < 24 * 3600 * 1000 )
+          if ( currentTimestamp > fileTimestamp && currentTimestamp - fileTimestamp < 24 * 3600 * 1000 )
           {
             QgsDebugMsgLevel( QStringLiteral( "Cache dir %1 kept since last modified in the past 24 hours" ).arg( info.absoluteFilePath() ), 4 );
             canDelete = false;
