@@ -30,16 +30,12 @@
  * \ingroup server
  * \class QgsServerInterfaceImpl
  * \brief Interfaces exposed by QGIS Server and made available to plugins.
- * \since QGIS 2.8
  */
 class SERVER_EXPORT QgsServerInterfaceImpl : public QgsServerInterface
 {
   public:
-
     //! Constructor
-    explicit QgsServerInterfaceImpl( QgsCapabilitiesCache *capCache,
-                                     QgsServiceRegistry *srvRegistry,
-                                     QgsServerSettings *serverSettings );
+    explicit QgsServerInterfaceImpl( QgsCapabilitiesCache *capCache, QgsServiceRegistry *srvRegistry, QgsServerSettings *serverSettings );
 
 
     ~QgsServerInterfaceImpl() override;
@@ -48,7 +44,7 @@ class SERVER_EXPORT QgsServerInterfaceImpl : public QgsServerInterface
     void clearRequestHandler() override;
     QgsCapabilitiesCache *capabilitiesCache() override { return mCapabilitiesCache; }
     //! Returns the QgsRequestHandler, to be used only in server plugins
-    QgsRequestHandler  *requestHandler() override { return mRequestHandler; }
+    QgsRequestHandler *requestHandler() override { return mRequestHandler; }
     void registerFilter( QgsServerFilter *filter, int priority = 0 ) override;
     QgsServerFiltersMap filters() override { return mFilters; }
 
@@ -90,7 +86,6 @@ class SERVER_EXPORT QgsServerInterfaceImpl : public QgsServerInterface
     void reloadSettings() override;
 
   private:
-
     QString mConfigFilePath;
     QgsServerFiltersMap mFilters;
     QgsAccessControl *mAccessControls = nullptr;
@@ -99,7 +94,6 @@ class SERVER_EXPORT QgsServerInterfaceImpl : public QgsServerInterface
     QgsRequestHandler *mRequestHandler = nullptr;
     QgsServiceRegistry *mServiceRegistry = nullptr;
     QgsServerSettings *mServerSettings = nullptr;
-
 };
 
 #endif // QGSSERVERINTERFACEIMPL_H
