@@ -67,12 +67,10 @@ qint64 QgsServerResponse::write( const char *data )
 
 void QgsServerResponse::finish()
 {
-
 }
 
 void QgsServerResponse::flush()
 {
-
 }
 
 qint64 QgsServerResponse::write( const std::string data )
@@ -96,3 +94,8 @@ void QgsServerResponse::write( const QgsServerException &ex )
   setHeader( "Content-Type", responseFormat );
   write( ba );
 }
+
+QgsFeedback *QgsServerResponse::feedback() const
+{
+  return nullptr;
+}
