@@ -36,8 +36,7 @@ namespace QgsWfs
   /**
    * Output WFS  GetCapabilities response
    */
-  void writeGetCapabilities( QgsServerInterface *serverIface, const QgsProject *project, const QString &version,
-                             const QgsServerRequest &request, QgsServerResponse &response )
+  void writeGetCapabilities( QgsServerInterface *serverIface, const QgsProject *project, const QString &version, const QgsServerRequest &request, QgsServerResponse &response )
   {
 #ifdef HAVE_SERVER_PYTHON_PLUGINS
     QgsAccessControl *accessControl = serverIface->accessControls();
@@ -70,15 +69,14 @@ namespace QgsWfs
   }
 
 
-  QDomDocument createGetCapabilitiesDocument( QgsServerInterface *serverIface, const QgsProject *project, const QString &version,
-      const QgsServerRequest &request )
+  QDomDocument createGetCapabilitiesDocument( QgsServerInterface *serverIface, const QgsProject *project, const QString &version, const QgsServerRequest &request )
   {
     Q_UNUSED( version )
 
     QDomDocument doc;
 
     //wfs:WFS_Capabilities element
-    QDomElement wfsCapabilitiesElement = doc.createElement( QStringLiteral( "WFS_Capabilities" )/*wms:WFS_Capabilities*/ );
+    QDomElement wfsCapabilitiesElement = doc.createElement( QStringLiteral( "WFS_Capabilities" ) /*wms:WFS_Capabilities*/ );
     wfsCapabilitiesElement.setAttribute( QStringLiteral( "xmlns" ), WFS_NAMESPACE );
     wfsCapabilitiesElement.setAttribute( QStringLiteral( "xmlns:xsi" ), QStringLiteral( "http://www.w3.org/2001/XMLSchema-instance" ) );
     wfsCapabilitiesElement.setAttribute( QStringLiteral( "xsi:schemaLocation" ), WFS_NAMESPACE + " http://schemas.opengis.net/wfs/1.1.0/wfs.xsd" );
@@ -106,9 +104,9 @@ namespace QgsWfs
      * Adding ogc:Filter_Capabilities in wfsCapabilitiesElement
      */
     //ogc:Filter_Capabilities element
-    QDomElement filterCapabilitiesElement = doc.createElement( QStringLiteral( "ogc:Filter_Capabilities" )/*ogc:Filter_Capabilities*/ );
+    QDomElement filterCapabilitiesElement = doc.createElement( QStringLiteral( "ogc:Filter_Capabilities" ) /*ogc:Filter_Capabilities*/ );
     wfsCapabilitiesElement.appendChild( filterCapabilitiesElement );
-    QDomElement spatialCapabilitiesElement = doc.createElement( QStringLiteral( "ogc:Spatial_Capabilities" )/*ogc:Spatial_Capabilities*/ );
+    QDomElement spatialCapabilitiesElement = doc.createElement( QStringLiteral( "ogc:Spatial_Capabilities" ) /*ogc:Spatial_Capabilities*/ );
     filterCapabilitiesElement.appendChild( spatialCapabilitiesElement );
     //GeometryOperands
     QStringList geometryOperands;
@@ -136,7 +134,7 @@ namespace QgsWfs
       spatialOperatorsElem.appendChild( spatialOperatorElem );
     }
     spatialCapabilitiesElement.appendChild( spatialOperatorsElem );
-    QDomElement scalarCapabilitiesElement = doc.createElement( QStringLiteral( "ogc:Scalar_Capabilities" )/*ogc:Scalar_Capabilities*/ );
+    QDomElement scalarCapabilitiesElement = doc.createElement( QStringLiteral( "ogc:Scalar_Capabilities" ) /*ogc:Scalar_Capabilities*/ );
     filterCapabilitiesElement.appendChild( scalarCapabilitiesElement );
     const QDomElement logicalOperatorsElement = doc.createElement( QStringLiteral( "ogc:LogicalOperators" ) );
     scalarCapabilitiesElement.appendChild( logicalOperatorsElement );
@@ -161,7 +159,6 @@ namespace QgsWfs
     filterCapabilitiesElement.appendChild( idCapabilitiesElement );
 
     return doc;
-
   }
 
   QDomElement getServiceIdentificationElement( QDomDocument &doc, const QgsProject *project )
@@ -234,7 +231,6 @@ namespace QgsWfs
     serviceElem.appendChild( accessConstraintsElem );
 
     return serviceElem;
-
   }
 
   QDomElement getServiceProviderElement( QDomDocument &doc, const QgsProject *project )
@@ -254,8 +250,7 @@ namespace QgsWfs
 
     const QString contactPerson = QgsServerProjectUtils::owsServiceContactPerson( *project );
     const QString contactPosition = QgsServerProjectUtils::owsServiceContactPosition( *project );
-    if ( !contactPerson.isEmpty() ||
-         !contactPosition.isEmpty() )
+    if ( !contactPerson.isEmpty() || !contactPosition.isEmpty() )
     {
       //Contact information
       QDomElement serviceContactElem = doc.createElement( QStringLiteral( "ows:ServiceContact" ) );
@@ -279,9 +274,7 @@ namespace QgsWfs
       const QString contactMail = QgsServerProjectUtils::owsServiceContactMail( *project );
       const QString contactPhone = QgsServerProjectUtils::owsServiceContactPhone( *project );
       const QString onlineResource = QgsServerProjectUtils::owsServiceOnlineResource( *project );
-      if ( !contactMail.isEmpty() ||
-           !contactPhone.isEmpty() ||
-           !onlineResource.isEmpty() )
+      if ( !contactMail.isEmpty() || !contactPhone.isEmpty() || !onlineResource.isEmpty() )
       {
         //Contact information
         QDomElement contactInfoElem = doc.createElement( QStringLiteral( "ows:ContactInfo" ) );
@@ -323,7 +316,6 @@ namespace QgsWfs
     }
 
     return serviceElem;
-
   }
 
   QDomElement getParameterElement( QDomDocument &doc, const QString &name, const QStringList &values )
@@ -367,16 +359,13 @@ namespace QgsWfs
     QDomElement getCapabilitiesElement = operationElement.cloneNode().toElement();
     getCapabilitiesElement.setAttribute( QStringLiteral( "name" ), QStringLiteral( "GetCapabilities" ) );
     // GetCapabilities service
-    const QDomElement serviceParameterElement = getParameterElement( doc, QStringLiteral( "service" ),
-        QStringList() << QStringLiteral( "WFS" ) );
+    const QDomElement serviceParameterElement = getParameterElement( doc, QStringLiteral( "service" ), QStringList() << QStringLiteral( "WFS" ) );
     getCapabilitiesElement.appendChild( serviceParameterElement );
     // GetCapabilities AcceptVersions
-    const QDomElement acceptVersionsParameterElement = getParameterElement( doc, QStringLiteral( "AcceptVersions" ),
-        QStringList() << QStringLiteral( "1.1.0" ) << QStringLiteral( "1.0.0" ) );
+    const QDomElement acceptVersionsParameterElement = getParameterElement( doc, QStringLiteral( "AcceptVersions" ), QStringList() << QStringLiteral( "1.1.0" ) << QStringLiteral( "1.0.0" ) );
     getCapabilitiesElement.appendChild( acceptVersionsParameterElement );
     // GetCapabilities AcceptFormats
-    const QDomElement acceptFormatsParameterElement = getParameterElement( doc, QStringLiteral( "AcceptFormats" ),
-        QStringList() << QStringLiteral( "text/xml" ) );
+    const QDomElement acceptFormatsParameterElement = getParameterElement( doc, QStringLiteral( "AcceptFormats" ), QStringList() << QStringLiteral( "text/xml" ) );
     getCapabilitiesElement.appendChild( acceptFormatsParameterElement );
     // Add
     oprationsElement.appendChild( getCapabilitiesElement );
@@ -385,10 +374,7 @@ namespace QgsWfs
     QDomElement describeFeatureTypeElement = operationElement.cloneNode().toElement();
     describeFeatureTypeElement.setAttribute( QStringLiteral( "name" ), QStringLiteral( "DescribeFeatureType" ) );
     // DescribeFeatureType outputFormat
-    const QDomElement dftOutputFormatParameterElement = getParameterElement( doc, QStringLiteral( "outputFormat" ),
-        QStringList() << QStringLiteral( "XMLSCHEMA" )
-        << QStringLiteral( "text/xml; subtype=gml/2.1.2" )
-        << QStringLiteral( "text/xml; subtype=gml/3.1.1" ) );
+    const QDomElement dftOutputFormatParameterElement = getParameterElement( doc, QStringLiteral( "outputFormat" ), QStringList() << QStringLiteral( "XMLSCHEMA" ) << QStringLiteral( "text/xml; subtype=gml/2.1.2" ) << QStringLiteral( "text/xml; subtype=gml/3.1.1" ) );
     describeFeatureTypeElement.appendChild( dftOutputFormatParameterElement );
     // Add
     oprationsElement.appendChild( describeFeatureTypeElement );
@@ -397,14 +383,10 @@ namespace QgsWfs
     QDomElement getFeatureElement = operationElement.cloneNode().toElement();
     getFeatureElement.setAttribute( QStringLiteral( "name" ), QStringLiteral( "GetFeature" ) );
     // GetFeature outputFormat
-    const QDomElement gfOutputFormatParameterElement = getParameterElement( doc, QStringLiteral( "outputFormat" ),
-        QStringList() << QStringLiteral( "text/xml; subtype=gml/2.1.2" )
-        << QStringLiteral( "text/xml; subtype=gml/3.1.1" )
-        << QStringLiteral( "application/vnd.geo+json" ) );
+    const QDomElement gfOutputFormatParameterElement = getParameterElement( doc, QStringLiteral( "outputFormat" ), QStringList() << QStringLiteral( "text/xml; subtype=gml/2.1.2" ) << QStringLiteral( "text/xml; subtype=gml/3.1.1" ) << QStringLiteral( "application/vnd.geo+json" ) );
     getFeatureElement.appendChild( gfOutputFormatParameterElement );
     // GetFeature resultType
-    const QDomElement resultTypeParameterElement = getParameterElement( doc, QStringLiteral( "resultType" ),
-        QStringList() << QStringLiteral( "results" ) << QStringLiteral( "hits" ) );
+    const QDomElement resultTypeParameterElement = getParameterElement( doc, QStringLiteral( "resultType" ), QStringList() << QStringLiteral( "results" ) << QStringLiteral( "hits" ) );
     getFeatureElement.appendChild( resultTypeParameterElement );
     // Add
     oprationsElement.appendChild( getFeatureElement );
@@ -413,16 +395,12 @@ namespace QgsWfs
     QDomElement transactionElement = operationElement.cloneNode().toElement();
     transactionElement.setAttribute( QStringLiteral( "name" ), QStringLiteral( "Transaction" ) );
     // GetFeature inputFormat
-    const QDomElement inputFormatParameterElement = getParameterElement( doc, QStringLiteral( "inputFormat" ),
-        QStringList() << QStringLiteral( "text/xml; subtype=gml/2.1.2" )
-        << QStringLiteral( "text/xml; subtype=gml/3.1.1" )
-        << QStringLiteral( "application/vnd.geo+json" ) );
+    const QDomElement inputFormatParameterElement = getParameterElement( doc, QStringLiteral( "inputFormat" ), QStringList() << QStringLiteral( "text/xml; subtype=gml/2.1.2" ) << QStringLiteral( "text/xml; subtype=gml/3.1.1" ) << QStringLiteral( "application/vnd.geo+json" ) );
     transactionElement.appendChild( inputFormatParameterElement );
     // Add
     oprationsElement.appendChild( transactionElement );
 
     return oprationsElement;
-
   }
 
   QDomElement getFeatureTypeListElement( QDomDocument &doc, QgsServerInterface *serverIface, const QgsProject *project )
@@ -430,13 +408,13 @@ namespace QgsWfs
 #ifdef HAVE_SERVER_PYTHON_PLUGINS
     QgsAccessControl *accessControl = serverIface->accessControls();
 #else
-    ( void )serverIface;
+    ( void ) serverIface;
 #endif
 
     //wfs:FeatureTypeList element
-    QDomElement featureTypeListElement = doc.createElement( QStringLiteral( "FeatureTypeList" )/*wfs:FeatureTypeList*/ );
+    QDomElement featureTypeListElement = doc.createElement( QStringLiteral( "FeatureTypeList" ) /*wfs:FeatureTypeList*/ );
     //wfs:Operations element
-    QDomElement operationsElement = doc.createElement( QStringLiteral( "Operations" )/*wfs:Operations*/ );
+    QDomElement operationsElement = doc.createElement( QStringLiteral( "Operations" ) /*wfs:Operations*/ );
     featureTypeListElement.appendChild( operationsElement );
     //wfs:Query element
     QDomElement operationElement = doc.createElement( QStringLiteral( "Operation" ) );
@@ -475,7 +453,7 @@ namespace QgsWfs
 
       //create Title
       QDomElement titleElem = doc.createElement( QStringLiteral( "Title" ) );
-      QString title = layer->title();
+      QString title = layer->serverProperties()->wfsTitle();
       if ( title.isEmpty() )
       {
         title = layer->name();
@@ -485,7 +463,7 @@ namespace QgsWfs
       layerElem.appendChild( titleElem );
 
       //create Abstract
-      const QString abstract = layer->abstract();
+      const QString abstract = layer->serverProperties()->abstract();
       if ( !abstract.isEmpty() )
       {
         QDomElement abstractElem = doc.createElement( QStringLiteral( "Abstract" ) );
@@ -495,7 +473,7 @@ namespace QgsWfs
       }
 
       //create keywords
-      const QString keywords = layer->keywordList();
+      const QString keywords = layer->serverProperties()->keywordList();
       if ( !keywords.isEmpty() )
       {
         QDomElement keywordsElem = doc.createElement( QStringLiteral( "ows:Keywords" ) );
@@ -532,44 +510,40 @@ namespace QgsWfs
       }
 
       //wfs:Operations element
-      QDomElement operationsElement = doc.createElement( QStringLiteral( "Operations" )/*wfs:Operations*/ );
+      QDomElement operationsElement = doc.createElement( QStringLiteral( "Operations" ) /*wfs:Operations*/ );
       //wfs:Query element
       QDomElement operationElement = doc.createElement( QStringLiteral( "Operation" ) );
       const QDomText queryText = doc.createTextNode( QStringLiteral( "Query" ) );
       operationElement.appendChild( queryText );
       operationsElement.appendChild( operationElement );
 
-      if ( wfstUpdateLayersId.contains( layer->id() ) ||
-           wfstInsertLayersId.contains( layer->id() ) ||
-           wfstDeleteLayersId.contains( layer->id() ) )
+      if ( wfstUpdateLayersId.contains( layer->id() ) || wfstInsertLayersId.contains( layer->id() ) || wfstDeleteLayersId.contains( layer->id() ) )
       {
         QgsVectorLayer *vlayer = qobject_cast<QgsVectorLayer *>( layer );
         QgsVectorDataProvider *provider = vlayer->dataProvider();
-        if ( ( provider->capabilities() & QgsVectorDataProvider::AddFeatures ) && wfstInsertLayersId.contains( layer->id() ) )
+        if ( ( provider->capabilities() & Qgis::VectorProviderCapability::AddFeatures ) && wfstInsertLayersId.contains( layer->id() ) )
         {
           //wfs:Insert element
           QDomElement operationElement = doc.createElement( QStringLiteral( "Operation" ) );
-          const QDomText insertText = doc.createTextNode( QStringLiteral( "Insert" )/*wfs:Insert*/ );
+          const QDomText insertText = doc.createTextNode( QStringLiteral( "Insert" ) /*wfs:Insert*/ );
           operationElement.appendChild( insertText );
           operationsElement.appendChild( operationElement );
         }
 
-        if ( ( provider->capabilities() & QgsVectorDataProvider::ChangeAttributeValues ) &&
-             ( provider->capabilities() & QgsVectorDataProvider::ChangeGeometries ) &&
-             wfstUpdateLayersId.contains( layer->id() ) )
+        if ( ( provider->capabilities() & Qgis::VectorProviderCapability::ChangeAttributeValues ) && ( !layer->isSpatial() || provider->capabilities() & Qgis::VectorProviderCapability::ChangeGeometries ) && wfstUpdateLayersId.contains( layer->id() ) )
         {
           //wfs:Update element
           QDomElement operationElement = doc.createElement( QStringLiteral( "Operation" ) );
-          const QDomText updateText = doc.createTextNode( QStringLiteral( "Update" )/*wfs:Update*/ );
+          const QDomText updateText = doc.createTextNode( QStringLiteral( "Update" ) /*wfs:Update*/ );
           operationElement.appendChild( updateText );
           operationsElement.appendChild( operationElement );
         }
 
-        if ( ( provider->capabilities() & QgsVectorDataProvider::DeleteFeatures ) && wfstDeleteLayersId.contains( layer->id() ) )
+        if ( ( provider->capabilities() & Qgis::VectorProviderCapability::DeleteFeatures ) && wfstDeleteLayersId.contains( layer->id() ) )
         {
           //wfs:Delete element
           QDomElement operationElement = doc.createElement( QStringLiteral( "Operation" ) );
-          const QDomText deleteText = doc.createTextNode( QStringLiteral( "Delete" )/*wfs:Delete*/ );
+          const QDomText deleteText = doc.createTextNode( QStringLiteral( "Delete" ) /*wfs:Delete*/ );
           operationElement.appendChild( deleteText );
           operationsElement.appendChild( operationElement );
         }
