@@ -18,16 +18,10 @@
 //header for class being tested
 #include <[testClassLowerCaseName].h>
 
-class Test[testClassCamelCaseName]: public QObject
-{
-    Q_OBJECT
-  private slots:
+class Test[testClassCamelCaseName] : public QObject {
+  Q_OBJECT private slots:
     [TestMethods]
 };
 
 QGSTEST_MAIN( Test[testClassCamelCaseName] )
 #include "test[testClassLowerCaseName].moc"
-
-
-
-
