@@ -66,9 +66,11 @@ class TestQgsGML : public QObject
     void testPointGML3_EPSG_4326_honour_EPSG_invert();
     void testLineStringGML3();
     void testLineStringGML3_LineStringSegment();
+    void testLineStringGML3_pos();
     void testPolygonGML3();
     void testPolygonGML3_srsDimension_on_Polygon();
     void testPolygonGML3_srsDimension_on_posList();
+    void testPolygonGML3_pos();
     void testMultiLineStringGML3();
     void testMultiPolygonGML3();
     void testPointGML3_2();
@@ -655,6 +657,35 @@ void TestQgsGML::testLineStringGML3_LineStringSegment()
   delete features[0].first;
 }
 
+void TestQgsGML::testLineStringGML3_pos()
+{
+  const QgsFields fields;
+  QgsGmlStreamingParser gmlParser( QStringLiteral( "mytypename" ), QStringLiteral( "mygeom" ), fields );
+  QCOMPARE( gmlParser.processData( QByteArray( "<myns:FeatureCollection "
+                                               "xmlns:myns='http://myns' "
+                                               "xmlns:gml='http://www.opengis.net/gml'>"
+                                               "<gml:featureMember>"
+                                               "<myns:mytypename fid='mytypename.1'>"
+                                               "<myns:mygeom>"
+                                               "<gml:Curve srsName='EPSG:27700'><gml:segments><gml:LineStringSegment><gml:pos>10 20</gml:pos><gml:pos>30 40</gml:pos></gml:LineStringSegment></gml:segments></gml:Curve>"
+                                               "</myns:mygeom>"
+                                               "</myns:mytypename>"
+                                               "</gml:featureMember>"
+                                               "</myns:FeatureCollection>" ),
+                                   true ),
+            true );
+  QCOMPARE( gmlParser.wkbType(), Qgis::WkbType::LineString );
+  QVector<QgsGmlStreamingParser::QgsGmlFeaturePtrGmlIdPair> features = gmlParser.getAndStealReadyFeatures();
+  QCOMPARE( features.size(), 1 );
+  QVERIFY( features[0].first->hasGeometry() );
+  QCOMPARE( features[0].first->geometry().wkbType(), Qgis::WkbType::LineString );
+  QgsPolylineXY line = features[0].first->geometry().asPolyline();
+  QCOMPARE( line.size(), 2 );
+  QCOMPARE( line[0], QgsPointXY( 10, 20 ) );
+  QCOMPARE( line[1], QgsPointXY( 30, 40 ) );
+  delete features[0].first;
+}
+
 void TestQgsGML::testPolygonGML3()
 {
   const QgsFields fields;
@@ -763,6 +794,44 @@ void TestQgsGML::testPolygonGML3_srsDimension_on_posList()
   delete features[0].first;
 }
 
+void TestQgsGML::testPolygonGML3_pos()
+{
+  const QgsFields fields;
+  QgsGmlStreamingParser gmlParser( QStringLiteral( "mytypename" ), QStringLiteral( "mygeom" ), fields );
+  QCOMPARE( gmlParser.processData( QByteArray( "<myns:FeatureCollection "
+                                               "xmlns:myns='http://myns' "
+                                               "xmlns:gml='http://www.opengis.net/gml'>"
+                                               "<gml:featureMember>"
+                                               "<myns:mytypename fid='mytypename.1'>"
+                                               "<myns:mygeom>"
+                                               "<gml:Polygon srsName='EPSG:27700'>"
+                                               "<gml:exterior>"
+                                               "<gml:LinearRing>"
+                                               "<gml:pos srsDimension='3'>0 0 -100 </gml:pos>"
+                                               "<gml:pos srsDimension='3'>0 10 -100</gml:pos>"
+                                               "<gml:pos srsDimension='3'>10 10 -100</gml:pos>"
+                                               "<gml:pos srsDimension='3'>10 0 -100</gml:pos>"
+                                               "<gml:pos srsDimension='3'>0 0 -100</gml:pos>"
+                                               "</gml:LinearRing>"
+                                               "</gml:exterior>"
+                                               "</gml:Polygon>"
+                                               "</myns:mygeom>"
+                                               "</myns:mytypename>"
+                                               "</gml:featureMember>"
+                                               "</myns:FeatureCollection>" ),
+                                   true ),
+            true );
+  QCOMPARE( gmlParser.wkbType(), Qgis::WkbType::Polygon );
+  QVector<QgsGmlStreamingParser::QgsGmlFeaturePtrGmlIdPair> features = gmlParser.getAndStealReadyFeatures();
+  QCOMPARE( features.size(), 1 );
+  QVERIFY( features[0].first->hasGeometry() );
+  QCOMPARE( features[0].first->geometry().wkbType(), Qgis::WkbType::Polygon );
+  QgsPolygonXY poly = features[0].first->geometry().asPolygon();
+  QCOMPARE( poly.size(), 1 );
+  QCOMPARE( poly[0].size(), 5 );
+  delete features[0].first;
+}
+
 void TestQgsGML::testMultiLineStringGML3()
 {
   const QgsFields fields;
