@@ -26,15 +26,16 @@
 
 #include <QStyleOptionGraphicsItem>
 
-class TestQgsLayoutUtils: public QgsTest
+class TestQgsLayoutUtils : public QgsTest
 {
     Q_OBJECT
 
   public:
-    TestQgsLayoutUtils() : QgsTest( QStringLiteral( "Layout Utils Tests" ), QStringLiteral( "composer_utils" ) ) {}
+    TestQgsLayoutUtils()
+      : QgsTest( QStringLiteral( "Layout Utils Tests" ), QStringLiteral( "composer_utils" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
+    void initTestCase(); // will be called before the first testfunction is executed.
     void cleanupTestCase();
     void rotate();
     void normalizedAngle(); //test normalised angle function
@@ -43,23 +44,22 @@ class TestQgsLayoutUtils: public QgsTest
     void createRenderContextFromMap();
     void relativePosition();
     void relativeResizeRect();
-    void pointsToMM(); //test conversion of point size to mm
-    void mmToPoints(); //test conversion of mm to point size
-    void scaledFontPixelSize(); //test creating a scaled font
-    void fontAscentMM(); //test calculating font ascent in mm
-    void fontDescentMM(); //test calculating font descent in mm
-    void fontHeightMM(); //test calculating font height in mm
+    void pointsToMM();            //test conversion of point size to mm
+    void mmToPoints();            //test conversion of mm to point size
+    void scaledFontPixelSize();   //test creating a scaled font
+    void fontAscentMM();          //test calculating font ascent in mm
+    void fontDescentMM();         //test calculating font descent in mm
+    void fontHeightMM();          //test calculating font height in mm
     void fontHeightCharacterMM(); //test calculating font character height in mm
-    void textWidthMM(); //test calculating text width in mm
-    void textHeightMM(); //test calculating text height in mm
-    void drawTextPos(); //test drawing text at a pos
-    void drawTextRect(); //test drawing text in a rect
-    void largestRotatedRect(); //test largest rotated rect helper function
+    void textWidthMM();           //test calculating text width in mm
+    void textHeightMM();          //test calculating text height in mm
+    void drawTextPos();           //test drawing text at a pos
+    void drawTextRect();          //test drawing text in a rect
+    void largestRotatedRect();    //test largest rotated rect helper function
     void decodePaperOrientation();
     void mapLayerFromString();
 
   private:
-
     QFont mTestFont;
 };
 
@@ -78,7 +78,7 @@ void TestQgsLayoutUtils::cleanupTestCase()
 void TestQgsLayoutUtils::rotate()
 {
   // pairs of lines from before -> expected after position and angle to rotate
-  QList< QPair< QLineF, double > > testVals;
+  QList<QPair<QLineF, double>> testVals;
   testVals << qMakePair( QLineF( 0, 1, 0, 1 ), 0.0 );
   testVals << qMakePair( QLineF( 0, 1, -1, 0 ), 90.0 );
   testVals << qMakePair( QLineF( 0, 1, 0, -1 ), 180.0 );
@@ -86,7 +86,7 @@ void TestQgsLayoutUtils::rotate()
   testVals << qMakePair( QLineF( 0, 1, 0, 1 ), 360.0 );
 
   //test rotate helper function
-  QList< QPair< QLineF, double > >::const_iterator it = testVals.constBegin();
+  QList<QPair<QLineF, double>>::const_iterator it = testVals.constBegin();
   for ( ; it != testVals.constEnd(); ++it )
   {
     double x = ( *it ).first.x1();
@@ -99,7 +99,7 @@ void TestQgsLayoutUtils::rotate()
 
 void TestQgsLayoutUtils::normalizedAngle()
 {
-  QList< QPair< double, double > > testVals;
+  QList<QPair<double, double>> testVals;
   testVals << qMakePair( 0.0, 0.0 );
   testVals << qMakePair( 90.0, 90.0 );
   testVals << qMakePair( 180.0, 180.0 );
@@ -114,18 +114,17 @@ void TestQgsLayoutUtils::normalizedAngle()
   testVals << qMakePair( -760.0, 320.0 );
 
   //test normalized angle helper function
-  QList< QPair< double, double > >::const_iterator it = testVals.constBegin();
+  QList<QPair<double, double>>::const_iterator it = testVals.constBegin();
   for ( ; it != testVals.constEnd(); ++it )
 
   {
     const double result = QgsLayoutUtils::normalizedAngle( ( *it ).first );
     qDebug() << QStringLiteral( "actual: %1 expected: %2" ).arg( result ).arg( ( *it ).second );
     QGSCOMPARENEAR( result, ( *it ).second, 4 * std::numeric_limits<double>::epsilon() );
-
   }
 
   //test with allowing negative angles
-  QList< QPair< double, double > > negativeTestVals;
+  QList<QPair<double, double>> negativeTestVals;
   negativeTestVals << qMakePair( 0.0, 0.0 );
   negativeTestVals << qMakePair( 90.0, 90.0 );
   negativeTestVals << qMakePair( 360.0, 0.0 );
@@ -142,13 +141,12 @@ void TestQgsLayoutUtils::normalizedAngle()
     const double result = QgsLayoutUtils::normalizedAngle( ( *it ).first, true );
     qDebug() << QStringLiteral( "actual: %1 expected: %2" ).arg( result ).arg( ( *it ).second );
     QGSCOMPARENEAR( result, ( *it ).second, 4 * std::numeric_limits<double>::epsilon() );
-
   }
 }
 
 void TestQgsLayoutUtils::snappedAngle()
 {
-  QList< QPair< double, double > > testVals;
+  QList<QPair<double, double>> testVals;
   testVals << qMakePair( 0.0, 0.0 );
   testVals << qMakePair( 10.0, 0.0 );
   testVals << qMakePair( 20.0, 0.0 );
@@ -188,7 +186,7 @@ void TestQgsLayoutUtils::snappedAngle()
   testVals << qMakePair( 360.0, 0.0 );
 
   //test snapped angle helper function
-  QList< QPair< double, double > >::const_iterator it = testVals.constBegin();
+  QList<QPair<double, double>>::const_iterator it = testVals.constBegin();
   for ( ; it != testVals.constEnd(); ++it )
   {
     QGSCOMPARENEAR( QgsLayoutUtils::snappedAngle( ( *it ).first ), ( *it ).second, 4 * std::numeric_limits<double>::epsilon() );
@@ -458,7 +456,6 @@ void TestQgsLayoutUtils::fontHeightCharacterMM()
   QGSCOMPARENEAR( QgsLayoutUtils::fontHeightCharacterMM( mTestFont, QChar( 'a' ) ), 2.4, 0.15 );
   QGSCOMPARENEAR( QgsLayoutUtils::fontHeightCharacterMM( mTestFont, QChar( 'l' ) ), 3.15, 0.16 );
   QGSCOMPARENEAR( QgsLayoutUtils::fontHeightCharacterMM( mTestFont, QChar( 'g' ) ), 3.2, 0.11 );
-
 }
 
 void TestQgsLayoutUtils::textWidthMM()
@@ -466,7 +463,6 @@ void TestQgsLayoutUtils::textWidthMM()
   //platform specific font rendering differences mean this test needs to be very lenient
   mTestFont.setPointSize( 12 );
   QGSCOMPARENEAR( QgsLayoutUtils::textWidthMM( mTestFont, QString( "test string" ) ), 20, 2 );
-
 }
 
 void TestQgsLayoutUtils::textHeightMM()
@@ -477,7 +473,6 @@ void TestQgsLayoutUtils::textHeightMM()
   QGSCOMPARENEAR( QgsLayoutUtils::textHeightMM( mTestFont, QString( "test\nstring" ) ), 8.7, 0.2 );
   QGSCOMPARENEAR( QgsLayoutUtils::textHeightMM( mTestFont, QString( "test\nstring" ), 2 ), 13.5, 0.2 );
   QGSCOMPARENEAR( QgsLayoutUtils::textHeightMM( mTestFont, QString( "test\nstring\nstring" ) ), 13.5, 0.2 );
-
 }
 
 void TestQgsLayoutUtils::drawTextPos()
@@ -493,7 +488,7 @@ void TestQgsLayoutUtils::drawTextPos()
   testPainter.begin( &testImage );
   QgsLayoutUtils::drawText( &testPainter, QPointF( 5, 15 ), QStringLiteral( "Abc123" ), mTestFont, Qt::white );
   testPainter.end();
-  QVERIFY( imageCheck( "composerutils_drawtext_pos", "composerutils_drawtext_pos", testImage, QString(), 100 ) );
+  QGSVERIFYIMAGECHECK( "composerutils_drawtext_pos", "composerutils_drawtext_pos", testImage, QString(), 100 );
 
   //test drawing with pen color set on painter and no specified color
   //text should be drawn using painter pen color
@@ -502,7 +497,7 @@ void TestQgsLayoutUtils::drawTextPos()
   testPainter.setPen( QPen( Qt::green ) );
   QgsLayoutUtils::drawText( &testPainter, QPointF( 5, 15 ), QStringLiteral( "Abc123" ), mTestFont );
   testPainter.end();
-  QVERIFY( imageCheck( "composerutils_drawtext_posnocolor", "composerutils_drawtext_posnocolor", testImage, QString(), 100 ) );
+  QGSVERIFYIMAGECHECK( "composerutils_drawtext_posnocolor", "composerutils_drawtext_posnocolor", testImage, QString(), 100 );
 }
 
 void TestQgsLayoutUtils::drawTextRect()
@@ -518,7 +513,7 @@ void TestQgsLayoutUtils::drawTextRect()
   testPainter.begin( &testImage );
   QgsLayoutUtils::drawText( &testPainter, QRectF( 5, 15, 200, 50 ), QStringLiteral( "Abc123" ), mTestFont, Qt::white );
   testPainter.end();
-  QVERIFY( imageCheck( "composerutils_drawtext_rect", "composerutils_drawtext_rect", testImage, QString(), 100 ) );
+  QGSVERIFYIMAGECHECK( "composerutils_drawtext_rect", "composerutils_drawtext_rect", testImage, QString(), 100 );
 
   //test drawing with pen color set on painter and no specified color
   //text should be drawn using painter pen color
@@ -527,21 +522,21 @@ void TestQgsLayoutUtils::drawTextRect()
   testPainter.setPen( QPen( Qt::green ) );
   QgsLayoutUtils::drawText( &testPainter, QRectF( 5, 15, 200, 50 ), QStringLiteral( "Abc123" ), mTestFont );
   testPainter.end();
-  QVERIFY( imageCheck( "composerutils_drawtext_rectnocolor", "composerutils_drawtext_rectnocolor", testImage, QString(), 100 ) );
+  QGSVERIFYIMAGECHECK( "composerutils_drawtext_rectnocolor", "composerutils_drawtext_rectnocolor", testImage, QString(), 100 );
 
   //test alignment settings
   testImage.fill( qRgb( 152, 219, 249 ) );
   testPainter.begin( &testImage );
   QgsLayoutUtils::drawText( &testPainter, QRectF( 5, 15, 200, 50 ), QStringLiteral( "Abc123" ), mTestFont, Qt::black, Qt::AlignRight, Qt::AlignBottom );
   testPainter.end();
-  QVERIFY( imageCheck( "composerutils_drawtext_rectalign", "composerutils_drawtext_rectalign", testImage, QString(), 100 ) );
+  QGSVERIFYIMAGECHECK( "composerutils_drawtext_rectalign", "composerutils_drawtext_rectalign", testImage, QString(), 100 );
 
   //test extra flags - render without clipping
   testImage.fill( qRgb( 152, 219, 249 ) );
   testPainter.begin( &testImage );
   QgsLayoutUtils::drawText( &testPainter, QRectF( 5, 15, 20, 50 ), QStringLiteral( "Abc123" ), mTestFont, Qt::white, Qt::AlignLeft, Qt::AlignTop, Qt::TextDontClip );
   testPainter.end();
-  QVERIFY( imageCheck( "composerutils_drawtext_rectflag", "composerutils_drawtext_rectflag", testImage, QString(), 100 ) );
+  QGSVERIFYIMAGECHECK( "composerutils_drawtext_rectflag", "composerutils_drawtext_rectflag", testImage, QString(), 100 );
 }
 
 void TestQgsLayoutUtils::largestRotatedRect()
@@ -586,8 +581,7 @@ void TestQgsLayoutUtils::largestRotatedRect()
     const QRectF rotatedRectBounds = t.mapRect( result );
     //one of the rotated rects dimensions must equal the bounding rectangles dimensions (ie, it has been constrained by one dimension)
     //and the other dimension must be less than or equal to bounds dimension
-    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) )
-             || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
+    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) ) || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
 
     //also verify that aspect ratio of rectangle has not changed
     QGSCOMPARENEAR( result.width() / result.height(), wideRect.width() / wideRect.height(), 4 * std::numeric_limits<double>::epsilon() );
@@ -601,8 +595,7 @@ void TestQgsLayoutUtils::largestRotatedRect()
     const QRectF rotatedRectBounds = t.mapRect( result );
     //one of the rotated rects dimensions must equal the bounding rectangles dimensions (ie, it has been constrained by one dimension)
     //and the other dimension must be less than or equal to bounds dimension
-    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) )
-             || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
+    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) ) || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
 
     //also verify that aspect ratio of rectangle has not changed
     QGSCOMPARENEAR( result.width() / result.height(), highRect.width() / highRect.height(), 4 * std::numeric_limits<double>::epsilon() );
