@@ -20,7 +20,7 @@
 #include <qgsmaptopixel.h>
 #include <qgspoint.h>
 
-class TestQgsMapToPixel: public QObject
+class TestQgsMapToPixel : public QObject
 {
     Q_OBJECT
   private slots:
@@ -30,6 +30,7 @@ class TestQgsMapToPixel: public QObject
     void fromScale();
     void equality();
     void toMapCoordinates();
+    void transformBounds();
 };
 
 void TestQgsMapToPixel::isValid()
@@ -70,9 +71,9 @@ void TestQgsMapToPixel::rotation()
 {
   QgsMapToPixel m2p( 1, 5, 5, 10, 10, 90 );
 
-  QgsPointXY p( 5, 5 ); // in geographical units
+  QgsPointXY p( 5, 5 );              // in geographical units
   QgsPointXY d = m2p.transform( p ); // to device pixels
-  QCOMPARE( d.x(), 5.0 ); // center doesn't move
+  QCOMPARE( d.x(), 5.0 );            // center doesn't move
   QCOMPARE( d.y(), 5.0 );
 
   const QgsPointXY b = m2p.toMapCoordinates( d.x(), d.y() ); // transform back
@@ -107,7 +108,6 @@ void TestQgsMapToPixel::rotation()
   QCOMPARE( p.y(), 5.5 );
   d = m2p.transform( p );
   QCOMPARE( d, QgsPointXY( 10, 0 ) );
-
 }
 
 void TestQgsMapToPixel::getters()
@@ -184,9 +184,25 @@ void TestQgsMapToPixel::toMapCoordinates()
   QCOMPARE( p, QgsPointXY( 20, 20 ) );
 }
 
+void TestQgsMapToPixel::transformBounds()
+{
+  // no rotation
+  const QgsMapToPixel m2p( 1.5, 5, 15, 20, 10, 0 );
+  QRectF result = m2p.transformBounds( QRectF( 10, 20, 30, 40 ) );
+
+  QGSCOMPARENEAR( result.left(), 13.3333333333, 6 );
+  QGSCOMPARENEAR( result.right(), 33.3333333333, 6 );
+  QCOMPARE( result.top(), -25 );
+  QGSCOMPARENEAR( result.bottom(), 1.66666666667, 6 );
+
+  // with rotation
+  const QgsMapToPixel m2pRotated( 1.5, 5, 15, 20, 10, 45 );
+  result = m2pRotated.transformBounds( QRectF( 10, 20, 30, 40 ) );
+  QGSCOMPARENEAR( result.left(), 14.7140452079, 6 );
+  QGSCOMPARENEAR( result.right(), 47.7123616633, 6 );
+  QGSCOMPARENEAR( result.top(), -13.8561808316, 6 );
+  QGSCOMPARENEAR( result.bottom(), 19.1421356237, 6 );
+}
+
 QGSTEST_MAIN( TestQgsMapToPixel )
 #include "testqgsmaptopixel.moc"
-
-
-
-
