@@ -49,21 +49,23 @@ class TestQgsRasterSubLayer : public QgsTest
     Q_OBJECT
 
   public:
-    TestQgsRasterSubLayer() : QgsTest( QStringLiteral( "Raster Sub Layer Tests" ) ) {}
+    TestQgsRasterSubLayer()
+      : QgsTest( QStringLiteral( "Raster Sub Layer Tests" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
-    void init() {}// will be called before each testfunction is executed.
-    void cleanup() {}// will be called after every testfunction.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
+    void init() {}          // will be called before each testfunction is executed.
+    void cleanup() {}       // will be called after every testfunction.
 
     void subLayersList();
     void checkStats();
+
   private:
     QString mTestDataDir;
     QString mFileName;
     QgsRasterLayer *mpRasterLayer = nullptr;
-    bool mHasNetCDF =  false ;
+    bool mHasNetCDF = false;
 };
 
 //runs before all tests
@@ -87,8 +89,7 @@ void TestQgsRasterSubLayer::initTestCase()
   if ( mHasNetCDF )
   {
     const QFileInfo myRasterFileInfo( mFileName );
-    mpRasterLayer = new QgsRasterLayer( myRasterFileInfo.filePath(),
-                                        myRasterFileInfo.completeBaseName() );
+    mpRasterLayer = new QgsRasterLayer( myRasterFileInfo.filePath(), myRasterFileInfo.completeBaseName() );
   }
   else
   {
@@ -156,8 +157,7 @@ void TestQgsRasterSubLayer::checkStats()
   sublayerUri = sublayerUri.split( QgsDataProvider::sublayerSeparator() )[0];
   QgsRasterLayer *sublayer = new QgsRasterLayer( sublayerUri, QStringLiteral( "Sublayer 1" ) );
 
-  const QgsRasterBandStats myStatistics = sublayer->dataProvider()->bandStatistics( 1,
-                                          QgsRasterBandStats::Min | QgsRasterBandStats::Max );
+  const QgsRasterBandStats myStatistics = sublayer->dataProvider()->bandStatistics( 1, Qgis::RasterBandStatistic::Min | Qgis::RasterBandStatistic::Max );
   const int width = 200;
   const int height = 200;
   const double min = 122;
