@@ -5,16 +5,16 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '11/04/2017'
-__copyright__ = 'Copyright 2018, The QGIS Project'
+
+__author__ = "Nyall Dawson"
+__date__ = "11/04/2017"
+__copyright__ = "Copyright 2018, The QGIS Project"
 
 import http.server
 import os
 import socketserver
 import threading
 
-import qgis  # NOQA
 from qgis.PyQt.QtGui import QColor
 from qgis.PyQt.QtXml import QDomDocument
 from qgis.core import (
@@ -47,10 +47,10 @@ class TestQgsEditFormConfig(QgisTestCase):
         QgsSettings().clear()
 
         # Bring up a simple HTTP server
-        os.chdir(unitTestDataPath() + '')
+        os.chdir(unitTestDataPath() + "")
         handler = http.server.SimpleHTTPRequestHandler
 
-        cls.httpd = socketserver.TCPServer(('localhost', 0), handler)
+        cls.httpd = socketserver.TCPServer(("localhost", 0), handler)
         cls.port = cls.httpd.server_address[1]
 
         cls.httpd_thread = threading.Thread(target=cls.httpd.serve_forever)
@@ -58,8 +58,9 @@ class TestQgsEditFormConfig(QgisTestCase):
         cls.httpd_thread.start()
 
     def createLayer(self):
-        self.layer = QgsVectorLayer("Point?field=fldtxt:string&field=fldint:integer",
-                                    "addfeat", "memory")
+        self.layer = QgsVectorLayer(
+            "Point?field=fldtxt:string&field=fldint:integer", "addfeat", "memory"
+        )
         f = QgsFeature()
         pr = self.layer.dataProvider()
         assert pr.addFeatures([f])
@@ -77,7 +78,7 @@ class TestQgsEditFormConfig(QgisTestCase):
         config.setReuseLastValue(1, True)
 
         doc = QDomDocument("testdoc")
-        elem = doc.createElement('edit')
+        elem = doc.createElement("edit")
         config.writeXml(elem, QgsReadWriteContext())
 
         layer2 = self.createLayer()
@@ -95,28 +96,41 @@ class TestQgsEditFormConfig(QgisTestCase):
         layer = self.createLayer()
         config = layer.editFormConfig()
 
-        config.setLayout(QgsEditFormConfig.GeneratedLayout)
-        self.assertEqual(config.layout(), QgsEditFormConfig.GeneratedLayout)
+        config.setLayout(QgsEditFormConfig.EditorLayout.GeneratedLayout)
+        self.assertEqual(
+            config.layout(), QgsEditFormConfig.EditorLayout.GeneratedLayout
+        )
 
         uiLocal = os.path.join(
-            unitTestDataPath(), '/qgis_local_server/layer_attribute_form.ui')
+            unitTestDataPath(), "/qgis_local_server/layer_attribute_form.ui"
+        )
         config.setUiForm(uiLocal)
-        self.assertEqual(config.layout(), QgsEditFormConfig.UiFileLayout)
+        self.assertEqual(config.layout(), QgsEditFormConfig.EditorLayout.UiFileLayout)
 
-        config.setLayout(QgsEditFormConfig.GeneratedLayout)
-        self.assertEqual(config.layout(), QgsEditFormConfig.GeneratedLayout)
+        config.setLayout(QgsEditFormConfig.EditorLayout.GeneratedLayout)
+        self.assertEqual(
+            config.layout(), QgsEditFormConfig.EditorLayout.GeneratedLayout
+        )
 
-        uiUrl = 'http://localhost:' + \
-            str(self.port) + '/qgis_local_server/layer_attribute_form.ui'
+        uiUrl = (
+            "http://localhost:"
+            + str(self.port)
+            + "/qgis_local_server/layer_attribute_form.ui"
+        )
         config.setUiForm(uiUrl)
-        self.assertEqual(config.layout(), QgsEditFormConfig.UiFileLayout)
-        content = QgsApplication.networkContentFetcherRegistry().fetch(uiUrl, QgsNetworkContentFetcherRegistry.DownloadImmediately)
+        self.assertEqual(config.layout(), QgsEditFormConfig.EditorLayout.UiFileLayout)
+        content = QgsApplication.networkContentFetcherRegistry().fetch(
+            uiUrl, QgsNetworkContentFetcherRegistry.FetchingMode.DownloadImmediately
+        )
         self.assertTrue(content is not None)
         while True:
-            if content.status() in (QgsFetchedContent.Finished, QgsFetchedContent.Failed):
+            if content.status() in (
+                QgsFetchedContent.ContentStatus.Finished,
+                QgsFetchedContent.ContentStatus.Failed,
+            ):
                 break
             app.processEvents()
-        self.assertEqual(content.status(), QgsFetchedContent.Finished)
+        self.assertEqual(content.status(), QgsFetchedContent.ContentStatus.Finished)
 
     # Failing on Travis, seg fault in event loop, no idea why
     """
@@ -134,7 +148,7 @@ class TestQgsEditFormConfig(QgisTestCase):
         pyUrl = 'http://localhost:' + \
             str(self.port) + '/qgis_local_server/layer_attribute_form.py'
 
-        QgsSettings().setEnumValue('qgis/enableMacros', Qgis.Always)
+        QgsSettings().setEnumValue('qgis/enablePythonEmbedded', Qgis.Always)
 
         config.setInitFilePath(pyUrl)
         config.setInitFunction('formOpen')
@@ -215,13 +229,17 @@ class TestQgsEditFormConfig(QgisTestCase):
         """Test backgroundColor serialization"""
 
         layer = self.createLayer()
-        color_name = '#ff00ff'
-        container = QgsAttributeEditorContainer('container name', None, QColor('#ff00ff'))
+        color_name = "#ff00ff"
+        container = QgsAttributeEditorContainer(
+            "container name", None, QColor("#ff00ff")
+        )
         doc = QDomDocument()
         element = container.toDomElement(doc)
-        container2 = QgsAttributeEditorElement.create(element, self.layer.id(), layer.fields(), QgsReadWriteContext(), None)
+        container2 = QgsAttributeEditorElement.create(
+            element, self.layer.id(), layer.fields(), QgsReadWriteContext(), None
+        )
         self.assertEqual(container2.backgroundColor().name(), color_name)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
