@@ -5,11 +5,11 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '18/07/2017'
-__copyright__ = 'Copyright 2017, The QGIS Project'
 
-import qgis  # NOQA
+__author__ = "Nyall Dawson"
+__date__ = "18/07/2017"
+__copyright__ = "Copyright 2017, The QGIS Project"
+
 from qgis.PyQt import sip
 from qgis.PyQt.QtCore import QCoreApplication, QEvent, QPointF, QRectF, Qt
 from qgis.PyQt.QtTest import QSignalSpy
@@ -58,12 +58,16 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, fill)
-        fill.setColor(Qt.green)
-        fill.setStrokeColor(Qt.red)
+        fill.setColor(Qt.GlobalColor.green)
+        fill.setStrokeColor(Qt.GlobalColor.red)
         fill.setStrokeWidth(6)
         collection.setPageStyleSymbol(fill_symbol)
-        self.assertEqual(collection.pageStyleSymbol().symbolLayer(0).color().name(), '#00ff00')
-        self.assertEqual(collection.pageStyleSymbol().symbolLayer(0).strokeColor().name(), '#ff0000')
+        self.assertEqual(
+            collection.pageStyleSymbol().symbolLayer(0).color().name(), "#00ff00"
+        )
+        self.assertEqual(
+            collection.pageStyleSymbol().symbolLayer(0).strokeColor().name(), "#ff0000"
+        )
 
     def testPages(self):
         """
@@ -81,12 +85,12 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         self.assertEqual(collection.pageNumber(page), -1)
 
         collection.addPage(page)
 
-        self.assertTrue(page in l.items())
+        self.assertIn(page, l.items())
 
         self.assertEqual(collection.pageCount(), 1)
         self.assertEqual(collection.pages(), [page])
@@ -97,7 +101,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         self.assertEqual(collection.pageCount(), 2)
@@ -109,9 +113,9 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # insert a page
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize('A3')
+        page3.setPageSize("A3")
         collection.insertPage(page3, 1)
-        self.assertTrue(page3 in l.items())
+        self.assertIn(page3, l.items())
 
         self.assertEqual(collection.pageCount(), 3)
         self.assertEqual(collection.pages(), [page, page3, page2])
@@ -132,11 +136,11 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(collection.pages(), [page, page2])
 
         # make sure page was deleted
-        QCoreApplication.sendPostedEvents(None, QEvent.DeferredDelete)
+        QCoreApplication.sendPostedEvents(None, QEvent.Type.DeferredDelete)
         self.assertTrue(sip.isdeleted(page3))
 
         del l
-        QCoreApplication.sendPostedEvents(None, QEvent.DeferredDelete)
+        QCoreApplication.sendPostedEvents(None, QEvent.Type.DeferredDelete)
         self.assertTrue(sip.isdeleted(page))
         self.assertTrue(sip.isdeleted(page2))
 
@@ -150,11 +154,11 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         page_about_to_be_removed_spy = QSignalSpy(collection.pageAboutToBeRemoved)
@@ -167,17 +171,21 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         page3 = QgsLayoutItemPage(l)
         # try deleting a page not in collection
         collection.deletePage(page3)
-        QCoreApplication.sendPostedEvents(None, QEvent.DeferredDelete)
+        QCoreApplication.sendPostedEvents(None, QEvent.Type.DeferredDelete)
         self.assertFalse(sip.isdeleted(page3))
         self.assertEqual(collection.pageCount(), 2)
         self.assertEqual(len(page_about_to_be_removed_spy), 0)
 
-        self.assertEqual(l.layoutBounds(ignorePages=False), QRectF(0.0, 0.0, 210.0, 517.0))
+        self.assertEqual(
+            l.layoutBounds(ignorePages=False), QRectF(0.0, 0.0, 210.0, 517.0)
+        )
         collection.deletePage(page)
         self.assertEqual(collection.pageCount(), 1)
-        self.assertEqual(l.layoutBounds(ignorePages=False), QRectF(0.0, 0.0, 148.0, 210.0))
-        self.assertFalse(page in collection.pages())
-        QCoreApplication.sendPostedEvents(None, QEvent.DeferredDelete)
+        self.assertEqual(
+            l.layoutBounds(ignorePages=False), QRectF(0.0, 0.0, 148.0, 210.0)
+        )
+        self.assertNotIn(page, collection.pages())
+        QCoreApplication.sendPostedEvents(None, QEvent.Type.DeferredDelete)
         self.assertTrue(sip.isdeleted(page))
         self.assertEqual(len(page_about_to_be_removed_spy), 1)
         self.assertEqual(page_about_to_be_removed_spy[-1][0], 0)
@@ -186,7 +194,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(collection.pageCount(), 0)
         self.assertFalse(collection.pages())
         self.assertEqual(l.layoutBounds(ignorePages=False), QRectF())
-        QCoreApplication.sendPostedEvents(None, QEvent.DeferredDelete)
+        QCoreApplication.sendPostedEvents(None, QEvent.Type.DeferredDelete)
         self.assertTrue(sip.isdeleted(page2))
         self.assertEqual(len(page_about_to_be_removed_spy), 2)
         self.assertEqual(page_about_to_be_removed_spy[-1][0], 0)
@@ -203,11 +211,11 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         page_about_to_be_removed_spy = QSignalSpy(collection.pageAboutToBeRemoved)
@@ -217,7 +225,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(collection.pageCount(), 0)
         self.assertEqual(len(page_about_to_be_removed_spy), 2)
 
-        QCoreApplication.sendPostedEvents(None, QEvent.DeferredDelete)
+        QCoreApplication.sendPostedEvents(None, QEvent.Type.DeferredDelete)
         self.assertTrue(sip.isdeleted(page))
         self.assertTrue(sip.isdeleted(page2))
 
@@ -260,7 +268,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         self.assertEqual(collection.maximumPageWidth(), 210.0)
         self.assertEqual(collection.maximumPageSize().width(), 210.0)
@@ -268,7 +276,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A3')
+        page2.setPageSize("A3")
         collection.addPage(page2)
         self.assertEqual(collection.maximumPageWidth(), 297.0)
         self.assertEqual(collection.maximumPageSize().width(), 297.0)
@@ -276,7 +284,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page with other units
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize(QgsLayoutSize(100, 100, QgsUnitTypes.LayoutMeters))
+        page3.setPageSize(QgsLayoutSize(100, 100, QgsUnitTypes.LayoutUnit.LayoutMeters))
         collection.addPage(page3)
         self.assertEqual(collection.maximumPageWidth(), 100000.0)
         self.assertEqual(collection.maximumPageSize().width(), 100000.0)
@@ -294,19 +302,21 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         self.assertTrue(collection.hasUniformPageSizes())
 
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize(QgsLayoutSize(21.0, 29.7, QgsUnitTypes.LayoutCentimeters))
+        page2.setPageSize(
+            QgsLayoutSize(21.0, 29.7, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+        )
         collection.addPage(page2)
         self.assertTrue(collection.hasUniformPageSizes())
 
         # add a page with other units
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize('A5')
+        page3.setPageSize("A5")
         collection.addPage(page3)
         self.assertFalse(collection.hasUniformPageSizes())
 
@@ -320,7 +330,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
 
         # should be positioned at origin
@@ -329,7 +339,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         self.assertEqual(page.pos().x(), 0)
@@ -339,7 +349,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # third page, slotted in middle
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize('A3')
+        page3.setPageSize("A3")
         collection.insertPage(page3, 1)
 
         self.assertEqual(page.pos().x(), 0)
@@ -372,10 +382,10 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         # item on pages
@@ -394,7 +404,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # third page, slotted in middle
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize('A3')
+        page3.setPageSize("A3")
         collection.insertPage(page3, 0)
 
         # check item position
@@ -410,13 +420,13 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A4')
+        page2.setPageSize("A4")
         collection.addPage(page2)
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize('A4')
+        page3.setPageSize("A4")
         collection.addPage(page3)
 
         # item on pages
@@ -448,13 +458,13 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A4')
+        page2.setPageSize("A4")
         collection.addPage(page2)
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize('A4')
+        page3.setPageSize("A4")
         collection.addPage(page3)
 
         # item on pages
@@ -486,13 +496,13 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add some pages
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
         page3 = QgsLayoutItemPage(l)
-        page3.setPageSize('A5')
+        page3.setPageSize("A5")
         collection.addPage(page3)
 
         self.assertEqual(page.pos().x(), 0)
@@ -502,7 +512,10 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(page3.pos().x(), 0)
         self.assertEqual(page3.pos().y(), 527)
 
-        page.dataDefinedProperties().setProperty(QgsLayoutObject.ItemHeight, QgsProperty.fromExpression('50*3'))
+        page.dataDefinedProperties().setProperty(
+            QgsLayoutObject.DataDefinedProperty.ItemHeight,
+            QgsProperty.fromExpression("50*3"),
+        )
         page.refresh()
         collection.reflow()
         self.assertEqual(page.pos().x(), 0)
@@ -512,7 +525,10 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(page3.pos().x(), 0)
         self.assertEqual(page3.pos().y(), 380)
 
-        page2.dataDefinedProperties().setProperty(QgsLayoutObject.ItemHeight, QgsProperty.fromExpression('50-20'))
+        page2.dataDefinedProperties().setProperty(
+            QgsLayoutObject.DataDefinedProperty.ItemHeight,
+            QgsProperty.fromExpression("50-20"),
+        )
         page2.refresh()
         collection.reflow()
         self.assertEqual(page.pos().x(), 0)
@@ -532,7 +548,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
 
         self.assertEqual(collection.pageNumberForPoint(QPointF(-100, -100)), 0)
@@ -541,14 +557,22 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(collection.pageNumberForPoint(QPointF(-100, 270)), 0)
         self.assertEqual(collection.pageNumberForPoint(QPointF(-100, 1270)), 0)
 
-        self.assertEqual(collection.positionOnPage(QPointF(-100, -100)), QPointF(-100, -100))
-        self.assertEqual(collection.positionOnPage(QPointF(-100, -1)), QPointF(-100, -1))
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, -100)), QPointF(-100, -100)
+        )
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, -1)), QPointF(-100, -1)
+        )
         self.assertEqual(collection.positionOnPage(QPointF(-100, 1)), QPointF(-100, 1))
-        self.assertEqual(collection.positionOnPage(QPointF(-100, 270)), QPointF(-100, 270))
-        self.assertEqual(collection.positionOnPage(QPointF(-100, 1270)), QPointF(-100, 973))
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, 270)), QPointF(-100, 270)
+        )
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, 1270)), QPointF(-100, 973)
+        )
 
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         self.assertEqual(collection.pageNumberForPoint(QPointF(-100, -100)), 0)
@@ -558,12 +582,22 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(collection.pageNumberForPoint(QPointF(-100, 370)), 1)
         self.assertEqual(collection.pageNumberForPoint(QPointF(-100, 1270)), 1)
 
-        self.assertEqual(collection.positionOnPage(QPointF(-100, -100)), QPointF(-100, -100))
-        self.assertEqual(collection.positionOnPage(QPointF(-100, -1)), QPointF(-100, -1))
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, -100)), QPointF(-100, -100)
+        )
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, -1)), QPointF(-100, -1)
+        )
         self.assertEqual(collection.positionOnPage(QPointF(-100, 1)), QPointF(-100, 1))
-        self.assertEqual(collection.positionOnPage(QPointF(-100, 270)), QPointF(-100, 270))
-        self.assertEqual(collection.positionOnPage(QPointF(-100, 370)), QPointF(-100, 63))
-        self.assertEqual(collection.positionOnPage(QPointF(-100, 1270)), QPointF(-100, 753))
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, 270)), QPointF(-100, 270)
+        )
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, 370)), QPointF(-100, 63)
+        )
+        self.assertEqual(
+            collection.positionOnPage(QPointF(-100, 1270)), QPointF(-100, 753)
+        )
 
     def testPredictionPageNumberForPoint(self):
         """
@@ -628,7 +662,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
 
         self.assertFalse(collection.pageAtPoint(QPointF(10, -1)))
@@ -640,7 +674,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertFalse(collection.pageAtPoint(QPointF(10, 1000)))
 
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         self.assertEqual(collection.pageAtPoint(QPointF(1, 1)), page)
@@ -661,43 +695,91 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         collection = l.pageCollection()
 
         # invalid pages
-        self.assertEqual(collection.pagePositionToLayoutPosition(-1, QgsLayoutPoint(1, 1)), QPointF(1, 1))
-        self.assertEqual(collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(1, 1)), QPointF(1, 1))
-        self.assertEqual(collection.pagePositionToLayoutPosition(100, QgsLayoutPoint(1, 1)), QPointF(1, 1))
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(-1, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(100, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
 
         # invalid pages
-        self.assertEqual(collection.pagePositionToLayoutPosition(-1, QgsLayoutPoint(1, 1)), QPointF(1, 1))
-        self.assertEqual(collection.pagePositionToLayoutPosition(1, QgsLayoutPoint(1, 1)), QPointF(1, 1))
-        # valid page
-        self.assertEqual(collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(1, 1)), QPointF(1, 1))
-        self.assertEqual(collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(5, 6)), QPointF(5, 6))
         self.assertEqual(
-            collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutCentimeters)),
-            QPointF(50, 60))
+            collection.pagePositionToLayoutPosition(-1, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(1, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
+        # valid page
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(5, 6)),
+            QPointF(5, 6),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(
+                0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+            ),
+            QPointF(50, 60),
+        )
 
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         # invalid pages
-        self.assertEqual(collection.pagePositionToLayoutPosition(-1, QgsLayoutPoint(1, 1)), QPointF(1, 1))
-        self.assertEqual(collection.pagePositionToLayoutPosition(3, QgsLayoutPoint(1, 1)), QPointF(1, 1))
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(-1, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(3, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
         # valid pages
-        self.assertEqual(collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(1, 1)), QPointF(1, 1))
-        self.assertEqual(collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(5, 6)), QPointF(5, 6))
         self.assertEqual(
-            collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutCentimeters)),
-            QPointF(50, 60))
-        self.assertEqual(collection.pagePositionToLayoutPosition(1, QgsLayoutPoint(1, 1)), QPointF(1, 308.0))
-        self.assertEqual(collection.pagePositionToLayoutPosition(1, QgsLayoutPoint(5, 6)), QPointF(5, 313.0))
+            collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(1, 1)),
+            QPointF(1, 1),
+        )
         self.assertEqual(
-            collection.pagePositionToLayoutPosition(1, QgsLayoutPoint(0.5, 0.6, QgsUnitTypes.LayoutCentimeters)),
-            QPointF(5, 313.0))
+            collection.pagePositionToLayoutPosition(0, QgsLayoutPoint(5, 6)),
+            QPointF(5, 6),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(
+                0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+            ),
+            QPointF(50, 60),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(1, QgsLayoutPoint(1, 1)),
+            QPointF(1, 308.0),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(1, QgsLayoutPoint(5, 6)),
+            QPointF(5, 313.0),
+        )
+        self.assertEqual(
+            collection.pagePositionToLayoutPosition(
+                1, QgsLayoutPoint(0.5, 0.6, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+            ),
+            QPointF(5, 313.0),
+        )
 
     def testPagePositionToAbsolute(self):
         """
@@ -708,40 +790,91 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         collection = l.pageCollection()
 
         # invalid pages
-        self.assertEqual(collection.pagePositionToAbsolute(-1, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
-        self.assertEqual(collection.pagePositionToAbsolute(0, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
-        self.assertEqual(collection.pagePositionToAbsolute(100, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
+        self.assertEqual(
+            collection.pagePositionToAbsolute(-1, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(0, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(100, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
 
         # invalid pages
-        self.assertEqual(collection.pagePositionToAbsolute(-1, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
-        self.assertEqual(collection.pagePositionToAbsolute(1, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
+        self.assertEqual(
+            collection.pagePositionToAbsolute(-1, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(1, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
         # valid page
-        self.assertEqual(collection.pagePositionToAbsolute(0, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
-        self.assertEqual(collection.pagePositionToAbsolute(0, QgsLayoutPoint(5, 6)), QgsLayoutPoint(5, 6))
-        self.assertEqual(collection.pagePositionToAbsolute(0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutCentimeters)),
-                         QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutCentimeters))
+        self.assertEqual(
+            collection.pagePositionToAbsolute(0, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(0, QgsLayoutPoint(5, 6)),
+            QgsLayoutPoint(5, 6),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(
+                0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+            ),
+            QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutUnit.LayoutCentimeters),
+        )
 
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         # invalid pages
-        self.assertEqual(collection.pagePositionToAbsolute(-1, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
-        self.assertEqual(collection.pagePositionToAbsolute(3, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
+        self.assertEqual(
+            collection.pagePositionToAbsolute(-1, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(3, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
         # valid pages
-        self.assertEqual(collection.pagePositionToAbsolute(0, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 1))
-        self.assertEqual(collection.pagePositionToAbsolute(0, QgsLayoutPoint(5, 6)), QgsLayoutPoint(5, 6))
-        self.assertEqual(collection.pagePositionToAbsolute(0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutCentimeters)),
-                         QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutCentimeters))
-        self.assertEqual(collection.pagePositionToAbsolute(1, QgsLayoutPoint(1, 1)), QgsLayoutPoint(1, 308.0))
-        self.assertEqual(collection.pagePositionToAbsolute(1, QgsLayoutPoint(5, 6)), QgsLayoutPoint(5, 313.0))
-        self.assertEqual(collection.pagePositionToAbsolute(1, QgsLayoutPoint(0.5, 0.6, QgsUnitTypes.LayoutCentimeters)),
-                         QgsLayoutPoint(0.5, 31.3, QgsUnitTypes.LayoutCentimeters))
+        self.assertEqual(
+            collection.pagePositionToAbsolute(0, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 1),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(0, QgsLayoutPoint(5, 6)),
+            QgsLayoutPoint(5, 6),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(
+                0, QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+            ),
+            QgsLayoutPoint(5, 6, QgsUnitTypes.LayoutUnit.LayoutCentimeters),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(1, QgsLayoutPoint(1, 1)),
+            QgsLayoutPoint(1, 308.0),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(1, QgsLayoutPoint(5, 6)),
+            QgsLayoutPoint(5, 313.0),
+        )
+        self.assertEqual(
+            collection.pagePositionToAbsolute(
+                1, QgsLayoutPoint(0.5, 0.6, QgsUnitTypes.LayoutUnit.LayoutCentimeters)
+            ),
+            QgsLayoutPoint(0.5, 31.3, QgsUnitTypes.LayoutUnit.LayoutCentimeters),
+        )
 
     def testVisiblePages(self):
         p = QgsProject()
@@ -753,7 +886,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
 
         self.assertFalse(collection.visiblePages(QRectF(-10, -10, 5, 5)))
@@ -764,7 +897,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(collection.visiblePageNumbers(QRectF(200, 200, 115, 115)), [0])
 
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         self.assertFalse(collection.visiblePages(QRectF(-10, -10, 5, 5)))
@@ -776,8 +909,12 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         self.assertEqual(collection.visiblePages(QRectF(200, 200, 115, 615)), [page])
         self.assertEqual(collection.visiblePageNumbers(QRectF(200, 200, 115, 115)), [0])
-        self.assertEqual(collection.visiblePages(QRectF(100, 200, 115, 615)), [page, page2])
-        self.assertEqual(collection.visiblePageNumbers(QRectF(100, 200, 115, 115)), [0, 1])
+        self.assertEqual(
+            collection.visiblePages(QRectF(100, 200, 115, 615)), [page, page2]
+        )
+        self.assertEqual(
+            collection.visiblePageNumbers(QRectF(100, 200, 115, 115)), [0, 1]
+        )
         self.assertEqual(collection.visiblePages(QRectF(100, 310, 115, 615)), [page2])
         self.assertEqual(collection.visiblePageNumbers(QRectF(100, 310, 115, 115)), [1])
 
@@ -788,10 +925,10 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add some pages
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         self.assertEqual(collection.pageCount(), 2)
@@ -820,21 +957,21 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         fill = QgsSimpleFillSymbolLayer()
         fill_symbol = QgsFillSymbol()
         fill_symbol.changeSymbolLayer(0, fill)
-        fill.setColor(Qt.green)
-        fill.setStrokeColor(Qt.red)
+        fill.setColor(Qt.GlobalColor.green)
+        fill.setStrokeColor(Qt.GlobalColor.red)
         fill.setStrokeWidth(6)
         collection.setPageStyleSymbol(fill_symbol)
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         self.assertEqual(collection.pageNumber(page), -1)
 
         collection.addPage(page)
 
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         doc = QDomDocument("testdoc")
@@ -844,7 +981,9 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         l2 = QgsLayout(p)
         collection2 = l2.pageCollection()
 
-        self.assertTrue(collection2.readXml(elem.firstChildElement(), doc, QgsReadWriteContext()))
+        self.assertTrue(
+            collection2.readXml(elem.firstChildElement(), doc, QgsReadWriteContext())
+        )
 
         self.assertEqual(collection2.pageCount(), 2)
         self.assertEqual(collection2.page(0).pageSize().width(), 210)
@@ -852,8 +991,12 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         self.assertEqual(collection2.page(1).pageSize().width(), 148)
         self.assertEqual(collection2.page(1).pageSize().height(), 210)
 
-        self.assertEqual(collection2.pageStyleSymbol().symbolLayer(0).color().name(), '#00ff00')
-        self.assertEqual(collection2.pageStyleSymbol().symbolLayer(0).strokeColor().name(), '#ff0000')
+        self.assertEqual(
+            collection2.pageStyleSymbol().symbolLayer(0).color().name(), "#00ff00"
+        )
+        self.assertEqual(
+            collection2.pageStyleSymbol().symbolLayer(0).strokeColor().name(), "#ff0000"
+        )
 
     def testUndoRedo(self):
         p = QgsProject()
@@ -862,7 +1005,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a page
         page = QgsLayoutItemPage(l)
-        page.setPageSize('A4')
+        page.setPageSize("A4")
         collection.addPage(page)
         self.assertEqual(collection.pageCount(), 1)
 
@@ -876,7 +1019,7 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize('A5')
+        page2.setPageSize("A5")
         collection.addPage(page2)
 
         # delete page
@@ -910,15 +1053,23 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         l = QgsLayout(p)
 
         # no items -- no crash!
-        l.pageCollection().resizeToContents(QgsMargins(1, 2, 3, 4), QgsUnitTypes.LayoutCentimeters)
+        l.pageCollection().resizeToContents(
+            QgsMargins(1, 2, 3, 4), QgsUnitTypes.LayoutUnit.LayoutCentimeters
+        )
         page = QgsLayoutItemPage(l)
-        page.setPageSize("A5", QgsLayoutItemPage.Landscape)
+        page.setPageSize("A5", QgsLayoutItemPage.Orientation.Landscape)
         l.pageCollection().addPage(page)
         # no items, no change
-        l.pageCollection().resizeToContents(QgsMargins(1, 2, 3, 4), QgsUnitTypes.LayoutCentimeters)
+        l.pageCollection().resizeToContents(
+            QgsMargins(1, 2, 3, 4), QgsUnitTypes.LayoutUnit.LayoutCentimeters
+        )
         self.assertEqual(l.pageCollection().pageCount(), 1)
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().width(), 210.0, 2)
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().height(), 148.0, 2)
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().width(), 210.0, 2
+        )
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().height(), 148.0, 2
+        )
 
         p = QgsProject()
         l = QgsLayout(p)
@@ -942,12 +1093,21 @@ class TestQgsLayoutPageCollection(QgisTestCase):
         shape4.setVisibility(False)
 
         # resize with no existing pages
-        l.pageCollection().resizeToContents(QgsMargins(1, 2, 3, 4), QgsUnitTypes.LayoutCentimeters)
+        l.pageCollection().resizeToContents(
+            QgsMargins(1, 2, 3, 4), QgsUnitTypes.LayoutUnit.LayoutCentimeters
+        )
         self.assertEqual(l.pageCollection().pageCount(), 1)
 
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().width(), 290.3, 2)
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().height(), 380.36, 2)
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().units(), QgsUnitTypes.LayoutMillimeters)
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().width(), 290.3, 2
+        )
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().height(), 380.36, 2
+        )
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().units(),
+            QgsUnitTypes.LayoutUnit.LayoutMillimeters,
+        )
 
         self.assertAlmostEqual(shape1.positionWithUnits().x(), 90.15, 2)
         self.assertAlmostEqual(shape1.positionWithUnits().y(), 20.21, 2)
@@ -960,28 +1120,43 @@ class TestQgsLayoutPageCollection(QgisTestCase):
 
         # add a second page
         page2 = QgsLayoutItemPage(l)
-        page2.setPageSize("A4", QgsLayoutItemPage.Landscape)
+        page2.setPageSize("A4", QgsLayoutItemPage.Orientation.Landscape)
         l.pageCollection().addPage(page2)
 
         # add some guides
-        g1 = QgsLayoutGuide(Qt.Horizontal, QgsLayoutMeasurement(2.5, QgsUnitTypes.LayoutCentimeters),
-                            l.pageCollection().page(0))
+        g1 = QgsLayoutGuide(
+            Qt.Orientation.Horizontal,
+            QgsLayoutMeasurement(2.5, QgsUnitTypes.LayoutUnit.LayoutCentimeters),
+            l.pageCollection().page(0),
+        )
         l.guides().addGuide(g1)
-        g2 = QgsLayoutGuide(Qt.Vertical, QgsLayoutMeasurement(4.5, QgsUnitTypes.LayoutCentimeters),
-                            l.pageCollection().page(0))
+        g2 = QgsLayoutGuide(
+            Qt.Orientation.Vertical,
+            QgsLayoutMeasurement(4.5, QgsUnitTypes.LayoutUnit.LayoutCentimeters),
+            l.pageCollection().page(0),
+        )
         l.guides().addGuide(g2)
 
         # second page should be removed
-        l.pageCollection().resizeToContents(QgsMargins(0, 0, 0, 0), QgsUnitTypes.LayoutCentimeters)
+        l.pageCollection().resizeToContents(
+            QgsMargins(0, 0, 0, 0), QgsUnitTypes.LayoutUnit.LayoutCentimeters
+        )
         self.assertEqual(l.pageCollection().pageCount(), 1)
 
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().width(), 250.3, 2)
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().height(), 320.36, 2)
-        self.assertAlmostEqual(l.pageCollection().page(0).sizeWithUnits().units(), QgsUnitTypes.LayoutMillimeters)
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().width(), 250.3, 2
+        )
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().height(), 320.36, 2
+        )
+        self.assertAlmostEqual(
+            l.pageCollection().page(0).sizeWithUnits().units(),
+            QgsUnitTypes.LayoutUnit.LayoutMillimeters,
+        )
 
         self.assertAlmostEqual(g1.position().length(), 0.5, 2)
         self.assertAlmostEqual(g2.position().length(), 3.5, 2)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
