@@ -5,22 +5,25 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = '(C) 2016 by Paul Blottiere'
-__date__ = '14/03/2016'
-__copyright__ = 'Copyright 2016, The QGIS Project'
 
-import qgis  # NOQA
-from qgis.PyQt.QtCore import QPointF
+__author__ = "(C) 2016 by Paul Blottiere"
+__date__ = "14/03/2016"
+__copyright__ = "Copyright 2016, The QGIS Project"
+
+from qgis.PyQt.QtCore import QPointF, QRectF
 from qgis.PyQt.QtGui import QPolygonF
 from qgis.PyQt.QtXml import QDomDocument
 from qgis.core import (
+    Qgis,
     QgsLayout,
     QgsLayoutItemPolyline,
+    QgsLayoutItemMap,
     QgsLayoutItemRegistry,
     QgsLineSymbol,
     QgsProject,
     QgsReadWriteContext,
-    QgsLayoutChecker
+    QgsGeometryGeneratorSymbolLayer,
+    QgsRectangle,
 )
 import unittest
 from qgis.testing import start_app, QgisTestCase
@@ -34,9 +37,13 @@ TEST_DATA_DIR = unitTestDataPath()
 
 class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
 
+    @classmethod
+    def control_path_prefix(cls):
+        return "composer_polyline"
+
     @classmethod
     def setUpClass(cls):
-        super(TestQgsLayoutPolyline, cls).setUpClass()
+        super().setUpClass()
         cls.item_class = QgsLayoutItemPolyline
 
     def __init__(self, methodName):
@@ -54,8 +61,7 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         polygon.append(QPointF(200.0, 100.0))
         polygon.append(QPointF(100.0, 200.0))
 
-        self.polyline = QgsLayoutItemPolyline(
-            polygon, self.layout)
+        self.polyline = QgsLayoutItemPolyline(polygon, self.layout)
         self.layout.addLayoutItem(self.polyline)
 
         # style
@@ -95,34 +101,29 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         """Test if type is valid"""
 
         self.assertEqual(
-            self.polyline.type(), QgsLayoutItemRegistry.LayoutPolyline)
+            self.polyline.type(), QgsLayoutItemRegistry.ItemType.LayoutPolyline
+        )
 
     def testDefaultStyle(self):
         """Test polygon rendering with default style."""
 
         self.polyline.setDisplayNodes(False)
-        checker = QgsLayoutChecker(
-            'composerpolyline_defaultstyle', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_defaultstyle", self.layout)
+        )
 
     def testDisplayNodes(self):
         """Test displayNodes method"""
 
         self.polyline.setDisplayNodes(True)
-        checker = QgsLayoutChecker(
-            'composerpolyline_displaynodes', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_displaynodes", self.layout)
+        )
 
         self.polyline.setDisplayNodes(False)
-        checker = QgsLayoutChecker(
-            'composerpolyline_defaultstyle', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_defaultstyle", self.layout)
+        )
 
     def testSelectedNode(self):
         """Test selectedNode and deselectNode methods"""
@@ -130,30 +131,24 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         self.polyline.setDisplayNodes(True)
 
         self.polyline.setSelectedNode(3)
-        checker = QgsLayoutChecker(
-            'composerpolyline_selectednode', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_selectednode", self.layout)
+        )
 
         self.polyline.deselectNode()
         self.polyline.setDisplayNodes(False)
-        checker = QgsLayoutChecker(
-            'composerpolyline_defaultstyle', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_defaultstyle", self.layout)
+        )
 
     def testEndArrow(self):
-        self.polyline.setEndMarker(QgsLayoutItemPolyline.ArrowHead)
+        self.polyline.setEndMarker(QgsLayoutItemPolyline.MarkerMode.ArrowHead)
         self.polyline.setArrowHeadWidth(30.0)
 
-        checker = QgsLayoutChecker('composerpolyline_endArrow', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
-
-        self.polyline.setEndMarker(QgsLayoutItemPolyline.NoMarker)
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_endArrow", self.layout)
+        )
+        self.polyline.setEndMarker(QgsLayoutItemPolyline.MarkerMode.NoMarker)
 
     def testRemoveNode(self):
         """Test removeNode method"""
@@ -161,22 +156,18 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         rc = self.polyline.removeNode(100)
         self.assertEqual(rc, False)
 
-        checker = QgsLayoutChecker(
-            'composerpolyline_defaultstyle', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_defaultstyle", self.layout)
+        )
 
         self.assertEqual(self.polyline.nodesSize(), 4)
         rc = self.polyline.removeNode(3)
         self.assertEqual(rc, True)
         self.assertEqual(self.polyline.nodesSize(), 3)
 
-        checker = QgsLayoutChecker(
-            'composerpolyline_removednode', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_removednode", self.layout)
+        )
 
     def testAddNode(self):
         """Test addNode method"""
@@ -221,11 +212,9 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         self.assertEqual(rc, True)
         self.assertEqual(self.polyline.nodesSize(), 5)
 
-        checker = QgsLayoutChecker(
-            'composerpolyline_addnode', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_addnode", self.layout)
+        )
 
     def testMoveNode(self):
         """Test moveNode method"""
@@ -236,11 +225,9 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         rc = self.polyline.moveNode(3, QPointF(100.0, 150.0))
         self.assertEqual(rc, True)
 
-        checker = QgsLayoutChecker(
-            'composerpolyline_movenode', self.layout)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(
+            self.render_layout_check("composerpolyline_movenode", self.layout)
+        )
 
     def testNodeAtPosition(self):
         """Test nodeAtPosition method"""
@@ -250,13 +237,11 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         self.assertEqual(rc, -1)
 
         # default searching radius is 10
-        rc = self.polyline.nodeAtPosition(
-            QPointF(100.0, 210.0), False)
+        rc = self.polyline.nodeAtPosition(QPointF(100.0, 210.0), False)
         self.assertEqual(rc, 3)
 
         # default searching radius is 10
-        rc = self.polyline.nodeAtPosition(
-            QPointF(100.0, 210.0), True, 10.1)
+        rc = self.polyline.nodeAtPosition(QPointF(100.0, 210.0), True, 10.1)
         self.assertEqual(rc, 3)
 
     def testReadWriteXml(self):
@@ -283,10 +268,12 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         self.assertTrue(shape.writeXml(elem, doc, QgsReadWriteContext()))
 
         shape2 = QgsLayoutItemPolyline(l)
-        self.assertTrue(shape2.readXml(elem.firstChildElement(), doc, QgsReadWriteContext()))
+        self.assertTrue(
+            shape2.readXml(elem.firstChildElement(), doc, QgsReadWriteContext())
+        )
 
         self.assertEqual(shape2.nodes(), shape.nodes())
-        self.assertEqual(shape2.symbol().symbolLayer(0).color().name(), '#ff0000')
+        self.assertEqual(shape2.symbol().symbolLayer(0).color().name(), "#ff0000")
 
     def testBounds(self):
         pr = QgsProject()
@@ -339,11 +326,7 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         style = QgsLineSymbol.createSimple(props)
         shape.setSymbol(style)
 
-        checker = QgsLayoutChecker(
-            'composerpolyline_hozline', l)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(self.render_layout_check("composerpolyline_hozline", l))
 
     def testVerticalLine(self):
         pr = QgsProject()
@@ -364,12 +347,46 @@ class TestQgsLayoutPolyline(QgisTestCase, LayoutItemTestCase):
         style = QgsLineSymbol.createSimple(props)
         shape.setSymbol(style)
 
-        checker = QgsLayoutChecker(
-            'composerpolyline_vertline', l)
-        checker.setControlPathPrefix("composer_polyline")
-        myTestResult, myMessage = checker.testLayout()
-        assert myTestResult, myMessage
+        self.assertTrue(self.render_layout_check("composerpolyline_vertline", l))
+
+    def test_generator(self):
+        project = QgsProject()
+        layout = QgsLayout(project)
+        layout.initializeDefaults()
+
+        p = QPolygonF()
+        p.append(QPointF(0.0, 0.0))
+        p.append(QPointF(100.0, 100.0))
+        shape = QgsLayoutItemPolyline(p, layout)
+        layout.addLayoutItem(shape)
+
+        map = QgsLayoutItemMap(layout)
+        map.attemptSetSceneRect(QRectF(0, 0, 10, 10))
+        map.zoomToExtent(QgsRectangle(1, 1, 2, 2))
+        layout.addLayoutItem(map)
+
+        props = {}
+        props["color"] = "0,0,0,255"
+        props["width"] = "10.0"
+        props["capstyle"] = "square"
+
+        sub_symbol = QgsLineSymbol.createSimple(props)
+
+        line_symbol = QgsLineSymbol()
+        generator = QgsGeometryGeneratorSymbolLayer.create(
+            {
+                "geometryModifier": "geom_from_wkt('POLYGON((10 10,287 10,287 200,10 200,10 10))')",
+                "SymbolType": "Line",
+            }
+        )
+        generator.setUnits(Qgis.RenderUnit.Millimeters)
+        generator.setSubSymbol(sub_symbol)
+
+        line_symbol.changeSymbolLayer(0, generator)
+        shape.setSymbol(line_symbol)
+
+        self.assertTrue(self.render_layout_check("polyline_generator", layout))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
