@@ -5,15 +5,15 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
-__author__ = 'Nyall Dawson'
-__date__ = '22/07/2019'
-__copyright__ = 'Copyright 2019, The QGIS Project'
+
+__author__ = "Nyall Dawson"
+__date__ = "22/07/2019"
+__copyright__ = "Copyright 2019, The QGIS Project"
 
 import gc
 import os
 import tempfile
 
-import qgis  # NOQA
 from qgis.core import (
     QgsApplication,
     QgsPathResolver,
@@ -33,9 +33,9 @@ TEST_DATA_DIR = unitTestDataPath()
 class TestQgsPathResolver(QgisTestCase):
 
     def testCustomPreprocessor(self):
-        self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'aaaaa')
+        self.assertEqual(QgsPathResolver().readPath("aaaaa"), "aaaaa")
         with self.assertRaises(KeyError):
-            QgsPathResolver().removePathPreprocessor('bad')
+            QgsPathResolver().removePathPreprocessor("bad")
 
         def run_test():
             def my_processor(path):
@@ -43,17 +43,17 @@ class TestQgsPathResolver(QgisTestCase):
 
             id = QgsPathResolver.setPathPreprocessor(my_processor)
             self.assertTrue(id)
-            self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'AAAAA')
+            self.assertEqual(QgsPathResolver().readPath("aaaaa"), "AAAAA")
             return id
 
         id = run_test()
         gc.collect()
         # my_processor should be out of scope and cleaned up, unless things are working
         # correctly and ownership was transferred
-        self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'AAAAA')
+        self.assertEqual(QgsPathResolver().readPath("aaaaa"), "AAAAA")
 
         QgsPathResolver().removePathPreprocessor(id)
-        self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'aaaaa')
+        self.assertEqual(QgsPathResolver().readPath("aaaaa"), "aaaaa")
 
         # expect key error
         with self.assertRaises(KeyError):
@@ -63,24 +63,24 @@ class TestQgsPathResolver(QgisTestCase):
         """
         Test that chaining preprocessors works correctly
         """
-        self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'aaaaa')
+        self.assertEqual(QgsPathResolver().readPath("aaaaa"), "aaaaa")
 
         def run_test():
             def my_processor(path):
-                return 'x' + path + 'x'
+                return "x" + path + "x"
 
             def my_processor2(path):
-                return 'y' + path + 'y'
+                return "y" + path + "y"
 
             id = QgsPathResolver.setPathPreprocessor(my_processor)
             self.assertTrue(id)
 
-            self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'xaaaaax')
+            self.assertEqual(QgsPathResolver().readPath("aaaaa"), "xaaaaax")
 
             id2 = QgsPathResolver.setPathPreprocessor(my_processor2)
             self.assertTrue(id2)
 
-            self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'yxaaaaaxy')
+            self.assertEqual(QgsPathResolver().readPath("aaaaa"), "yxaaaaaxy")
 
             return id, id2
 
@@ -88,17 +88,17 @@ class TestQgsPathResolver(QgisTestCase):
         gc.collect()
         # my_processor should be out of scope and cleaned up, unless things are working
         # correctly and ownership was transferred
-        self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'yxaaaaaxy')
+        self.assertEqual(QgsPathResolver().readPath("aaaaa"), "yxaaaaaxy")
 
         QgsPathResolver().removePathPreprocessor(id)
-        self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'yaaaaay')
+        self.assertEqual(QgsPathResolver().readPath("aaaaa"), "yaaaaay")
 
         # expect key error
         with self.assertRaises(KeyError):
             QgsPathResolver().removePathPreprocessor(id)
 
         QgsPathResolver().removePathPreprocessor(id2)
-        self.assertEqual(QgsPathResolver().readPath('aaaaa'), 'aaaaa')
+        self.assertEqual(QgsPathResolver().readPath("aaaaa"), "aaaaa")
 
         with self.assertRaises(KeyError):
             QgsPathResolver().removePathPreprocessor(id2)
@@ -107,32 +107,32 @@ class TestQgsPathResolver(QgisTestCase):
         """
         Test that custom path preprocessor is used when loading layers
         """
-        lines_shp_path = os.path.join(TEST_DATA_DIR, 'moooooo.shp')
+        lines_shp_path = os.path.join(TEST_DATA_DIR, "moooooo.shp")
 
-        lines_layer = QgsVectorLayer(lines_shp_path, 'Lines', 'ogr')
+        lines_layer = QgsVectorLayer(lines_shp_path, "Lines", "ogr")
         self.assertFalse(lines_layer.isValid())
         p = QgsProject()
         p.addMapLayer(lines_layer)
         # save project to a temporary file
         temp_path = tempfile.mkdtemp()
-        temp_project_path = os.path.join(temp_path, 'temp.qgs')
+        temp_project_path = os.path.join(temp_path, "temp.qgs")
         self.assertTrue(p.write(temp_project_path))
 
         p2 = QgsProject()
         self.assertTrue(p2.read(temp_project_path))
-        l = p2.mapLayersByName('Lines')[0]
-        self.assertEqual(l.name(), 'Lines')
+        l = p2.mapLayersByName("Lines")[0]
+        self.assertEqual(l.name(), "Lines")
         self.assertFalse(l.isValid())
 
         # custom processor to fix path
         def my_processor(path):
-            return path.replace('moooooo', 'lines')
+            return path.replace("moooooo", "lines")
 
         QgsPathResolver.setPathPreprocessor(my_processor)
         p3 = QgsProject()
         self.assertTrue(p3.read(temp_project_path))
-        l = p3.mapLayersByName('Lines')[0]
-        self.assertEqual(l.name(), 'Lines')
+        l = p3.mapLayersByName("Lines")[0]
+        self.assertEqual(l.name(), "Lines")
         # layer should have correct path now
         self.assertTrue(l.isValid())
 
@@ -141,21 +141,49 @@ class TestQgsPathResolver(QgisTestCase):
         Test resolving and saving inbuilt data paths
         """
         path = "inbuilt:/data/world_map.shp"
-        self.assertEqual(QgsPathResolver().readPath(path), QgsApplication.pkgDataPath() + '/resources/data/world_map.shp')
+        self.assertEqual(
+            QgsPathResolver().readPath(path),
+            QgsApplication.pkgDataPath() + "/resources/data/world_map.shp",
+        )
 
-        self.assertEqual(QgsPathResolver().writePath(QgsApplication.pkgDataPath() + '/resources/data/world_map.shp'), 'inbuilt:/data/world_map.shp')
+        self.assertEqual(
+            QgsPathResolver().writePath(
+                QgsApplication.pkgDataPath() + "/resources/data/world_map.shp"
+            ),
+            "inbuilt:/data/world_map.shp",
+        )
 
     def testRelativeProject(self):
         """Test relative project paths can still resolve, regression #33200"""
 
         curdir = os.getcwd()
-        os.chdir(os.path.join(TEST_DATA_DIR, 'qgis_server'))
-        resolver = QgsPathResolver('./test_project.qgs')
-        self.assertEqual(resolver.readPath('./testlayer.shp').replace("\\", "/"), os.path.join(TEST_DATA_DIR, 'qgis_server', 'testlayer.shp').replace("\\", "/"))
-        self.assertEqual(resolver.readPath('testlayer.shp').replace("\\", "/"), os.path.join(TEST_DATA_DIR, 'qgis_server', 'testlayer.shp').replace("\\", "/"))
-        resolver = QgsPathResolver('test_project.qgs')
-        self.assertEqual(resolver.readPath('./testlayer.shp').replace("\\", "/"), os.path.join(TEST_DATA_DIR, 'qgis_server', 'testlayer.shp').replace("\\", "/"))
-        self.assertEqual(resolver.readPath('testlayer.shp').replace("\\", "/"), os.path.join(TEST_DATA_DIR, 'qgis_server', 'testlayer.shp').replace("\\", "/"))
+        os.chdir(os.path.join(TEST_DATA_DIR, "qgis_server"))
+        resolver = QgsPathResolver("./test_project.qgs")
+        self.assertEqual(
+            resolver.readPath("./testlayer.shp").replace("\\", "/"),
+            os.path.join(TEST_DATA_DIR, "qgis_server", "testlayer.shp").replace(
+                "\\", "/"
+            ),
+        )
+        self.assertEqual(
+            resolver.readPath("testlayer.shp").replace("\\", "/"),
+            os.path.join(TEST_DATA_DIR, "qgis_server", "testlayer.shp").replace(
+                "\\", "/"
+            ),
+        )
+        resolver = QgsPathResolver("test_project.qgs")
+        self.assertEqual(
+            resolver.readPath("./testlayer.shp").replace("\\", "/"),
+            os.path.join(TEST_DATA_DIR, "qgis_server", "testlayer.shp").replace(
+                "\\", "/"
+            ),
+        )
+        self.assertEqual(
+            resolver.readPath("testlayer.shp").replace("\\", "/"),
+            os.path.join(TEST_DATA_DIR, "qgis_server", "testlayer.shp").replace(
+                "\\", "/"
+            ),
+        )
         os.chdir(curdir)
 
     def __test__path_writer(self, path):
@@ -172,23 +200,26 @@ class TestQgsPathResolver(QgisTestCase):
         readerId = QgsPathResolver.setPathPreprocessor(self.__test_path_reader)
         writerId = QgsPathResolver.setPathWriter(self.__test__path_writer)
 
-        uri = os.path.join(TEST_DATA_DIR, 'points_gpkg.gpkg') + "|layername=points_gpkg|subset=1=1 /* foo */"
+        uri = (
+            os.path.join(TEST_DATA_DIR, "points_gpkg.gpkg")
+            + "|layername=points_gpkg|subset=1=1 /* foo */"
+        )
 
-        lines_layer = QgsVectorLayer(uri, 'Points', 'ogr')
+        lines_layer = QgsVectorLayer(uri, "Points", "ogr")
         self.assertTrue(lines_layer.isValid())
         p = QgsProject()
         p.addMapLayer(lines_layer)
         # save project to a temporary file
         temp_path = tempfile.mkdtemp()
-        temp_project_path = os.path.join(temp_path, 'temp.qgs')
+        temp_project_path = os.path.join(temp_path, "temp.qgs")
         self.assertTrue(p.write(temp_project_path))
 
         with open(temp_project_path) as f:
-            self.assertTrue("@TEST_DATA_DIR@" in f.read())
+            self.assertIn("@TEST_DATA_DIR@", f.read())
 
         p2 = QgsProject()
         self.assertTrue(p2.read(temp_project_path))
-        l = p2.mapLayersByName('Points')[0]
+        l = p2.mapLayersByName("Points")[0]
         self.assertEqual(l.isValid(), True)
         self.assertEqual(l.source(), uri)
 
@@ -196,5 +227,5 @@ class TestQgsPathResolver(QgisTestCase):
         QgsPathResolver.removePathWriter(writerId)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
