@@ -44,10 +44,16 @@ from qgis.core import (
     QgsFields,
     QgsField,
 )
-from qgis.server import QgsServerRequest, QgsServer, QgsBufferServerResponse
+from qgis.server import (
+    QgsServerRequest,
+    QgsServer,
+    QgsBufferServerResponse,
+    QgsBufferServerRequest,
+)
 from qgis.testing import unittest
 from test_qgsserver import QgsServerTestBase
 from qgis.PyQt.QtCore import QVariant, QUrl
+from test_qgsserver_accesscontrol import XML_NS
 
 # Strip path and content length because path may vary
 RE_STRIP_UNCHECKABLE = rb'MAP=[^"]+|Content-Length: \d+|timeStamp="[^"]+"'
@@ -1569,6 +1575,37 @@ class TestQgsServerWFS(QgsServerTestBase):
         body = response.body().data().decode("utf8").replace("\n", "")
         self.assertIn("<Operation>Update</Operation>", body)
 
+        # Test an actual transaction
+        post_data = f"""<?xml version="1.0" encoding="UTF-8"?>
+<wfs:Transaction {XML_NS}>
+  <wfs:Insert idgen="GenerateNew">
+    <qgs:no_geom>
+      <qgs:id>1</qgs:id>
+      <qgs:name>one</qgs:name>
+    </qgs:no_geom>
+  </wfs:Insert>
+</wfs:Transaction>"""
+
+        query_string = "?SERVICE=WFS&REQUEST=TRANSACTION"
+        request = QgsBufferServerRequest(
+            QUrl(query_string),
+            QgsServerRequest.PostMethod,
+            {},
+            post_data.encode("utf-8"),
+        )
+        response = QgsBufferServerResponse()
+        server.handleRequest(request, response, project)
+        body = response.body().data()
+
+        self.assertIn(b"<SUCCESS/>", body)
+
+        # Check the backend
+        features = list(provider.getFeatures())
+        self.assertEqual(len(features), 1)
+        f = features[0]
+        self.assertEqual(f["id"], 1)
+        self.assertEqual(f["name"], "one")
+
 
 if __name__ == "__main__":
     unittest.main()
